// Code generated by protoc-gen-go. DO NOT EDIT.
// versions:
// 	protoc-gen-go v1.36.9
// 	protoc        v6.32.1
// source: linkedca/majordomo.proto

package linkedca

import (
	protoreflect "google.golang.org/protobuf/reflect/protoreflect"
	protoimpl "google.golang.org/protobuf/runtime/protoimpl"
	timestamppb "google.golang.org/protobuf/types/known/timestamppb"
	reflect "reflect"
	sync "sync"
	unsafe "unsafe"
)

const (
	// Verify that this generated code is sufficiently up-to-date.
	_ = protoimpl.EnforceVersion(20 - protoimpl.MinVersion)
	// Verify that runtime/protoimpl is sufficiently up-to-date.
	_ = protoimpl.EnforceVersion(protoimpl.MaxVersion - 20)
)

type RevocationStatus int32

const (
	RevocationStatus_UNKNOWN RevocationStatus = 0
	RevocationStatus_ACTIVE  RevocationStatus = 1
	RevocationStatus_REVOKED RevocationStatus = 2
	RevocationStatus_HOLD    RevocationStatus = 3
)

// Enum value maps for RevocationStatus.
var (
	RevocationStatus_name = map[int32]string{
		0: "UNKNOWN",
		1: "ACTIVE",
		2: "REVOKED",
		3: "HOLD",
	}
	RevocationStatus_value = map[string]int32{
		"UNKNOWN": 0,
		"ACTIVE":  1,
		"REVOKED": 2,
		"HOLD":    3,
	}
)

func (x RevocationStatus) Enum() *RevocationStatus {
	p := new(RevocationStatus)
	*p = x
	return p
}

func (x RevocationStatus) String() string {
	return protoimpl.X.EnumStringOf(x.Descriptor(), protoreflect.EnumNumber(x))
}

func (RevocationStatus) Descriptor() protoreflect.EnumDescriptor {
	return file_linkedca_majordomo_proto_enumTypes[0].Descriptor()
}

func (RevocationStatus) Type() protoreflect.EnumType {
	return &file_linkedca_majordomo_proto_enumTypes[0]
}

func (x RevocationStatus) Number() protoreflect.EnumNumber {
	return protoreflect.EnumNumber(x)
}

// Deprecated: Use RevocationStatus.Descriptor instead.
func (RevocationStatus) EnumDescriptor() ([]byte, []int) {
	return file_linkedca_majordomo_proto_rawDescGZIP(), []int{0}
}

type RevocationReasonCode int32

const (
	RevocationReasonCode_UNSPECIFIED            RevocationReasonCode = 0
	RevocationReasonCode_KEY_COMPROMISE         RevocationReasonCode = 1
	RevocationReasonCode_CA_COMPROMISE          RevocationReasonCode = 2
	RevocationReasonCode_AFFILIATION_CHANGED    RevocationReasonCode = 3
	RevocationReasonCode_SUPERSEDED             RevocationReasonCode = 4
	RevocationReasonCode_CESSATION_OF_OPERATION RevocationReasonCode = 5
	RevocationReasonCode_CERTIFICATE_HOLD       RevocationReasonCode = 6
	RevocationReasonCode_REMOVE_FROM_CRL        RevocationReasonCode = 8
	RevocationReasonCode_PRIVILEGE_WITHDRAWN    RevocationReasonCode = 9
	RevocationReasonCode_AA_COMPROMISE          RevocationReasonCode = 10
)

// Enum value maps for RevocationReasonCode.
var (
	RevocationReasonCode_name = map[int32]string{
		0:  "UNSPECIFIED",
		1:  "KEY_COMPROMISE",
		2:  "CA_COMPROMISE",
		3:  "AFFILIATION_CHANGED",
		4:  "SUPERSEDED",
		5:  "CESSATION_OF_OPERATION",
		6:  "CERTIFICATE_HOLD",
		8:  "REMOVE_FROM_CRL",
		9:  "PRIVILEGE_WITHDRAWN",
		10: "AA_COMPROMISE",
	}
	RevocationReasonCode_value = map[string]int32{
		"UNSPECIFIED":            0,
		"KEY_COMPROMISE":         1,
		"CA_COMPROMISE":          2,
		"AFFILIATION_CHANGED":    3,
		"SUPERSEDED":             4,
		"CESSATION_OF_OPERATION": 5,
		"CERTIFICATE_HOLD":       6,
		"REMOVE_FROM_CRL":        8,
		"PRIVILEGE_WITHDRAWN":    9,
		"AA_COMPROMISE":          10,
	}
)

func (x RevocationReasonCode) Enum() *RevocationReasonCode {
	p := new(RevocationReasonCode)
	*p = x
	return p
}

func (x RevocationReasonCode) String() string {
	return protoimpl.X.EnumStringOf(x.Descriptor(), protoreflect.EnumNumber(x))
}

func (RevocationReasonCode) Descriptor() protoreflect.EnumDescriptor {
	return file_linkedca_majordomo_proto_enumTypes[1].Descriptor()
}

func (RevocationReasonCode) Type() protoreflect.EnumType {
	return &file_linkedca_majordomo_proto_enumTypes[1]
}

func (x RevocationReasonCode) Number() protoreflect.EnumNumber {
	return protoreflect.EnumNumber(x)
}

// Deprecated: Use RevocationReasonCode.Descriptor instead.
func (RevocationReasonCode) EnumDescriptor() ([]byte, []int) {
	return file_linkedca_majordomo_proto_rawDescGZIP(), []int{1}
}

type LoginRequest struct {
	state                 protoimpl.MessageState `protogen:"open.v1"`
	AuthorityId           string                 `protobuf:"bytes,1,opt,name=authority_id,json=authorityId,proto3" json:"authority_id,omitempty"`
	Token                 string                 `protobuf:"bytes,2,opt,name=token,proto3" json:"token,omitempty"`
	PemCertificateRequest string                 `protobuf:"bytes,3,opt,name=pem_certificate_request,json=pemCertificateRequest,proto3" json:"pem_certificate_request,omitempty"`
	unknownFields         protoimpl.UnknownFields
	sizeCache             protoimpl.SizeCache
}

func (x *LoginRequest) Reset() {
	*x = LoginRequest{}
	mi := &file_linkedca_majordomo_proto_msgTypes[0]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *LoginRequest) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*LoginRequest) ProtoMessage() {}

func (x *LoginRequest) ProtoReflect() protoreflect.Message {
	mi := &file_linkedca_majordomo_proto_msgTypes[0]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use LoginRequest.ProtoReflect.Descriptor instead.
func (*LoginRequest) Descriptor() ([]byte, []int) {
	return file_linkedca_majordomo_proto_rawDescGZIP(), []int{0}
}

func (x *LoginRequest) GetAuthorityId() string {
	if x != nil {
		return x.AuthorityId
	}
	return ""
}

func (x *LoginRequest) GetToken() string {
	if x != nil {
		return x.Token
	}
	return ""
}

func (x *LoginRequest) GetPemCertificateRequest() string {
	if x != nil {
		return x.PemCertificateRequest
	}
	return ""
}

type LoginResponse struct {
	state               protoimpl.MessageState `protogen:"open.v1"`
	PemCertificate      string                 `protobuf:"bytes,1,opt,name=pem_certificate,json=pemCertificate,proto3" json:"pem_certificate,omitempty"`
	PemCertificateChain string                 `protobuf:"bytes,2,opt,name=pem_certificate_chain,json=pemCertificateChain,proto3" json:"pem_certificate_chain,omitempty"`
	unknownFields       protoimpl.UnknownFields
	sizeCache           protoimpl.SizeCache
}

func (x *LoginResponse) Reset() {
	*x = LoginResponse{}
	mi := &file_linkedca_majordomo_proto_msgTypes[1]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *LoginResponse) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*LoginResponse) ProtoMessage() {}

func (x *LoginResponse) ProtoReflect() protoreflect.Message {
	mi := &file_linkedca_majordomo_proto_msgTypes[1]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use LoginResponse.ProtoReflect.Descriptor instead.
func (*LoginResponse) Descriptor() ([]byte, []int) {
	return file_linkedca_majordomo_proto_rawDescGZIP(), []int{1}
}

func (x *LoginResponse) GetPemCertificate() string {
	if x != nil {
		return x.PemCertificate
	}
	return ""
}

func (x *LoginResponse) GetPemCertificateChain() string {
	if x != nil {
		return x.PemCertificateChain
	}
	return ""
}

type GetRootCertificateRequest struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	Fingerprint   string                 `protobuf:"bytes,1,opt,name=fingerprint,proto3" json:"fingerprint,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *GetRootCertificateRequest) Reset() {
	*x = GetRootCertificateRequest{}
	mi := &file_linkedca_majordomo_proto_msgTypes[2]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *GetRootCertificateRequest) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*GetRootCertificateRequest) ProtoMessage() {}

func (x *GetRootCertificateRequest) ProtoReflect() protoreflect.Message {
	mi := &file_linkedca_majordomo_proto_msgTypes[2]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use GetRootCertificateRequest.ProtoReflect.Descriptor instead.
func (*GetRootCertificateRequest) Descriptor() ([]byte, []int) {
	return file_linkedca_majordomo_proto_rawDescGZIP(), []int{2}
}

func (x *GetRootCertificateRequest) GetFingerprint() string {
	if x != nil {
		return x.Fingerprint
	}
	return ""
}

type GetRootCertificateResponse struct {
	state          protoimpl.MessageState `protogen:"open.v1"`
	PemCertificate string                 `protobuf:"bytes,1,opt,name=pem_certificate,json=pemCertificate,proto3" json:"pem_certificate,omitempty"`
	unknownFields  protoimpl.UnknownFields
	sizeCache      protoimpl.SizeCache
}

func (x *GetRootCertificateResponse) Reset() {
	*x = GetRootCertificateResponse{}
	mi := &file_linkedca_majordomo_proto_msgTypes[3]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *GetRootCertificateResponse) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*GetRootCertificateResponse) ProtoMessage() {}

func (x *GetRootCertificateResponse) ProtoReflect() protoreflect.Message {
	mi := &file_linkedca_majordomo_proto_msgTypes[3]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use GetRootCertificateResponse.ProtoReflect.Descriptor instead.
func (*GetRootCertificateResponse) Descriptor() ([]byte, []int) {
	return file_linkedca_majordomo_proto_rawDescGZIP(), []int{3}
}

func (x *GetRootCertificateResponse) GetPemCertificate() string {
	if x != nil {
		return x.PemCertificate
	}
	return ""
}

type ConfigurationRequest struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	AuthorityId   string                 `protobuf:"bytes,1,opt,name=authority_id,json=authorityId,proto3" json:"authority_id,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *ConfigurationRequest) Reset() {
	*x = ConfigurationRequest{}
	mi := &file_linkedca_majordomo_proto_msgTypes[4]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *ConfigurationRequest) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*ConfigurationRequest) ProtoMessage() {}

func (x *ConfigurationRequest) ProtoReflect() protoreflect.Message {
	mi := &file_linkedca_majordomo_proto_msgTypes[4]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use ConfigurationRequest.ProtoReflect.Descriptor instead.
func (*ConfigurationRequest) Descriptor() ([]byte, []int) {
	return file_linkedca_majordomo_proto_rawDescGZIP(), []int{4}
}

func (x *ConfigurationRequest) GetAuthorityId() string {
	if x != nil {
		return x.AuthorityId
	}
	return ""
}

type ConfigurationResponse struct {
	state         protoimpl.MessageState       `protogen:"open.v1"`
	Provisioners  []*Provisioner               `protobuf:"bytes,1,rep,name=provisioners,proto3" json:"provisioners,omitempty"`
	Admins        []*Admin                     `protobuf:"bytes,2,rep,name=admins,proto3" json:"admins,omitempty"`
	RaConfig      *RegistrationAuthorityConfig `protobuf:"bytes,3,opt,name=ra_config,json=raConfig,proto3" json:"ra_config,omitempty"`
	ServerConfig  *ServerConfiguration         `protobuf:"bytes,4,opt,name=server_config,json=serverConfig,proto3" json:"server_config,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *ConfigurationResponse) Reset() {
	*x = ConfigurationResponse{}
	mi := &file_linkedca_majordomo_proto_msgTypes[5]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *ConfigurationResponse) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*ConfigurationResponse) ProtoMessage() {}

func (x *ConfigurationResponse) ProtoReflect() protoreflect.Message {
	mi := &file_linkedca_majordomo_proto_msgTypes[5]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use ConfigurationResponse.ProtoReflect.Descriptor instead.
func (*ConfigurationResponse) Descriptor() ([]byte, []int) {
	return file_linkedca_majordomo_proto_rawDescGZIP(), []int{5}
}

func (x *ConfigurationResponse) GetProvisioners() []*Provisioner {
	if x != nil {
		return x.Provisioners
	}
	return nil
}

func (x *ConfigurationResponse) GetAdmins() []*Admin {
	if x != nil {
		return x.Admins
	}
	return nil
}

func (x *ConfigurationResponse) GetRaConfig() *RegistrationAuthorityConfig {
	if x != nil {
		return x.RaConfig
	}
	return nil
}

func (x *ConfigurationResponse) GetServerConfig() *ServerConfiguration {
	if x != nil {
		return x.ServerConfig
	}
	return nil
}

type ServerConfiguration struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	Address       string                 `protobuf:"bytes,1,opt,name=address,proto3" json:"address,omitempty"`
	DnsNames      []string               `protobuf:"bytes,2,rep,name=dns_names,json=dnsNames,proto3" json:"dns_names,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *ServerConfiguration) Reset() {
	*x = ServerConfiguration{}
	mi := &file_linkedca_majordomo_proto_msgTypes[6]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *ServerConfiguration) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*ServerConfiguration) ProtoMessage() {}

func (x *ServerConfiguration) ProtoReflect() protoreflect.Message {
	mi := &file_linkedca_majordomo_proto_msgTypes[6]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use ServerConfiguration.ProtoReflect.Descriptor instead.
func (*ServerConfiguration) Descriptor() ([]byte, []int) {
	return file_linkedca_majordomo_proto_rawDescGZIP(), []int{6}
}

func (x *ServerConfiguration) GetAddress() string {
	if x != nil {
		return x.Address
	}
	return ""
}

func (x *ServerConfiguration) GetDnsNames() []string {
	if x != nil {
		return x.DnsNames
	}
	return nil
}

type RegistrationAuthorityConfig struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	CaUrl         string                 `protobuf:"bytes,1,opt,name=ca_url,json=caUrl,proto3" json:"ca_url,omitempty"`
	Fingerprint   string                 `protobuf:"bytes,2,opt,name=fingerprint,proto3" json:"fingerprint,omitempty"`
	Provisioner   *ProvisionerIdentity   `protobuf:"bytes,3,opt,name=provisioner,proto3" json:"provisioner,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *RegistrationAuthorityConfig) Reset() {
	*x = RegistrationAuthorityConfig{}
	mi := &file_linkedca_majordomo_proto_msgTypes[7]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *RegistrationAuthorityConfig) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*RegistrationAuthorityConfig) ProtoMessage() {}

func (x *RegistrationAuthorityConfig) ProtoReflect() protoreflect.Message {
	mi := &file_linkedca_majordomo_proto_msgTypes[7]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use RegistrationAuthorityConfig.ProtoReflect.Descriptor instead.
func (*RegistrationAuthorityConfig) Descriptor() ([]byte, []int) {
	return file_linkedca_majordomo_proto_rawDescGZIP(), []int{7}
}

func (x *RegistrationAuthorityConfig) GetCaUrl() string {
	if x != nil {
		return x.CaUrl
	}
	return ""
}

func (x *RegistrationAuthorityConfig) GetFingerprint() string {
	if x != nil {
		return x.Fingerprint
	}
	return ""
}

func (x *RegistrationAuthorityConfig) GetProvisioner() *ProvisionerIdentity {
	if x != nil {
		return x.Provisioner
	}
	return nil
}

type RegistrationAuthorityProvisioner struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	AuthorityId   string                 `protobuf:"bytes,1,opt,name=authority_id,json=authorityId,proto3" json:"authority_id,omitempty"`
	Provisioner   *ProvisionerIdentity   `protobuf:"bytes,2,opt,name=provisioner,proto3" json:"provisioner,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *RegistrationAuthorityProvisioner) Reset() {
	*x = RegistrationAuthorityProvisioner{}
	mi := &file_linkedca_majordomo_proto_msgTypes[8]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *RegistrationAuthorityProvisioner) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*RegistrationAuthorityProvisioner) ProtoMessage() {}

func (x *RegistrationAuthorityProvisioner) ProtoReflect() protoreflect.Message {
	mi := &file_linkedca_majordomo_proto_msgTypes[8]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use RegistrationAuthorityProvisioner.ProtoReflect.Descriptor instead.
func (*RegistrationAuthorityProvisioner) Descriptor() ([]byte, []int) {
	return file_linkedca_majordomo_proto_rawDescGZIP(), []int{8}
}

func (x *RegistrationAuthorityProvisioner) GetAuthorityId() string {
	if x != nil {
		return x.AuthorityId
	}
	return ""
}

func (x *RegistrationAuthorityProvisioner) GetProvisioner() *ProvisionerIdentity {
	if x != nil {
		return x.Provisioner
	}
	return nil
}

type CreateProvisionerRequest struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	Type          Provisioner_Type       `protobuf:"varint,1,opt,name=type,proto3,enum=linkedca.Provisioner_Type" json:"type,omitempty"`
	Name          string                 `protobuf:"bytes,2,opt,name=name,proto3" json:"name,omitempty"`
	Details       *ProvisionerDetails    `protobuf:"bytes,3,opt,name=details,proto3" json:"details,omitempty"`
	Claims        *Claims                `protobuf:"bytes,4,opt,name=claims,proto3" json:"claims,omitempty"`
	X509Template  *Template              `protobuf:"bytes,5,opt,name=x509_template,json=x509Template,proto3" json:"x509_template,omitempty"`
	SshTemplate   *Template              `protobuf:"bytes,6,opt,name=ssh_template,json=sshTemplate,proto3" json:"ssh_template,omitempty"`
	PreferredId   string                 `protobuf:"bytes,7,opt,name=preferred_id,json=preferredId,proto3" json:"preferred_id,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *CreateProvisionerRequest) Reset() {
	*x = CreateProvisionerRequest{}
	mi := &file_linkedca_majordomo_proto_msgTypes[9]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *CreateProvisionerRequest) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*CreateProvisionerRequest) ProtoMessage() {}

func (x *CreateProvisionerRequest) ProtoReflect() protoreflect.Message {
	mi := &file_linkedca_majordomo_proto_msgTypes[9]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use CreateProvisionerRequest.ProtoReflect.Descriptor instead.
func (*CreateProvisionerRequest) Descriptor() ([]byte, []int) {
	return file_linkedca_majordomo_proto_rawDescGZIP(), []int{9}
}

func (x *CreateProvisionerRequest) GetType() Provisioner_Type {
	if x != nil {
		return x.Type
	}
	return Provisioner_NOOP
}

func (x *CreateProvisionerRequest) GetName() string {
	if x != nil {
		return x.Name
	}
	return ""
}

func (x *CreateProvisionerRequest) GetDetails() *ProvisionerDetails {
	if x != nil {
		return x.Details
	}
	return nil
}

func (x *CreateProvisionerRequest) GetClaims() *Claims {
	if x != nil {
		return x.Claims
	}
	return nil
}

func (x *CreateProvisionerRequest) GetX509Template() *Template {
	if x != nil {
		return x.X509Template
	}
	return nil
}

func (x *CreateProvisionerRequest) GetSshTemplate() *Template {
	if x != nil {
		return x.SshTemplate
	}
	return nil
}

func (x *CreateProvisionerRequest) GetPreferredId() string {
	if x != nil {
		return x.PreferredId
	}
	return ""
}

type GetProvisionerRequest struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	Id            string                 `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *GetProvisionerRequest) Reset() {
	*x = GetProvisionerRequest{}
	mi := &file_linkedca_majordomo_proto_msgTypes[10]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *GetProvisionerRequest) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*GetProvisionerRequest) ProtoMessage() {}

func (x *GetProvisionerRequest) ProtoReflect() protoreflect.Message {
	mi := &file_linkedca_majordomo_proto_msgTypes[10]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use GetProvisionerRequest.ProtoReflect.Descriptor instead.
func (*GetProvisionerRequest) Descriptor() ([]byte, []int) {
	return file_linkedca_majordomo_proto_rawDescGZIP(), []int{10}
}

func (x *GetProvisionerRequest) GetId() string {
	if x != nil {
		return x.Id
	}
	return ""
}

type UpdateProvisionerRequest struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	Id            string                 `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
	Name          string                 `protobuf:"bytes,2,opt,name=name,proto3" json:"name,omitempty"`
	Details       *ProvisionerDetails    `protobuf:"bytes,3,opt,name=details,proto3" json:"details,omitempty"`
	Claims        *Claims                `protobuf:"bytes,4,opt,name=claims,proto3" json:"claims,omitempty"`
	X509Template  *Template              `protobuf:"bytes,5,opt,name=x509_template,json=x509Template,proto3" json:"x509_template,omitempty"`
	SshTemplate   *Template              `protobuf:"bytes,6,opt,name=ssh_template,json=sshTemplate,proto3" json:"ssh_template,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *UpdateProvisionerRequest) Reset() {
	*x = UpdateProvisionerRequest{}
	mi := &file_linkedca_majordomo_proto_msgTypes[11]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *UpdateProvisionerRequest) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*UpdateProvisionerRequest) ProtoMessage() {}

func (x *UpdateProvisionerRequest) ProtoReflect() protoreflect.Message {
	mi := &file_linkedca_majordomo_proto_msgTypes[11]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use UpdateProvisionerRequest.ProtoReflect.Descriptor instead.
func (*UpdateProvisionerRequest) Descriptor() ([]byte, []int) {
	return file_linkedca_majordomo_proto_rawDescGZIP(), []int{11}
}

func (x *UpdateProvisionerRequest) GetId() string {
	if x != nil {
		return x.Id
	}
	return ""
}

func (x *UpdateProvisionerRequest) GetName() string {
	if x != nil {
		return x.Name
	}
	return ""
}

func (x *UpdateProvisionerRequest) GetDetails() *ProvisionerDetails {
	if x != nil {
		return x.Details
	}
	return nil
}

func (x *UpdateProvisionerRequest) GetClaims() *Claims {
	if x != nil {
		return x.Claims
	}
	return nil
}

func (x *UpdateProvisionerRequest) GetX509Template() *Template {
	if x != nil {
		return x.X509Template
	}
	return nil
}

func (x *UpdateProvisionerRequest) GetSshTemplate() *Template {
	if x != nil {
		return x.SshTemplate
	}
	return nil
}

type DeleteProvisionerRequest struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	Id            string                 `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *DeleteProvisionerRequest) Reset() {
	*x = DeleteProvisionerRequest{}
	mi := &file_linkedca_majordomo_proto_msgTypes[12]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *DeleteProvisionerRequest) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*DeleteProvisionerRequest) ProtoMessage() {}

func (x *DeleteProvisionerRequest) ProtoReflect() protoreflect.Message {
	mi := &file_linkedca_majordomo_proto_msgTypes[12]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use DeleteProvisionerRequest.ProtoReflect.Descriptor instead.
func (*DeleteProvisionerRequest) Descriptor() ([]byte, []int) {
	return file_linkedca_majordomo_proto_rawDescGZIP(), []int{12}
}

func (x *DeleteProvisionerRequest) GetId() string {
	if x != nil {
		return x.Id
	}
	return ""
}

type CreateAdminRequest struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	Subject       string                 `protobuf:"bytes,1,opt,name=subject,proto3" json:"subject,omitempty"`
	ProvisionerId string                 `protobuf:"bytes,2,opt,name=provisioner_id,json=provisionerId,proto3" json:"provisioner_id,omitempty"`
	Type          Admin_Type             `protobuf:"varint,3,opt,name=type,proto3,enum=linkedca.Admin_Type" json:"type,omitempty"`
	PreferredId   string                 `protobuf:"bytes,4,opt,name=preferred_id,json=preferredId,proto3" json:"preferred_id,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *CreateAdminRequest) Reset() {
	*x = CreateAdminRequest{}
	mi := &file_linkedca_majordomo_proto_msgTypes[13]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *CreateAdminRequest) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*CreateAdminRequest) ProtoMessage() {}

func (x *CreateAdminRequest) ProtoReflect() protoreflect.Message {
	mi := &file_linkedca_majordomo_proto_msgTypes[13]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use CreateAdminRequest.ProtoReflect.Descriptor instead.
func (*CreateAdminRequest) Descriptor() ([]byte, []int) {
	return file_linkedca_majordomo_proto_rawDescGZIP(), []int{13}
}

func (x *CreateAdminRequest) GetSubject() string {
	if x != nil {
		return x.Subject
	}
	return ""
}

func (x *CreateAdminRequest) GetProvisionerId() string {
	if x != nil {
		return x.ProvisionerId
	}
	return ""
}

func (x *CreateAdminRequest) GetType() Admin_Type {
	if x != nil {
		return x.Type
	}
	return Admin_UNKNOWN
}

func (x *CreateAdminRequest) GetPreferredId() string {
	if x != nil {
		return x.PreferredId
	}
	return ""
}

type GetAdminRequest struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	Id            string                 `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *GetAdminRequest) Reset() {
	*x = GetAdminRequest{}
	mi := &file_linkedca_majordomo_proto_msgTypes[14]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *GetAdminRequest) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*GetAdminRequest) ProtoMessage() {}

func (x *GetAdminRequest) ProtoReflect() protoreflect.Message {
	mi := &file_linkedca_majordomo_proto_msgTypes[14]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use GetAdminRequest.ProtoReflect.Descriptor instead.
func (*GetAdminRequest) Descriptor() ([]byte, []int) {
	return file_linkedca_majordomo_proto_rawDescGZIP(), []int{14}
}

func (x *GetAdminRequest) GetId() string {
	if x != nil {
		return x.Id
	}
	return ""
}

type UpdateAdminRequest struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	Id            string                 `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
	Type          Admin_Type             `protobuf:"varint,2,opt,name=type,proto3,enum=linkedca.Admin_Type" json:"type,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *UpdateAdminRequest) Reset() {
	*x = UpdateAdminRequest{}
	mi := &file_linkedca_majordomo_proto_msgTypes[15]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *UpdateAdminRequest) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*UpdateAdminRequest) ProtoMessage() {}

func (x *UpdateAdminRequest) ProtoReflect() protoreflect.Message {
	mi := &file_linkedca_majordomo_proto_msgTypes[15]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use UpdateAdminRequest.ProtoReflect.Descriptor instead.
func (*UpdateAdminRequest) Descriptor() ([]byte, []int) {
	return file_linkedca_majordomo_proto_rawDescGZIP(), []int{15}
}

func (x *UpdateAdminRequest) GetId() string {
	if x != nil {
		return x.Id
	}
	return ""
}

func (x *UpdateAdminRequest) GetType() Admin_Type {
	if x != nil {
		return x.Type
	}
	return Admin_UNKNOWN
}

type DeleteAdminRequest struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	Id            string                 `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *DeleteAdminRequest) Reset() {
	*x = DeleteAdminRequest{}
	mi := &file_linkedca_majordomo_proto_msgTypes[16]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *DeleteAdminRequest) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*DeleteAdminRequest) ProtoMessage() {}

func (x *DeleteAdminRequest) ProtoReflect() protoreflect.Message {
	mi := &file_linkedca_majordomo_proto_msgTypes[16]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use DeleteAdminRequest.ProtoReflect.Descriptor instead.
func (*DeleteAdminRequest) Descriptor() ([]byte, []int) {
	return file_linkedca_majordomo_proto_rawDescGZIP(), []int{16}
}

func (x *DeleteAdminRequest) GetId() string {
	if x != nil {
		return x.Id
	}
	return ""
}

type CertificateRequest struct {
	state                protoimpl.MessageState            `protogen:"open.v1"`
	PemCertificate       string                            `protobuf:"bytes,1,opt,name=pem_certificate,json=pemCertificate,proto3" json:"pem_certificate,omitempty"`
	PemCertificateChain  string                            `protobuf:"bytes,2,opt,name=pem_certificate_chain,json=pemCertificateChain,proto3" json:"pem_certificate_chain,omitempty"`
	PemParentCertificate string                            `protobuf:"bytes,3,opt,name=pem_parent_certificate,json=pemParentCertificate,proto3" json:"pem_parent_certificate,omitempty"`
	Provisioner          *ProvisionerIdentity              `protobuf:"bytes,4,opt,name=provisioner,proto3" json:"provisioner,omitempty"`
	RaProvisioner        *RegistrationAuthorityProvisioner `protobuf:"bytes,5,opt,name=ra_provisioner,json=raProvisioner,proto3" json:"ra_provisioner,omitempty"`
	EndpointId           string                            `protobuf:"bytes,6,opt,name=endpoint_id,json=endpointId,proto3" json:"endpoint_id,omitempty"`
	AttestationData      *AttestationData                  `protobuf:"bytes,7,opt,name=attestation_data,json=attestationData,proto3" json:"attestation_data,omitempty"`
	unknownFields        protoimpl.UnknownFields
	sizeCache            protoimpl.SizeCache
}

func (x *CertificateRequest) Reset() {
	*x = CertificateRequest{}
	mi := &file_linkedca_majordomo_proto_msgTypes[17]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *CertificateRequest) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*CertificateRequest) ProtoMessage() {}

func (x *CertificateRequest) ProtoReflect() protoreflect.Message {
	mi := &file_linkedca_majordomo_proto_msgTypes[17]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use CertificateRequest.ProtoReflect.Descriptor instead.
func (*CertificateRequest) Descriptor() ([]byte, []int) {
	return file_linkedca_majordomo_proto_rawDescGZIP(), []int{17}
}

func (x *CertificateRequest) GetPemCertificate() string {
	if x != nil {
		return x.PemCertificate
	}
	return ""
}

func (x *CertificateRequest) GetPemCertificateChain() string {
	if x != nil {
		return x.PemCertificateChain
	}
	return ""
}

func (x *CertificateRequest) GetPemParentCertificate() string {
	if x != nil {
		return x.PemParentCertificate
	}
	return ""
}

func (x *CertificateRequest) GetProvisioner() *ProvisionerIdentity {
	if x != nil {
		return x.Provisioner
	}
	return nil
}

func (x *CertificateRequest) GetRaProvisioner() *RegistrationAuthorityProvisioner {
	if x != nil {
		return x.RaProvisioner
	}
	return nil
}

func (x *CertificateRequest) GetEndpointId() string {
	if x != nil {
		return x.EndpointId
	}
	return ""
}

func (x *CertificateRequest) GetAttestationData() *AttestationData {
	if x != nil {
		return x.AttestationData
	}
	return nil
}

// AttestationData holds the information available at certificate sign time.
// Currently only the permanent identifier (UDID or SerialNumber, not both) is
// available.
type AttestationData struct {
	state               protoimpl.MessageState `protogen:"open.v1"`
	PermanentIdentifier string                 `protobuf:"bytes,1,opt,name=permanent_identifier,json=permanentIdentifier,proto3" json:"permanent_identifier,omitempty"`
	unknownFields       protoimpl.UnknownFields
	sizeCache           protoimpl.SizeCache
}

func (x *AttestationData) Reset() {
	*x = AttestationData{}
	mi := &file_linkedca_majordomo_proto_msgTypes[18]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *AttestationData) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*AttestationData) ProtoMessage() {}

func (x *AttestationData) ProtoReflect() protoreflect.Message {
	mi := &file_linkedca_majordomo_proto_msgTypes[18]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use AttestationData.ProtoReflect.Descriptor instead.
func (*AttestationData) Descriptor() ([]byte, []int) {
	return file_linkedca_majordomo_proto_rawDescGZIP(), []int{18}
}

func (x *AttestationData) GetPermanentIdentifier() string {
	if x != nil {
		return x.PermanentIdentifier
	}
	return ""
}

type CertificateResponse struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	Id            string                 `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *CertificateResponse) Reset() {
	*x = CertificateResponse{}
	mi := &file_linkedca_majordomo_proto_msgTypes[19]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *CertificateResponse) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*CertificateResponse) ProtoMessage() {}

func (x *CertificateResponse) ProtoReflect() protoreflect.Message {
	mi := &file_linkedca_majordomo_proto_msgTypes[19]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use CertificateResponse.ProtoReflect.Descriptor instead.
func (*CertificateResponse) Descriptor() ([]byte, []int) {
	return file_linkedca_majordomo_proto_rawDescGZIP(), []int{19}
}

func (x *CertificateResponse) GetId() string {
	if x != nil {
		return x.Id
	}
	return ""
}

type SSHCertificateRequest struct {
	state             protoimpl.MessageState `protogen:"open.v1"`
	Certificate       string                 `protobuf:"bytes,1,opt,name=certificate,proto3" json:"certificate,omitempty"`
	ParentCertificate string                 `protobuf:"bytes,2,opt,name=parent_certificate,json=parentCertificate,proto3" json:"parent_certificate,omitempty"`
	Provisioner       *ProvisionerIdentity   `protobuf:"bytes,3,opt,name=provisioner,proto3" json:"provisioner,omitempty"`
	unknownFields     protoimpl.UnknownFields
	sizeCache         protoimpl.SizeCache
}

func (x *SSHCertificateRequest) Reset() {
	*x = SSHCertificateRequest{}
	mi := &file_linkedca_majordomo_proto_msgTypes[20]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *SSHCertificateRequest) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*SSHCertificateRequest) ProtoMessage() {}

func (x *SSHCertificateRequest) ProtoReflect() protoreflect.Message {
	mi := &file_linkedca_majordomo_proto_msgTypes[20]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use SSHCertificateRequest.ProtoReflect.Descriptor instead.
func (*SSHCertificateRequest) Descriptor() ([]byte, []int) {
	return file_linkedca_majordomo_proto_rawDescGZIP(), []int{20}
}

func (x *SSHCertificateRequest) GetCertificate() string {
	if x != nil {
		return x.Certificate
	}
	return ""
}

func (x *SSHCertificateRequest) GetParentCertificate() string {
	if x != nil {
		return x.ParentCertificate
	}
	return ""
}

func (x *SSHCertificateRequest) GetProvisioner() *ProvisionerIdentity {
	if x != nil {
		return x.Provisioner
	}
	return nil
}

type SSHCertificateResponse struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	Id            string                 `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *SSHCertificateResponse) Reset() {
	*x = SSHCertificateResponse{}
	mi := &file_linkedca_majordomo_proto_msgTypes[21]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *SSHCertificateResponse) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*SSHCertificateResponse) ProtoMessage() {}

func (x *SSHCertificateResponse) ProtoReflect() protoreflect.Message {
	mi := &file_linkedca_majordomo_proto_msgTypes[21]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use SSHCertificateResponse.ProtoReflect.Descriptor instead.
func (*SSHCertificateResponse) Descriptor() ([]byte, []int) {
	return file_linkedca_majordomo_proto_rawDescGZIP(), []int{21}
}

func (x *SSHCertificateResponse) GetId() string {
	if x != nil {
		return x.Id
	}
	return ""
}

type OneTimeTokenRequest struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	Jti           string                 `protobuf:"bytes,1,opt,name=jti,proto3" json:"jti,omitempty"`
	Token         string                 `protobuf:"bytes,2,opt,name=token,proto3" json:"token,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *OneTimeTokenRequest) Reset() {
	*x = OneTimeTokenRequest{}
	mi := &file_linkedca_majordomo_proto_msgTypes[22]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *OneTimeTokenRequest) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*OneTimeTokenRequest) ProtoMessage() {}

func (x *OneTimeTokenRequest) ProtoReflect() protoreflect.Message {
	mi := &file_linkedca_majordomo_proto_msgTypes[22]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use OneTimeTokenRequest.ProtoReflect.Descriptor instead.
func (*OneTimeTokenRequest) Descriptor() ([]byte, []int) {
	return file_linkedca_majordomo_proto_rawDescGZIP(), []int{22}
}

func (x *OneTimeTokenRequest) GetJti() string {
	if x != nil {
		return x.Jti
	}
	return ""
}

func (x *OneTimeTokenRequest) GetToken() string {
	if x != nil {
		return x.Token
	}
	return ""
}

type OneTimeTokenResponse struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	Id            string                 `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *OneTimeTokenResponse) Reset() {
	*x = OneTimeTokenResponse{}
	mi := &file_linkedca_majordomo_proto_msgTypes[23]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *OneTimeTokenResponse) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*OneTimeTokenResponse) ProtoMessage() {}

func (x *OneTimeTokenResponse) ProtoReflect() protoreflect.Message {
	mi := &file_linkedca_majordomo_proto_msgTypes[23]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use OneTimeTokenResponse.ProtoReflect.Descriptor instead.
func (*OneTimeTokenResponse) Descriptor() ([]byte, []int) {
	return file_linkedca_majordomo_proto_rawDescGZIP(), []int{23}
}

func (x *OneTimeTokenResponse) GetId() string {
	if x != nil {
		return x.Id
	}
	return ""
}

type RevokeCertificateRequest struct {
	state          protoimpl.MessageState `protogen:"open.v1"`
	Serial         string                 `protobuf:"bytes,1,opt,name=serial,proto3" json:"serial,omitempty"`
	PemCertificate string                 `protobuf:"bytes,2,opt,name=pem_certificate,json=pemCertificate,proto3" json:"pem_certificate,omitempty"`
	Reason         string                 `protobuf:"bytes,3,opt,name=reason,proto3" json:"reason,omitempty"`
	ReasonCode     RevocationReasonCode   `protobuf:"varint,4,opt,name=reason_code,json=reasonCode,proto3,enum=linkedca.RevocationReasonCode" json:"reason_code,omitempty"`
	Passive        bool                   `protobuf:"varint,5,opt,name=passive,proto3" json:"passive,omitempty"`
	RevokedAt      *timestamppb.Timestamp `protobuf:"bytes,6,opt,name=revoked_at,json=revokedAt,proto3" json:"revoked_at,omitempty"`
	unknownFields  protoimpl.UnknownFields
	sizeCache      protoimpl.SizeCache
}

func (x *RevokeCertificateRequest) Reset() {
	*x = RevokeCertificateRequest{}
	mi := &file_linkedca_majordomo_proto_msgTypes[24]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *RevokeCertificateRequest) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*RevokeCertificateRequest) ProtoMessage() {}

func (x *RevokeCertificateRequest) ProtoReflect() protoreflect.Message {
	mi := &file_linkedca_majordomo_proto_msgTypes[24]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use RevokeCertificateRequest.ProtoReflect.Descriptor instead.
func (*RevokeCertificateRequest) Descriptor() ([]byte, []int) {
	return file_linkedca_majordomo_proto_rawDescGZIP(), []int{24}
}

func (x *RevokeCertificateRequest) GetSerial() string {
	if x != nil {
		return x.Serial
	}
	return ""
}

func (x *RevokeCertificateRequest) GetPemCertificate() string {
	if x != nil {
		return x.PemCertificate
	}
	return ""
}

func (x *RevokeCertificateRequest) GetReason() string {
	if x != nil {
		return x.Reason
	}
	return ""
}

func (x *RevokeCertificateRequest) GetReasonCode() RevocationReasonCode {
	if x != nil {
		return x.ReasonCode
	}
	return RevocationReasonCode_UNSPECIFIED
}

func (x *RevokeCertificateRequest) GetPassive() bool {
	if x != nil {
		return x.Passive
	}
	return false
}

func (x *RevokeCertificateRequest) GetRevokedAt() *timestamppb.Timestamp {
	if x != nil {
		return x.RevokedAt
	}
	return nil
}

type RevokeCertificateResponse struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	Status        RevocationStatus       `protobuf:"varint,1,opt,name=status,proto3,enum=linkedca.RevocationStatus" json:"status,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *RevokeCertificateResponse) Reset() {
	*x = RevokeCertificateResponse{}
	mi := &file_linkedca_majordomo_proto_msgTypes[25]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *RevokeCertificateResponse) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*RevokeCertificateResponse) ProtoMessage() {}

func (x *RevokeCertificateResponse) ProtoReflect() protoreflect.Message {
	mi := &file_linkedca_majordomo_proto_msgTypes[25]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use RevokeCertificateResponse.ProtoReflect.Descriptor instead.
func (*RevokeCertificateResponse) Descriptor() ([]byte, []int) {
	return file_linkedca_majordomo_proto_rawDescGZIP(), []int{25}
}

func (x *RevokeCertificateResponse) GetStatus() RevocationStatus {
	if x != nil {
		return x.Status
	}
	return RevocationStatus_UNKNOWN
}

type RevokeSSHCertificateRequest struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	Serial        string                 `protobuf:"bytes,1,opt,name=serial,proto3" json:"serial,omitempty"`
	Certificate   string                 `protobuf:"bytes,2,opt,name=certificate,proto3" json:"certificate,omitempty"`
	Reason        string                 `protobuf:"bytes,3,opt,name=reason,proto3" json:"reason,omitempty"`
	ReasonCode    RevocationReasonCode   `protobuf:"varint,4,opt,name=reason_code,json=reasonCode,proto3,enum=linkedca.RevocationReasonCode" json:"reason_code,omitempty"`
	Passive       bool                   `protobuf:"varint,5,opt,name=passive,proto3" json:"passive,omitempty"`
	RevokedAt     *timestamppb.Timestamp `protobuf:"bytes,6,opt,name=revoked_at,json=revokedAt,proto3" json:"revoked_at,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *RevokeSSHCertificateRequest) Reset() {
	*x = RevokeSSHCertificateRequest{}
	mi := &file_linkedca_majordomo_proto_msgTypes[26]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *RevokeSSHCertificateRequest) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*RevokeSSHCertificateRequest) ProtoMessage() {}

func (x *RevokeSSHCertificateRequest) ProtoReflect() protoreflect.Message {
	mi := &file_linkedca_majordomo_proto_msgTypes[26]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use RevokeSSHCertificateRequest.ProtoReflect.Descriptor instead.
func (*RevokeSSHCertificateRequest) Descriptor() ([]byte, []int) {
	return file_linkedca_majordomo_proto_rawDescGZIP(), []int{26}
}

func (x *RevokeSSHCertificateRequest) GetSerial() string {
	if x != nil {
		return x.Serial
	}
	return ""
}

func (x *RevokeSSHCertificateRequest) GetCertificate() string {
	if x != nil {
		return x.Certificate
	}
	return ""
}

func (x *RevokeSSHCertificateRequest) GetReason() string {
	if x != nil {
		return x.Reason
	}
	return ""
}

func (x *RevokeSSHCertificateRequest) GetReasonCode() RevocationReasonCode {
	if x != nil {
		return x.ReasonCode
	}
	return RevocationReasonCode_UNSPECIFIED
}

func (x *RevokeSSHCertificateRequest) GetPassive() bool {
	if x != nil {
		return x.Passive
	}
	return false
}

func (x *RevokeSSHCertificateRequest) GetRevokedAt() *timestamppb.Timestamp {
	if x != nil {
		return x.RevokedAt
	}
	return nil
}

type RevokeSSHCertificateResponse struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	Status        RevocationStatus       `protobuf:"varint,1,opt,name=status,proto3,enum=linkedca.RevocationStatus" json:"status,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *RevokeSSHCertificateResponse) Reset() {
	*x = RevokeSSHCertificateResponse{}
	mi := &file_linkedca_majordomo_proto_msgTypes[27]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *RevokeSSHCertificateResponse) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*RevokeSSHCertificateResponse) ProtoMessage() {}

func (x *RevokeSSHCertificateResponse) ProtoReflect() protoreflect.Message {
	mi := &file_linkedca_majordomo_proto_msgTypes[27]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use RevokeSSHCertificateResponse.ProtoReflect.Descriptor instead.
func (*RevokeSSHCertificateResponse) Descriptor() ([]byte, []int) {
	return file_linkedca_majordomo_proto_rawDescGZIP(), []int{27}
}

func (x *RevokeSSHCertificateResponse) GetStatus() RevocationStatus {
	if x != nil {
		return x.Status
	}
	return RevocationStatus_UNKNOWN
}

type GetCertificateRequest struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	Serial        string                 `protobuf:"bytes,1,opt,name=serial,proto3" json:"serial,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *GetCertificateRequest) Reset() {
	*x = GetCertificateRequest{}
	mi := &file_linkedca_majordomo_proto_msgTypes[28]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *GetCertificateRequest) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*GetCertificateRequest) ProtoMessage() {}

func (x *GetCertificateRequest) ProtoReflect() protoreflect.Message {
	mi := &file_linkedca_majordomo_proto_msgTypes[28]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use GetCertificateRequest.ProtoReflect.Descriptor instead.
func (*GetCertificateRequest) Descriptor() ([]byte, []int) {
	return file_linkedca_majordomo_proto_rawDescGZIP(), []int{28}
}

func (x *GetCertificateRequest) GetSerial() string {
	if x != nil {
		return x.Serial
	}
	return ""
}

type GetCertificateResponse struct {
	state          protoimpl.MessageState            `protogen:"open.v1"`
	PemCertificate string                            `protobuf:"bytes,1,opt,name=pem_certificate,json=pemCertificate,proto3" json:"pem_certificate,omitempty"`
	Provisioner    *ProvisionerIdentity              `protobuf:"bytes,2,opt,name=provisioner,proto3" json:"provisioner,omitempty"`
	RaProvisioner  *RegistrationAuthorityProvisioner `protobuf:"bytes,3,opt,name=ra_provisioner,json=raProvisioner,proto3" json:"ra_provisioner,omitempty"`
	unknownFields  protoimpl.UnknownFields
	sizeCache      protoimpl.SizeCache
}

func (x *GetCertificateResponse) Reset() {
	*x = GetCertificateResponse{}
	mi := &file_linkedca_majordomo_proto_msgTypes[29]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *GetCertificateResponse) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*GetCertificateResponse) ProtoMessage() {}

func (x *GetCertificateResponse) ProtoReflect() protoreflect.Message {
	mi := &file_linkedca_majordomo_proto_msgTypes[29]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use GetCertificateResponse.ProtoReflect.Descriptor instead.
func (*GetCertificateResponse) Descriptor() ([]byte, []int) {
	return file_linkedca_majordomo_proto_rawDescGZIP(), []int{29}
}

func (x *GetCertificateResponse) GetPemCertificate() string {
	if x != nil {
		return x.PemCertificate
	}
	return ""
}

func (x *GetCertificateResponse) GetProvisioner() *ProvisionerIdentity {
	if x != nil {
		return x.Provisioner
	}
	return nil
}

func (x *GetCertificateResponse) GetRaProvisioner() *RegistrationAuthorityProvisioner {
	if x != nil {
		return x.RaProvisioner
	}
	return nil
}

type GetCertificateStatusRequest struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	Serial        string                 `protobuf:"bytes,1,opt,name=serial,proto3" json:"serial,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *GetCertificateStatusRequest) Reset() {
	*x = GetCertificateStatusRequest{}
	mi := &file_linkedca_majordomo_proto_msgTypes[30]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *GetCertificateStatusRequest) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*GetCertificateStatusRequest) ProtoMessage() {}

func (x *GetCertificateStatusRequest) ProtoReflect() protoreflect.Message {
	mi := &file_linkedca_majordomo_proto_msgTypes[30]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use GetCertificateStatusRequest.ProtoReflect.Descriptor instead.
func (*GetCertificateStatusRequest) Descriptor() ([]byte, []int) {
	return file_linkedca_majordomo_proto_rawDescGZIP(), []int{30}
}

func (x *GetCertificateStatusRequest) GetSerial() string {
	if x != nil {
		return x.Serial
	}
	return ""
}

type GetCertificateStatusResponse struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	Status        RevocationStatus       `protobuf:"varint,1,opt,name=status,proto3,enum=linkedca.RevocationStatus" json:"status,omitempty"`
	Reason        string                 `protobuf:"bytes,2,opt,name=reason,proto3" json:"reason,omitempty"`
	ReasonCode    RevocationReasonCode   `protobuf:"varint,3,opt,name=reason_code,json=reasonCode,proto3,enum=linkedca.RevocationReasonCode" json:"reason_code,omitempty"`
	RevokedAt     *timestamppb.Timestamp `protobuf:"bytes,4,opt,name=revoked_at,json=revokedAt,proto3" json:"revoked_at,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *GetCertificateStatusResponse) Reset() {
	*x = GetCertificateStatusResponse{}
	mi := &file_linkedca_majordomo_proto_msgTypes[31]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *GetCertificateStatusResponse) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*GetCertificateStatusResponse) ProtoMessage() {}

func (x *GetCertificateStatusResponse) ProtoReflect() protoreflect.Message {
	mi := &file_linkedca_majordomo_proto_msgTypes[31]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use GetCertificateStatusResponse.ProtoReflect.Descriptor instead.
func (*GetCertificateStatusResponse) Descriptor() ([]byte, []int) {
	return file_linkedca_majordomo_proto_rawDescGZIP(), []int{31}
}

func (x *GetCertificateStatusResponse) GetStatus() RevocationStatus {
	if x != nil {
		return x.Status
	}
	return RevocationStatus_UNKNOWN
}

func (x *GetCertificateStatusResponse) GetReason() string {
	if x != nil {
		return x.Reason
	}
	return ""
}

func (x *GetCertificateStatusResponse) GetReasonCode() RevocationReasonCode {
	if x != nil {
		return x.ReasonCode
	}
	return RevocationReasonCode_UNSPECIFIED
}

func (x *GetCertificateStatusResponse) GetRevokedAt() *timestamppb.Timestamp {
	if x != nil {
		return x.RevokedAt
	}
	return nil
}

type GetSSHCertificateStatusRequest struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	Serial        string                 `protobuf:"bytes,1,opt,name=serial,proto3" json:"serial,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *GetSSHCertificateStatusRequest) Reset() {
	*x = GetSSHCertificateStatusRequest{}
	mi := &file_linkedca_majordomo_proto_msgTypes[32]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *GetSSHCertificateStatusRequest) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*GetSSHCertificateStatusRequest) ProtoMessage() {}

func (x *GetSSHCertificateStatusRequest) ProtoReflect() protoreflect.Message {
	mi := &file_linkedca_majordomo_proto_msgTypes[32]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use GetSSHCertificateStatusRequest.ProtoReflect.Descriptor instead.
func (*GetSSHCertificateStatusRequest) Descriptor() ([]byte, []int) {
	return file_linkedca_majordomo_proto_rawDescGZIP(), []int{32}
}

func (x *GetSSHCertificateStatusRequest) GetSerial() string {
	if x != nil {
		return x.Serial
	}
	return ""
}

type GetSSHCertificateStatusResponse struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	Status        RevocationStatus       `protobuf:"varint,1,opt,name=status,proto3,enum=linkedca.RevocationStatus" json:"status,omitempty"`
	Reason        string                 `protobuf:"bytes,2,opt,name=reason,proto3" json:"reason,omitempty"`
	ReasonCode    RevocationReasonCode   `protobuf:"varint,3,opt,name=reason_code,json=reasonCode,proto3,enum=linkedca.RevocationReasonCode" json:"reason_code,omitempty"`
	RevokedAt     *timestamppb.Timestamp `protobuf:"bytes,4,opt,name=revoked_at,json=revokedAt,proto3" json:"revoked_at,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *GetSSHCertificateStatusResponse) Reset() {
	*x = GetSSHCertificateStatusResponse{}
	mi := &file_linkedca_majordomo_proto_msgTypes[33]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *GetSSHCertificateStatusResponse) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*GetSSHCertificateStatusResponse) ProtoMessage() {}

func (x *GetSSHCertificateStatusResponse) ProtoReflect() protoreflect.Message {
	mi := &file_linkedca_majordomo_proto_msgTypes[33]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use GetSSHCertificateStatusResponse.ProtoReflect.Descriptor instead.
func (*GetSSHCertificateStatusResponse) Descriptor() ([]byte, []int) {
	return file_linkedca_majordomo_proto_rawDescGZIP(), []int{33}
}

func (x *GetSSHCertificateStatusResponse) GetStatus() RevocationStatus {
	if x != nil {
		return x.Status
	}
	return RevocationStatus_UNKNOWN
}

func (x *GetSSHCertificateStatusResponse) GetReason() string {
	if x != nil {
		return x.Reason
	}
	return ""
}

func (x *GetSSHCertificateStatusResponse) GetReasonCode() RevocationReasonCode {
	if x != nil {
		return x.ReasonCode
	}
	return RevocationReasonCode_UNSPECIFIED
}

func (x *GetSSHCertificateStatusResponse) GetRevokedAt() *timestamppb.Timestamp {
	if x != nil {
		return x.RevokedAt
	}
	return nil
}

type GetACMEAccountRequest struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// Types that are valid to be assigned to Identifier:
	//
	//	*GetACMEAccountRequest_Id
	//	*GetACMEAccountRequest_Kid
	Identifier    isGetACMEAccountRequest_Identifier `protobuf_oneof:"identifier"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *GetACMEAccountRequest) Reset() {
	*x = GetACMEAccountRequest{}
	mi := &file_linkedca_majordomo_proto_msgTypes[34]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *GetACMEAccountRequest) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*GetACMEAccountRequest) ProtoMessage() {}

func (x *GetACMEAccountRequest) ProtoReflect() protoreflect.Message {
	mi := &file_linkedca_majordomo_proto_msgTypes[34]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use GetACMEAccountRequest.ProtoReflect.Descriptor instead.
func (*GetACMEAccountRequest) Descriptor() ([]byte, []int) {
	return file_linkedca_majordomo_proto_rawDescGZIP(), []int{34}
}

func (x *GetACMEAccountRequest) GetIdentifier() isGetACMEAccountRequest_Identifier {
	if x != nil {
		return x.Identifier
	}
	return nil
}

func (x *GetACMEAccountRequest) GetId() string {
	if x != nil {
		if x, ok := x.Identifier.(*GetACMEAccountRequest_Id); ok {
			return x.Id
		}
	}
	return ""
}

func (x *GetACMEAccountRequest) GetKid() string {
	if x != nil {
		if x, ok := x.Identifier.(*GetACMEAccountRequest_Kid); ok {
			return x.Kid
		}
	}
	return ""
}

type isGetACMEAccountRequest_Identifier interface {
	isGetACMEAccountRequest_Identifier()
}

type GetACMEAccountRequest_Id struct {
	Id string `protobuf:"bytes,1,opt,name=id,proto3,oneof"`
}

type GetACMEAccountRequest_Kid struct {
	Kid string `protobuf:"bytes,2,opt,name=kid,proto3,oneof"`
}

func (*GetACMEAccountRequest_Id) isGetACMEAccountRequest_Identifier() {}

func (*GetACMEAccountRequest_Kid) isGetACMEAccountRequest_Identifier() {}

type CreateACMEAccountRequest struct {
	state                protoimpl.MessageState `protogen:"open.v1"`
	PreferredId          string                 `protobuf:"bytes,1,opt,name=preferred_id,json=preferredId,proto3" json:"preferred_id,omitempty"`
	Jwk                  []byte                 `protobuf:"bytes,2,opt,name=jwk,proto3" json:"jwk,omitempty"`
	Status               ACMEAccount_Status     `protobuf:"varint,3,opt,name=status,proto3,enum=linkedca.ACMEAccount_Status" json:"status,omitempty"`
	Contact              []string               `protobuf:"bytes,4,rep,name=contact,proto3" json:"contact,omitempty"`
	TermsOfServiceAgreed bool                   `protobuf:"varint,5,opt,name=terms_of_service_agreed,json=termsOfServiceAgreed,proto3" json:"terms_of_service_agreed,omitempty"`
	unknownFields        protoimpl.UnknownFields
	sizeCache            protoimpl.SizeCache
}

func (x *CreateACMEAccountRequest) Reset() {
	*x = CreateACMEAccountRequest{}
	mi := &file_linkedca_majordomo_proto_msgTypes[35]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *CreateACMEAccountRequest) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*CreateACMEAccountRequest) ProtoMessage() {}

func (x *CreateACMEAccountRequest) ProtoReflect() protoreflect.Message {
	mi := &file_linkedca_majordomo_proto_msgTypes[35]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use CreateACMEAccountRequest.ProtoReflect.Descriptor instead.
func (*CreateACMEAccountRequest) Descriptor() ([]byte, []int) {
	return file_linkedca_majordomo_proto_rawDescGZIP(), []int{35}
}

func (x *CreateACMEAccountRequest) GetPreferredId() string {
	if x != nil {
		return x.PreferredId
	}
	return ""
}

func (x *CreateACMEAccountRequest) GetJwk() []byte {
	if x != nil {
		return x.Jwk
	}
	return nil
}

func (x *CreateACMEAccountRequest) GetStatus() ACMEAccount_Status {
	if x != nil {
		return x.Status
	}
	return ACMEAccount_UNDEFINED
}

func (x *CreateACMEAccountRequest) GetContact() []string {
	if x != nil {
		return x.Contact
	}
	return nil
}

func (x *CreateACMEAccountRequest) GetTermsOfServiceAgreed() bool {
	if x != nil {
		return x.TermsOfServiceAgreed
	}
	return false
}

type UpdateACMEAccountRequest struct {
	state                protoimpl.MessageState `protogen:"open.v1"`
	Id                   string                 `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
	Jwk                  []byte                 `protobuf:"bytes,2,opt,name=jwk,proto3" json:"jwk,omitempty"`
	Status               ACMEAccount_Status     `protobuf:"varint,3,opt,name=status,proto3,enum=linkedca.ACMEAccount_Status" json:"status,omitempty"`
	Contact              []string               `protobuf:"bytes,4,rep,name=contact,proto3" json:"contact,omitempty"`
	TermsOfServiceAgreed bool                   `protobuf:"varint,5,opt,name=terms_of_service_agreed,json=termsOfServiceAgreed,proto3" json:"terms_of_service_agreed,omitempty"`
	unknownFields        protoimpl.UnknownFields
	sizeCache            protoimpl.SizeCache
}

func (x *UpdateACMEAccountRequest) Reset() {
	*x = UpdateACMEAccountRequest{}
	mi := &file_linkedca_majordomo_proto_msgTypes[36]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *UpdateACMEAccountRequest) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*UpdateACMEAccountRequest) ProtoMessage() {}

func (x *UpdateACMEAccountRequest) ProtoReflect() protoreflect.Message {
	mi := &file_linkedca_majordomo_proto_msgTypes[36]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use UpdateACMEAccountRequest.ProtoReflect.Descriptor instead.
func (*UpdateACMEAccountRequest) Descriptor() ([]byte, []int) {
	return file_linkedca_majordomo_proto_rawDescGZIP(), []int{36}
}

func (x *UpdateACMEAccountRequest) GetId() string {
	if x != nil {
		return x.Id
	}
	return ""
}

func (x *UpdateACMEAccountRequest) GetJwk() []byte {
	if x != nil {
		return x.Jwk
	}
	return nil
}

func (x *UpdateACMEAccountRequest) GetStatus() ACMEAccount_Status {
	if x != nil {
		return x.Status
	}
	return ACMEAccount_UNDEFINED
}

func (x *UpdateACMEAccountRequest) GetContact() []string {
	if x != nil {
		return x.Contact
	}
	return nil
}

func (x *UpdateACMEAccountRequest) GetTermsOfServiceAgreed() bool {
	if x != nil {
		return x.TermsOfServiceAgreed
	}
	return false
}

type DeleteACMEAccountRequest struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	Id            string                 `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *DeleteACMEAccountRequest) Reset() {
	*x = DeleteACMEAccountRequest{}
	mi := &file_linkedca_majordomo_proto_msgTypes[37]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *DeleteACMEAccountRequest) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*DeleteACMEAccountRequest) ProtoMessage() {}

func (x *DeleteACMEAccountRequest) ProtoReflect() protoreflect.Message {
	mi := &file_linkedca_majordomo_proto_msgTypes[37]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use DeleteACMEAccountRequest.ProtoReflect.Descriptor instead.
func (*DeleteACMEAccountRequest) Descriptor() ([]byte, []int) {
	return file_linkedca_majordomo_proto_rawDescGZIP(), []int{37}
}

func (x *DeleteACMEAccountRequest) GetId() string {
	if x != nil {
		return x.Id
	}
	return ""
}

var File_linkedca_majordomo_proto protoreflect.FileDescriptor

const file_linkedca_majordomo_proto_rawDesc = "" +
	"\n" +
	"\x18linkedca/majordomo.proto\x12\blinkedca\x1a\x14linkedca/admin.proto\x1a\x1blinkedca/provisioners.proto\x1a\x13linkedca/acme.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x7f\n" +
	"\fLoginRequest\x12!\n" +
	"\fauthority_id\x18\x01 \x01(\tR\vauthorityId\x12\x14\n" +
	"\x05token\x18\x02 \x01(\tR\x05token\x126\n" +
	"\x17pem_certificate_request\x18\x03 \x01(\tR\x15pemCertificateRequest\"l\n" +
	"\rLoginResponse\x12'\n" +
	"\x0fpem_certificate\x18\x01 \x01(\tR\x0epemCertificate\x122\n" +
	"\x15pem_certificate_chain\x18\x02 \x01(\tR\x13pemCertificateChain\"=\n" +
	"\x19GetRootCertificateRequest\x12 \n" +
	"\vfingerprint\x18\x01 \x01(\tR\vfingerprint\"E\n" +
	"\x1aGetRootCertificateResponse\x12'\n" +
	"\x0fpem_certificate\x18\x01 \x01(\tR\x0epemCertificate\"9\n" +
	"\x14ConfigurationRequest\x12!\n" +
	"\fauthority_id\x18\x01 \x01(\tR\vauthorityId\"\x83\x02\n" +
	"\x15ConfigurationResponse\x129\n" +
	"\fprovisioners\x18\x01 \x03(\v2\x15.linkedca.ProvisionerR\fprovisioners\x12'\n" +
	"\x06admins\x18\x02 \x03(\v2\x0f.linkedca.AdminR\x06admins\x12B\n" +
	"\tra_config\x18\x03 \x01(\v2%.linkedca.RegistrationAuthorityConfigR\braConfig\x12B\n" +
	"\rserver_config\x18\x04 \x01(\v2\x1d.linkedca.ServerConfigurationR\fserverConfig\"L\n" +
	"\x13ServerConfiguration\x12\x18\n" +
	"\aaddress\x18\x01 \x01(\tR\aaddress\x12\x1b\n" +
	"\tdns_names\x18\x02 \x03(\tR\bdnsNames\"\x97\x01\n" +
	"\x1bRegistrationAuthorityConfig\x12\x15\n" +
	"\x06ca_url\x18\x01 \x01(\tR\x05caUrl\x12 \n" +
	"\vfingerprint\x18\x02 \x01(\tR\vfingerprint\x12?\n" +
	"\vprovisioner\x18\x03 \x01(\v2\x1d.linkedca.ProvisionerIdentityR\vprovisioner\"\x86\x01\n" +
	" RegistrationAuthorityProvisioner\x12!\n" +
	"\fauthority_id\x18\x01 \x01(\tR\vauthorityId\x12?\n" +
	"\vprovisioner\x18\x02 \x01(\v2\x1d.linkedca.ProvisionerIdentityR\vprovisioner\"\xd3\x02\n" +
	"\x18CreateProvisionerRequest\x12.\n" +
	"\x04type\x18\x01 \x01(\x0e2\x1a.linkedca.Provisioner.TypeR\x04type\x12\x12\n" +
	"\x04name\x18\x02 \x01(\tR\x04name\x126\n" +
	"\adetails\x18\x03 \x01(\v2\x1c.linkedca.ProvisionerDetailsR\adetails\x12(\n" +
	"\x06claims\x18\x04 \x01(\v2\x10.linkedca.ClaimsR\x06claims\x127\n" +
	"\rx509_template\x18\x05 \x01(\v2\x12.linkedca.TemplateR\fx509Template\x125\n" +
	"\fssh_template\x18\x06 \x01(\v2\x12.linkedca.TemplateR\vsshTemplate\x12!\n" +
	"\fpreferred_id\x18\a \x01(\tR\vpreferredId\"'\n" +
	"\x15GetProvisionerRequest\x12\x0e\n" +
	"\x02id\x18\x01 \x01(\tR\x02id\"\x90\x02\n" +
	"\x18UpdateProvisionerRequest\x12\x0e\n" +
	"\x02id\x18\x01 \x01(\tR\x02id\x12\x12\n" +
	"\x04name\x18\x02 \x01(\tR\x04name\x126\n" +
	"\adetails\x18\x03 \x01(\v2\x1c.linkedca.ProvisionerDetailsR\adetails\x12(\n" +
	"\x06claims\x18\x04 \x01(\v2\x10.linkedca.ClaimsR\x06claims\x127\n" +
	"\rx509_template\x18\x05 \x01(\v2\x12.linkedca.TemplateR\fx509Template\x125\n" +
	"\fssh_template\x18\x06 \x01(\v2\x12.linkedca.TemplateR\vsshTemplate\"*\n" +
	"\x18DeleteProvisionerRequest\x12\x0e\n" +
	"\x02id\x18\x01 \x01(\tR\x02id\"\xa2\x01\n" +
	"\x12CreateAdminRequest\x12\x18\n" +
	"\asubject\x18\x01 \x01(\tR\asubject\x12%\n" +
	"\x0eprovisioner_id\x18\x02 \x01(\tR\rprovisionerId\x12(\n" +
	"\x04type\x18\x03 \x01(\x0e2\x14.linkedca.Admin.TypeR\x04type\x12!\n" +
	"\fpreferred_id\x18\x04 \x01(\tR\vpreferredId\"!\n" +
	"\x0fGetAdminRequest\x12\x0e\n" +
	"\x02id\x18\x01 \x01(\tR\x02id\"N\n" +
	"\x12UpdateAdminRequest\x12\x0e\n" +
	"\x02id\x18\x01 \x01(\tR\x02id\x12(\n" +
	"\x04type\x18\x02 \x01(\x0e2\x14.linkedca.Admin.TypeR\x04type\"$\n" +
	"\x12DeleteAdminRequest\x12\x0e\n" +
	"\x02id\x18\x01 \x01(\tR\x02id\"\xa2\x03\n" +
	"\x12CertificateRequest\x12'\n" +
	"\x0fpem_certificate\x18\x01 \x01(\tR\x0epemCertificate\x122\n" +
	"\x15pem_certificate_chain\x18\x02 \x01(\tR\x13pemCertificateChain\x124\n" +
	"\x16pem_parent_certificate\x18\x03 \x01(\tR\x14pemParentCertificate\x12?\n" +
	"\vprovisioner\x18\x04 \x01(\v2\x1d.linkedca.ProvisionerIdentityR\vprovisioner\x12Q\n" +
	"\x0era_provisioner\x18\x05 \x01(\v2*.linkedca.RegistrationAuthorityProvisionerR\rraProvisioner\x12\x1f\n" +
	"\vendpoint_id\x18\x06 \x01(\tR\n" +
	"endpointId\x12D\n" +
	"\x10attestation_data\x18\a \x01(\v2\x19.linkedca.AttestationDataR\x0fattestationData\"D\n" +
	"\x0fAttestationData\x121\n" +
	"\x14permanent_identifier\x18\x01 \x01(\tR\x13permanentIdentifier\"%\n" +
	"\x13CertificateResponse\x12\x0e\n" +
	"\x02id\x18\x01 \x01(\tR\x02id\"\xa9\x01\n" +
	"\x15SSHCertificateRequest\x12 \n" +
	"\vcertificate\x18\x01 \x01(\tR\vcertificate\x12-\n" +
	"\x12parent_certificate\x18\x02 \x01(\tR\x11parentCertificate\x12?\n" +
	"\vprovisioner\x18\x03 \x01(\v2\x1d.linkedca.ProvisionerIdentityR\vprovisioner\"(\n" +
	"\x16SSHCertificateResponse\x12\x0e\n" +
	"\x02id\x18\x01 \x01(\tR\x02id\"=\n" +
	"\x13OneTimeTokenRequest\x12\x10\n" +
	"\x03jti\x18\x01 \x01(\tR\x03jti\x12\x14\n" +
	"\x05token\x18\x02 \x01(\tR\x05token\"&\n" +
	"\x14OneTimeTokenResponse\x12\x0e\n" +
	"\x02id\x18\x01 \x01(\tR\x02id\"\x89\x02\n" +
	"\x18RevokeCertificateRequest\x12\x16\n" +
	"\x06serial\x18\x01 \x01(\tR\x06serial\x12'\n" +
	"\x0fpem_certificate\x18\x02 \x01(\tR\x0epemCertificate\x12\x16\n" +
	"\x06reason\x18\x03 \x01(\tR\x06reason\x12?\n" +
	"\vreason_code\x18\x04 \x01(\x0e2\x1e.linkedca.RevocationReasonCodeR\n" +
	"reasonCode\x12\x18\n" +
	"\apassive\x18\x05 \x01(\bR\apassive\x129\n" +
	"\n" +
	"revoked_at\x18\x06 \x01(\v2\x1a.google.protobuf.TimestampR\trevokedAt\"O\n" +
	"\x19RevokeCertificateResponse\x122\n" +
	"\x06status\x18\x01 \x01(\x0e2\x1a.linkedca.RevocationStatusR\x06status\"\x85\x02\n" +
	"\x1bRevokeSSHCertificateRequest\x12\x16\n" +
	"\x06serial\x18\x01 \x01(\tR\x06serial\x12 \n" +
	"\vcertificate\x18\x02 \x01(\tR\vcertificate\x12\x16\n" +
	"\x06reason\x18\x03 \x01(\tR\x06reason\x12?\n" +
	"\vreason_code\x18\x04 \x01(\x0e2\x1e.linkedca.RevocationReasonCodeR\n" +
	"reasonCode\x12\x18\n" +
	"\apassive\x18\x05 \x01(\bR\apassive\x129\n" +
	"\n" +
	"revoked_at\x18\x06 \x01(\v2\x1a.google.protobuf.TimestampR\trevokedAt\"R\n" +
	"\x1cRevokeSSHCertificateResponse\x122\n" +
	"\x06status\x18\x01 \x01(\x0e2\x1a.linkedca.RevocationStatusR\x06status\"/\n" +
	"\x15GetCertificateRequest\x12\x16\n" +
	"\x06serial\x18\x01 \x01(\tR\x06serial\"\xd5\x01\n" +
	"\x16GetCertificateResponse\x12'\n" +
	"\x0fpem_certificate\x18\x01 \x01(\tR\x0epemCertificate\x12?\n" +
	"\vprovisioner\x18\x02 \x01(\v2\x1d.linkedca.ProvisionerIdentityR\vprovisioner\x12Q\n" +
	"\x0era_provisioner\x18\x03 \x01(\v2*.linkedca.RegistrationAuthorityProvisionerR\rraProvisioner\"5\n" +
	"\x1bGetCertificateStatusRequest\x12\x16\n" +
	"\x06serial\x18\x01 \x01(\tR\x06serial\"\xe6\x01\n" +
	"\x1cGetCertificateStatusResponse\x122\n" +
	"\x06status\x18\x01 \x01(\x0e2\x1a.linkedca.RevocationStatusR\x06status\x12\x16\n" +
	"\x06reason\x18\x02 \x01(\tR\x06reason\x12?\n" +
	"\vreason_code\x18\x03 \x01(\x0e2\x1e.linkedca.RevocationReasonCodeR\n" +
	"reasonCode\x129\n" +
	"\n" +
	"revoked_at\x18\x04 \x01(\v2\x1a.google.protobuf.TimestampR\trevokedAt\"8\n" +
	"\x1eGetSSHCertificateStatusRequest\x12\x16\n" +
	"\x06serial\x18\x01 \x01(\tR\x06serial\"\xe9\x01\n" +
	"\x1fGetSSHCertificateStatusResponse\x122\n" +
	"\x06status\x18\x01 \x01(\x0e2\x1a.linkedca.RevocationStatusR\x06status\x12\x16\n" +
	"\x06reason\x18\x02 \x01(\tR\x06reason\x12?\n" +
	"\vreason_code\x18\x03 \x01(\x0e2\x1e.linkedca.RevocationReasonCodeR\n" +
	"reasonCode\x129\n" +
	"\n" +
	"revoked_at\x18\x04 \x01(\v2\x1a.google.protobuf.TimestampR\trevokedAt\"K\n" +
	"\x15GetACMEAccountRequest\x12\x10\n" +
	"\x02id\x18\x01 \x01(\tH\x00R\x02id\x12\x12\n" +
	"\x03kid\x18\x02 \x01(\tH\x00R\x03kidB\f\n" +
	"\n" +
	"identifier\"\xd6\x01\n" +
	"\x18CreateACMEAccountRequest\x12!\n" +
	"\fpreferred_id\x18\x01 \x01(\tR\vpreferredId\x12\x10\n" +
	"\x03jwk\x18\x02 \x01(\fR\x03jwk\x124\n" +
	"\x06status\x18\x03 \x01(\x0e2\x1c.linkedca.ACMEAccount.StatusR\x06status\x12\x18\n" +
	"\acontact\x18\x04 \x03(\tR\acontact\x125\n" +
	"\x17terms_of_service_agreed\x18\x05 \x01(\bR\x14termsOfServiceAgreed\"\xc3\x01\n" +
	"\x18UpdateACMEAccountRequest\x12\x0e\n" +
	"\x02id\x18\x01 \x01(\tR\x02id\x12\x10\n" +
	"\x03jwk\x18\x02 \x01(\fR\x03jwk\x124\n" +
	"\x06status\x18\x03 \x01(\x0e2\x1c.linkedca.ACMEAccount.StatusR\x06status\x12\x18\n" +
	"\acontact\x18\x04 \x03(\tR\acontact\x125\n" +
	"\x17terms_of_service_agreed\x18\x05 \x01(\bR\x14termsOfServiceAgreed\"*\n" +
	"\x18DeleteACMEAccountRequest\x12\x0e\n" +
	"\x02id\x18\x01 \x01(\tR\x02id*B\n" +
	"\x10RevocationStatus\x12\v\n" +
	"\aUNKNOWN\x10\x00\x12\n" +
	"\n" +
	"\x06ACTIVE\x10\x01\x12\v\n" +
	"\aREVOKED\x10\x02\x12\b\n" +
	"\x04HOLD\x10\x03*\xea\x01\n" +
	"\x14RevocationReasonCode\x12\x0f\n" +
	"\vUNSPECIFIED\x10\x00\x12\x12\n" +
	"\x0eKEY_COMPROMISE\x10\x01\x12\x11\n" +
	"\rCA_COMPROMISE\x10\x02\x12\x17\n" +
	"\x13AFFILIATION_CHANGED\x10\x03\x12\x0e\n" +
	"\n" +
	"SUPERSEDED\x10\x04\x12\x1a\n" +
	"\x16CESSATION_OF_OPERATION\x10\x05\x12\x14\n" +
	"\x10CERTIFICATE_HOLD\x10\x06\x12\x13\n" +
	"\x0fREMOVE_FROM_CRL\x10\b\x12\x17\n" +
	"\x13PRIVILEGE_WITHDRAWN\x10\t\x12\x11\n" +
	"\rAA_COMPROMISE\x10\n" +
	"2\xce\x0e\n" +
	"\tMajordomo\x128\n" +
	"\x05Login\x12\x16.linkedca.LoginRequest\x1a\x17.linkedca.LoginResponse\x12_\n" +
	"\x12GetRootCertificate\x12#.linkedca.GetRootCertificateRequest\x1a$.linkedca.GetRootCertificateResponse\x12S\n" +
	"\x10GetConfiguration\x12\x1e.linkedca.ConfigurationRequest\x1a\x1f.linkedca.ConfigurationResponse\x12N\n" +
	"\x11CreateProvisioner\x12\".linkedca.CreateProvisionerRequest\x1a\x15.linkedca.Provisioner\x12H\n" +
	"\x0eGetProvisioner\x12\x1f.linkedca.GetProvisionerRequest\x1a\x15.linkedca.Provisioner\x12N\n" +
	"\x11UpdateProvisioner\x12\".linkedca.UpdateProvisionerRequest\x1a\x15.linkedca.Provisioner\x12N\n" +
	"\x11DeleteProvisioner\x12\".linkedca.DeleteProvisionerRequest\x1a\x15.linkedca.Provisioner\x12<\n" +
	"\vCreateAdmin\x12\x1c.linkedca.CreateAdminRequest\x1a\x0f.linkedca.Admin\x126\n" +
	"\bGetAdmin\x12\x19.linkedca.GetAdminRequest\x1a\x0f.linkedca.Admin\x12<\n" +
	"\vUpdateAdmin\x12\x1c.linkedca.UpdateAdminRequest\x1a\x0f.linkedca.Admin\x12<\n" +
	"\vDeleteAdmin\x12\x1c.linkedca.DeleteAdminRequest\x1a\x0f.linkedca.Admin\x12N\n" +
	"\x0fPostCertificate\x12\x1c.linkedca.CertificateRequest\x1a\x1d.linkedca.CertificateResponse\x12W\n" +
	"\x12PostSSHCertificate\x12\x1f.linkedca.SSHCertificateRequest\x1a .linkedca.SSHCertificateResponse\x12Q\n" +
	"\x10PostOneTimeToken\x12\x1d.linkedca.OneTimeTokenRequest\x1a\x1e.linkedca.OneTimeTokenResponse\x12\\\n" +
	"\x11RevokeCertificate\x12\".linkedca.RevokeCertificateRequest\x1a#.linkedca.RevokeCertificateResponse\x12e\n" +
	"\x14RevokeSSHCertificate\x12%.linkedca.RevokeSSHCertificateRequest\x1a&.linkedca.RevokeSSHCertificateResponse\x12S\n" +
	"\x0eGetCertificate\x12\x1f.linkedca.GetCertificateRequest\x1a .linkedca.GetCertificateResponse\x12e\n" +
	"\x14GetCertificateStatus\x12%.linkedca.GetCertificateStatusRequest\x1a&.linkedca.GetCertificateStatusResponse\x12n\n" +
	"\x17GetSSHCertificateStatus\x12(.linkedca.GetSSHCertificateStatusRequest\x1a).linkedca.GetSSHCertificateStatusResponse\x12H\n" +
	"\x0eGetACMEAccount\x12\x1f.linkedca.GetACMEAccountRequest\x1a\x15.linkedca.ACMEAccount\x12N\n" +
	"\x11CreateACMEAccount\x12\".linkedca.CreateACMEAccountRequest\x1a\x15.linkedca.ACMEAccount\x12N\n" +
	"\x11UpdateACMEAccount\x12\".linkedca.UpdateACMEAccountRequest\x1a\x15.linkedca.ACMEAccount\x12N\n" +
	"\x11DeleteACMEAccount\x12\".linkedca.DeleteACMEAccountRequest\x1a\x15.linkedca.ACMEAccountB\x1fZ\x1dgithub.com/smallstep/linkedcab\x06proto3"

var (
	file_linkedca_majordomo_proto_rawDescOnce sync.Once
	file_linkedca_majordomo_proto_rawDescData []byte
)

func file_linkedca_majordomo_proto_rawDescGZIP() []byte {
	file_linkedca_majordomo_proto_rawDescOnce.Do(func() {
		file_linkedca_majordomo_proto_rawDescData = protoimpl.X.CompressGZIP(unsafe.Slice(unsafe.StringData(file_linkedca_majordomo_proto_rawDesc), len(file_linkedca_majordomo_proto_rawDesc)))
	})
	return file_linkedca_majordomo_proto_rawDescData
}

var file_linkedca_majordomo_proto_enumTypes = make([]protoimpl.EnumInfo, 2)
var file_linkedca_majordomo_proto_msgTypes = make([]protoimpl.MessageInfo, 38)
var file_linkedca_majordomo_proto_goTypes = []any{
	(RevocationStatus)(0),                    // 0: linkedca.RevocationStatus
	(RevocationReasonCode)(0),                // 1: linkedca.RevocationReasonCode
	(*LoginRequest)(nil),                     // 2: linkedca.LoginRequest
	(*LoginResponse)(nil),                    // 3: linkedca.LoginResponse
	(*GetRootCertificateRequest)(nil),        // 4: linkedca.GetRootCertificateRequest
	(*GetRootCertificateResponse)(nil),       // 5: linkedca.GetRootCertificateResponse
	(*ConfigurationRequest)(nil),             // 6: linkedca.ConfigurationRequest
	(*ConfigurationResponse)(nil),            // 7: linkedca.ConfigurationResponse
	(*ServerConfiguration)(nil),              // 8: linkedca.ServerConfiguration
	(*RegistrationAuthorityConfig)(nil),      // 9: linkedca.RegistrationAuthorityConfig
	(*RegistrationAuthorityProvisioner)(nil), // 10: linkedca.RegistrationAuthorityProvisioner
	(*CreateProvisionerRequest)(nil),         // 11: linkedca.CreateProvisionerRequest
	(*GetProvisionerRequest)(nil),            // 12: linkedca.GetProvisionerRequest
	(*UpdateProvisionerRequest)(nil),         // 13: linkedca.UpdateProvisionerRequest
	(*DeleteProvisionerRequest)(nil),         // 14: linkedca.DeleteProvisionerRequest
	(*CreateAdminRequest)(nil),               // 15: linkedca.CreateAdminRequest
	(*GetAdminRequest)(nil),                  // 16: linkedca.GetAdminRequest
	(*UpdateAdminRequest)(nil),               // 17: linkedca.UpdateAdminRequest
	(*DeleteAdminRequest)(nil),               // 18: linkedca.DeleteAdminRequest
	(*CertificateRequest)(nil),               // 19: linkedca.CertificateRequest
	(*AttestationData)(nil),                  // 20: linkedca.AttestationData
	(*CertificateResponse)(nil),              // 21: linkedca.CertificateResponse
	(*SSHCertificateRequest)(nil),            // 22: linkedca.SSHCertificateRequest
	(*SSHCertificateResponse)(nil),           // 23: linkedca.SSHCertificateResponse
	(*OneTimeTokenRequest)(nil),              // 24: linkedca.OneTimeTokenRequest
	(*OneTimeTokenResponse)(nil),             // 25: linkedca.OneTimeTokenResponse
	(*RevokeCertificateRequest)(nil),         // 26: linkedca.RevokeCertificateRequest
	(*RevokeCertificateResponse)(nil),        // 27: linkedca.RevokeCertificateResponse
	(*RevokeSSHCertificateRequest)(nil),      // 28: linkedca.RevokeSSHCertificateRequest
	(*RevokeSSHCertificateResponse)(nil),     // 29: linkedca.RevokeSSHCertificateResponse
	(*GetCertificateRequest)(nil),            // 30: linkedca.GetCertificateRequest
	(*GetCertificateResponse)(nil),           // 31: linkedca.GetCertificateResponse
	(*GetCertificateStatusRequest)(nil),      // 32: linkedca.GetCertificateStatusRequest
	(*GetCertificateStatusResponse)(nil),     // 33: linkedca.GetCertificateStatusResponse
	(*GetSSHCertificateStatusRequest)(nil),   // 34: linkedca.GetSSHCertificateStatusRequest
	(*GetSSHCertificateStatusResponse)(nil),  // 35: linkedca.GetSSHCertificateStatusResponse
	(*GetACMEAccountRequest)(nil),            // 36: linkedca.GetACMEAccountRequest
	(*CreateACMEAccountRequest)(nil),         // 37: linkedca.CreateACMEAccountRequest
	(*UpdateACMEAccountRequest)(nil),         // 38: linkedca.UpdateACMEAccountRequest
	(*DeleteACMEAccountRequest)(nil),         // 39: linkedca.DeleteACMEAccountRequest
	(*Provisioner)(nil),                      // 40: linkedca.Provisioner
	(*Admin)(nil),                            // 41: linkedca.Admin
	(*ProvisionerIdentity)(nil),              // 42: linkedca.ProvisionerIdentity
	(Provisioner_Type)(0),                    // 43: linkedca.Provisioner.Type
	(*ProvisionerDetails)(nil),               // 44: linkedca.ProvisionerDetails
	(*Claims)(nil),                           // 45: linkedca.Claims
	(*Template)(nil),                         // 46: linkedca.Template
	(Admin_Type)(0),                          // 47: linkedca.Admin.Type
	(*timestamppb.Timestamp)(nil),            // 48: google.protobuf.Timestamp
	(ACMEAccount_Status)(0),                  // 49: linkedca.ACMEAccount.Status
	(*ACMEAccount)(nil),                      // 50: linkedca.ACMEAccount
}
var file_linkedca_majordomo_proto_depIdxs = []int32{
	40, // 0: linkedca.ConfigurationResponse.provisioners:type_name -> linkedca.Provisioner
	41, // 1: linkedca.ConfigurationResponse.admins:type_name -> linkedca.Admin
	9,  // 2: linkedca.ConfigurationResponse.ra_config:type_name -> linkedca.RegistrationAuthorityConfig
	8,  // 3: linkedca.ConfigurationResponse.server_config:type_name -> linkedca.ServerConfiguration
	42, // 4: linkedca.RegistrationAuthorityConfig.provisioner:type_name -> linkedca.ProvisionerIdentity
	42, // 5: linkedca.RegistrationAuthorityProvisioner.provisioner:type_name -> linkedca.ProvisionerIdentity
	43, // 6: linkedca.CreateProvisionerRequest.type:type_name -> linkedca.Provisioner.Type
	44, // 7: linkedca.CreateProvisionerRequest.details:type_name -> linkedca.ProvisionerDetails
	45, // 8: linkedca.CreateProvisionerRequest.claims:type_name -> linkedca.Claims
	46, // 9: linkedca.CreateProvisionerRequest.x509_template:type_name -> linkedca.Template
	46, // 10: linkedca.CreateProvisionerRequest.ssh_template:type_name -> linkedca.Template
	44, // 11: linkedca.UpdateProvisionerRequest.details:type_name -> linkedca.ProvisionerDetails
	45, // 12: linkedca.UpdateProvisionerRequest.claims:type_name -> linkedca.Claims
	46, // 13: linkedca.UpdateProvisionerRequest.x509_template:type_name -> linkedca.Template
	46, // 14: linkedca.UpdateProvisionerRequest.ssh_template:type_name -> linkedca.Template
	47, // 15: linkedca.CreateAdminRequest.type:type_name -> linkedca.Admin.Type
	47, // 16: linkedca.UpdateAdminRequest.type:type_name -> linkedca.Admin.Type
	42, // 17: linkedca.CertificateRequest.provisioner:type_name -> linkedca.ProvisionerIdentity
	10, // 18: linkedca.CertificateRequest.ra_provisioner:type_name -> linkedca.RegistrationAuthorityProvisioner
	20, // 19: linkedca.CertificateRequest.attestation_data:type_name -> linkedca.AttestationData
	42, // 20: linkedca.SSHCertificateRequest.provisioner:type_name -> linkedca.ProvisionerIdentity
	1,  // 21: linkedca.RevokeCertificateRequest.reason_code:type_name -> linkedca.RevocationReasonCode
	48, // 22: linkedca.RevokeCertificateRequest.revoked_at:type_name -> google.protobuf.Timestamp
	0,  // 23: linkedca.RevokeCertificateResponse.status:type_name -> linkedca.RevocationStatus
	1,  // 24: linkedca.RevokeSSHCertificateRequest.reason_code:type_name -> linkedca.RevocationReasonCode
	48, // 25: linkedca.RevokeSSHCertificateRequest.revoked_at:type_name -> google.protobuf.Timestamp
	0,  // 26: linkedca.RevokeSSHCertificateResponse.status:type_name -> linkedca.RevocationStatus
	42, // 27: linkedca.GetCertificateResponse.provisioner:type_name -> linkedca.ProvisionerIdentity
	10, // 28: linkedca.GetCertificateResponse.ra_provisioner:type_name -> linkedca.RegistrationAuthorityProvisioner
	0,  // 29: linkedca.GetCertificateStatusResponse.status:type_name -> linkedca.RevocationStatus
	1,  // 30: linkedca.GetCertificateStatusResponse.reason_code:type_name -> linkedca.RevocationReasonCode
	48, // 31: linkedca.GetCertificateStatusResponse.revoked_at:type_name -> google.protobuf.Timestamp
	0,  // 32: linkedca.GetSSHCertificateStatusResponse.status:type_name -> linkedca.RevocationStatus
	1,  // 33: linkedca.GetSSHCertificateStatusResponse.reason_code:type_name -> linkedca.RevocationReasonCode
	48, // 34: linkedca.GetSSHCertificateStatusResponse.revoked_at:type_name -> google.protobuf.Timestamp
	49, // 35: linkedca.CreateACMEAccountRequest.status:type_name -> linkedca.ACMEAccount.Status
	49, // 36: linkedca.UpdateACMEAccountRequest.status:type_name -> linkedca.ACMEAccount.Status
	2,  // 37: linkedca.Majordomo.Login:input_type -> linkedca.LoginRequest
	4,  // 38: linkedca.Majordomo.GetRootCertificate:input_type -> linkedca.GetRootCertificateRequest
	6,  // 39: linkedca.Majordomo.GetConfiguration:input_type -> linkedca.ConfigurationRequest
	11, // 40: linkedca.Majordomo.CreateProvisioner:input_type -> linkedca.CreateProvisionerRequest
	12, // 41: linkedca.Majordomo.GetProvisioner:input_type -> linkedca.GetProvisionerRequest
	13, // 42: linkedca.Majordomo.UpdateProvisioner:input_type -> linkedca.UpdateProvisionerRequest
	14, // 43: linkedca.Majordomo.DeleteProvisioner:input_type -> linkedca.DeleteProvisionerRequest
	15, // 44: linkedca.Majordomo.CreateAdmin:input_type -> linkedca.CreateAdminRequest
	16, // 45: linkedca.Majordomo.GetAdmin:input_type -> linkedca.GetAdminRequest
	17, // 46: linkedca.Majordomo.UpdateAdmin:input_type -> linkedca.UpdateAdminRequest
	18, // 47: linkedca.Majordomo.DeleteAdmin:input_type -> linkedca.DeleteAdminRequest
	19, // 48: linkedca.Majordomo.PostCertificate:input_type -> linkedca.CertificateRequest
	22, // 49: linkedca.Majordomo.PostSSHCertificate:input_type -> linkedca.SSHCertificateRequest
	24, // 50: linkedca.Majordomo.PostOneTimeToken:input_type -> linkedca.OneTimeTokenRequest
	26, // 51: linkedca.Majordomo.RevokeCertificate:input_type -> linkedca.RevokeCertificateRequest
	28, // 52: linkedca.Majordomo.RevokeSSHCertificate:input_type -> linkedca.RevokeSSHCertificateRequest
	30, // 53: linkedca.Majordomo.GetCertificate:input_type -> linkedca.GetCertificateRequest
	32, // 54: linkedca.Majordomo.GetCertificateStatus:input_type -> linkedca.GetCertificateStatusRequest
	34, // 55: linkedca.Majordomo.GetSSHCertificateStatus:input_type -> linkedca.GetSSHCertificateStatusRequest
	36, // 56: linkedca.Majordomo.GetACMEAccount:input_type -> linkedca.GetACMEAccountRequest
	37, // 57: linkedca.Majordomo.CreateACMEAccount:input_type -> linkedca.CreateACMEAccountRequest
	38, // 58: linkedca.Majordomo.UpdateACMEAccount:input_type -> linkedca.UpdateACMEAccountRequest
	39, // 59: linkedca.Majordomo.DeleteACMEAccount:input_type -> linkedca.DeleteACMEAccountRequest
	3,  // 60: linkedca.Majordomo.Login:output_type -> linkedca.LoginResponse
	5,  // 61: linkedca.Majordomo.GetRootCertificate:output_type -> linkedca.GetRootCertificateResponse
	7,  // 62: linkedca.Majordomo.GetConfiguration:output_type -> linkedca.ConfigurationResponse
	40, // 63: linkedca.Majordomo.CreateProvisioner:output_type -> linkedca.Provisioner
	40, // 64: linkedca.Majordomo.GetProvisioner:output_type -> linkedca.Provisioner
	40, // 65: linkedca.Majordomo.UpdateProvisioner:output_type -> linkedca.Provisioner
	40, // 66: linkedca.Majordomo.DeleteProvisioner:output_type -> linkedca.Provisioner
	41, // 67: linkedca.Majordomo.CreateAdmin:output_type -> linkedca.Admin
	41, // 68: linkedca.Majordomo.GetAdmin:output_type -> linkedca.Admin
	41, // 69: linkedca.Majordomo.UpdateAdmin:output_type -> linkedca.Admin
	41, // 70: linkedca.Majordomo.DeleteAdmin:output_type -> linkedca.Admin
	21, // 71: linkedca.Majordomo.PostCertificate:output_type -> linkedca.CertificateResponse
	23, // 72: linkedca.Majordomo.PostSSHCertificate:output_type -> linkedca.SSHCertificateResponse
	25, // 73: linkedca.Majordomo.PostOneTimeToken:output_type -> linkedca.OneTimeTokenResponse
	27, // 74: linkedca.Majordomo.RevokeCertificate:output_type -> linkedca.RevokeCertificateResponse
	29, // 75: linkedca.Majordomo.RevokeSSHCertificate:output_type -> linkedca.RevokeSSHCertificateResponse
	31, // 76: linkedca.Majordomo.GetCertificate:output_type -> linkedca.GetCertificateResponse
	33, // 77: linkedca.Majordomo.GetCertificateStatus:output_type -> linkedca.GetCertificateStatusResponse
	35, // 78: linkedca.Majordomo.GetSSHCertificateStatus:output_type -> linkedca.GetSSHCertificateStatusResponse
	50, // 79: linkedca.Majordomo.GetACMEAccount:output_type -> linkedca.ACMEAccount
	50, // 80: linkedca.Majordomo.CreateACMEAccount:output_type -> linkedca.ACMEAccount
	50, // 81: linkedca.Majordomo.UpdateACMEAccount:output_type -> linkedca.ACMEAccount
	50, // 82: linkedca.Majordomo.DeleteACMEAccount:output_type -> linkedca.ACMEAccount
	60, // [60:83] is the sub-list for method output_type
	37, // [37:60] is the sub-list for method input_type
	37, // [37:37] is the sub-list for extension type_name
	37, // [37:37] is the sub-list for extension extendee
	0,  // [0:37] is the sub-list for field type_name
}

func init() { file_linkedca_majordomo_proto_init() }
func file_linkedca_majordomo_proto_init() {
	if File_linkedca_majordomo_proto != nil {
		return
	}
	file_linkedca_admin_proto_init()
	file_linkedca_provisioners_proto_init()
	file_linkedca_acme_proto_init()
	file_linkedca_majordomo_proto_msgTypes[34].OneofWrappers = []any{
		(*GetACMEAccountRequest_Id)(nil),
		(*GetACMEAccountRequest_Kid)(nil),
	}
	type x struct{}
	out := protoimpl.TypeBuilder{
		File: protoimpl.DescBuilder{
			GoPackagePath: reflect.TypeOf(x{}).PkgPath(),
			RawDescriptor: unsafe.Slice(unsafe.StringData(file_linkedca_majordomo_proto_rawDesc), len(file_linkedca_majordomo_proto_rawDesc)),
			NumEnums:      2,
			NumMessages:   38,
			NumExtensions: 0,
			NumServices:   1,
		},
		GoTypes:           file_linkedca_majordomo_proto_goTypes,
		DependencyIndexes: file_linkedca_majordomo_proto_depIdxs,
		EnumInfos:         file_linkedca_majordomo_proto_enumTypes,
		MessageInfos:      file_linkedca_majordomo_proto_msgTypes,
	}.Build()
	File_linkedca_majordomo_proto = out.File
	file_linkedca_majordomo_proto_goTypes = nil
	file_linkedca_majordomo_proto_depIdxs = nil
}
