// Code generated by protoc-gen-go. DO NOT EDIT.
// versions:
// 	protoc-gen-go v1.36.9
// 	protoc        v6.32.1
// source: linkedca/eab.proto

package linkedca

import (
	protoreflect "google.golang.org/protobuf/reflect/protoreflect"
	protoimpl "google.golang.org/protobuf/runtime/protoimpl"
	timestamppb "google.golang.org/protobuf/types/known/timestamppb"
	reflect "reflect"
	sync "sync"
	unsafe "unsafe"
)

const (
	// Verify that this generated code is sufficiently up-to-date.
	_ = protoimpl.EnforceVersion(20 - protoimpl.MinVersion)
	// Verify that runtime/protoimpl is sufficiently up-to-date.
	_ = protoimpl.EnforceVersion(protoimpl.MaxVersion - 20)
)

type EABKey struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	Id            string                 `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`                                // the KeyID
	HmacKey       []byte                 `protobuf:"bytes,2,opt,name=hmac_key,json=hmacKey,proto3" json:"hmac_key,omitempty"`       // the key bytes
	Provisioner   string                 `protobuf:"bytes,3,opt,name=provisioner,proto3" json:"provisioner,omitempty"`              // the provisioner for which to create the key
	Reference     string                 `protobuf:"bytes,4,opt,name=reference,proto3" json:"reference,omitempty"`                  // name/reference to the key; can be linked to external system
	Account       string                 `protobuf:"bytes,5,opt,name=account,proto3" json:"account,omitempty"`                      // account the key is bound to
	CreatedAt     *timestamppb.Timestamp `protobuf:"bytes,6,opt,name=created_at,json=createdAt,proto3" json:"created_at,omitempty"` // time the key was created_at
	BoundAt       *timestamppb.Timestamp `protobuf:"bytes,7,opt,name=bound_at,json=boundAt,proto3" json:"bound_at,omitempty"`       // time the key was bound to an account
	Policy        *Policy                `protobuf:"bytes,8,opt,name=policy,proto3" json:"policy,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *EABKey) Reset() {
	*x = EABKey{}
	mi := &file_linkedca_eab_proto_msgTypes[0]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *EABKey) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*EABKey) ProtoMessage() {}

func (x *EABKey) ProtoReflect() protoreflect.Message {
	mi := &file_linkedca_eab_proto_msgTypes[0]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use EABKey.ProtoReflect.Descriptor instead.
func (*EABKey) Descriptor() ([]byte, []int) {
	return file_linkedca_eab_proto_rawDescGZIP(), []int{0}
}

func (x *EABKey) GetId() string {
	if x != nil {
		return x.Id
	}
	return ""
}

func (x *EABKey) GetHmacKey() []byte {
	if x != nil {
		return x.HmacKey
	}
	return nil
}

func (x *EABKey) GetProvisioner() string {
	if x != nil {
		return x.Provisioner
	}
	return ""
}

func (x *EABKey) GetReference() string {
	if x != nil {
		return x.Reference
	}
	return ""
}

func (x *EABKey) GetAccount() string {
	if x != nil {
		return x.Account
	}
	return ""
}

func (x *EABKey) GetCreatedAt() *timestamppb.Timestamp {
	if x != nil {
		return x.CreatedAt
	}
	return nil
}

func (x *EABKey) GetBoundAt() *timestamppb.Timestamp {
	if x != nil {
		return x.BoundAt
	}
	return nil
}

func (x *EABKey) GetPolicy() *Policy {
	if x != nil {
		return x.Policy
	}
	return nil
}

var File_linkedca_eab_proto protoreflect.FileDescriptor

const file_linkedca_eab_proto_rawDesc = "" +
	"\n" +
	"\x12linkedca/eab.proto\x12\blinkedca\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x15linkedca/policy.proto\"\xa9\x02\n" +
	"\x06EABKey\x12\x0e\n" +
	"\x02id\x18\x01 \x01(\tR\x02id\x12\x19\n" +
	"\bhmac_key\x18\x02 \x01(\fR\ahmacKey\x12 \n" +
	"\vprovisioner\x18\x03 \x01(\tR\vprovisioner\x12\x1c\n" +
	"\treference\x18\x04 \x01(\tR\treference\x12\x18\n" +
	"\aaccount\x18\x05 \x01(\tR\aaccount\x129\n" +
	"\n" +
	"created_at\x18\x06 \x01(\v2\x1a.google.protobuf.TimestampR\tcreatedAt\x125\n" +
	"\bbound_at\x18\a \x01(\v2\x1a.google.protobuf.TimestampR\aboundAt\x12(\n" +
	"\x06policy\x18\b \x01(\v2\x10.linkedca.PolicyR\x06policyB\x1fZ\x1dgithub.com/smallstep/linkedcab\x06proto3"

var (
	file_linkedca_eab_proto_rawDescOnce sync.Once
	file_linkedca_eab_proto_rawDescData []byte
)

func file_linkedca_eab_proto_rawDescGZIP() []byte {
	file_linkedca_eab_proto_rawDescOnce.Do(func() {
		file_linkedca_eab_proto_rawDescData = protoimpl.X.CompressGZIP(unsafe.Slice(unsafe.StringData(file_linkedca_eab_proto_rawDesc), len(file_linkedca_eab_proto_rawDesc)))
	})
	return file_linkedca_eab_proto_rawDescData
}

var file_linkedca_eab_proto_msgTypes = make([]protoimpl.MessageInfo, 1)
var file_linkedca_eab_proto_goTypes = []any{
	(*EABKey)(nil),                // 0: linkedca.EABKey
	(*timestamppb.Timestamp)(nil), // 1: google.protobuf.Timestamp
	(*Policy)(nil),                // 2: linkedca.Policy
}
var file_linkedca_eab_proto_depIdxs = []int32{
	1, // 0: linkedca.EABKey.created_at:type_name -> google.protobuf.Timestamp
	1, // 1: linkedca.EABKey.bound_at:type_name -> google.protobuf.Timestamp
	2, // 2: linkedca.EABKey.policy:type_name -> linkedca.Policy
	3, // [3:3] is the sub-list for method output_type
	3, // [3:3] is the sub-list for method input_type
	3, // [3:3] is the sub-list for extension type_name
	3, // [3:3] is the sub-list for extension extendee
	0, // [0:3] is the sub-list for field type_name
}

func init() { file_linkedca_eab_proto_init() }
func file_linkedca_eab_proto_init() {
	if File_linkedca_eab_proto != nil {
		return
	}
	file_linkedca_policy_proto_init()
	type x struct{}
	out := protoimpl.TypeBuilder{
		File: protoimpl.DescBuilder{
			GoPackagePath: reflect.TypeOf(x{}).PkgPath(),
			RawDescriptor: unsafe.Slice(unsafe.StringData(file_linkedca_eab_proto_rawDesc), len(file_linkedca_eab_proto_rawDesc)),
			NumEnums:      0,
			NumMessages:   1,
			NumExtensions: 0,
			NumServices:   0,
		},
		GoTypes:           file_linkedca_eab_proto_goTypes,
		DependencyIndexes: file_linkedca_eab_proto_depIdxs,
		MessageInfos:      file_linkedca_eab_proto_msgTypes,
	}.Build()
	File_linkedca_eab_proto = out.File
	file_linkedca_eab_proto_goTypes = nil
	file_linkedca_eab_proto_depIdxs = nil
}
