// Code generated by protoc-gen-go. DO NOT EDIT.
// versions:
// 	protoc-gen-go v1.36.9
// 	protoc        v6.32.1
// source: linkedca/acme.proto

package linkedca

import (
	protoreflect "google.golang.org/protobuf/reflect/protoreflect"
	protoimpl "google.golang.org/protobuf/runtime/protoimpl"
	timestamppb "google.golang.org/protobuf/types/known/timestamppb"
	reflect "reflect"
	sync "sync"
	unsafe "unsafe"
)

const (
	// Verify that this generated code is sufficiently up-to-date.
	_ = protoimpl.EnforceVersion(20 - protoimpl.MinVersion)
	// Verify that runtime/protoimpl is sufficiently up-to-date.
	_ = protoimpl.EnforceVersion(protoimpl.MaxVersion - 20)
)

type ACMEAccount_Status int32

const (
	ACMEAccount_UNDEFINED   ACMEAccount_Status = 0
	ACMEAccount_VALID       ACMEAccount_Status = 1
	ACMEAccount_DEACTIVATED ACMEAccount_Status = 2
	ACMEAccount_REVOKED     ACMEAccount_Status = 3
)

// Enum value maps for ACMEAccount_Status.
var (
	ACMEAccount_Status_name = map[int32]string{
		0: "UNDEFINED",
		1: "VALID",
		2: "DEACTIVATED",
		3: "REVOKED",
	}
	ACMEAccount_Status_value = map[string]int32{
		"UNDEFINED":   0,
		"VALID":       1,
		"DEACTIVATED": 2,
		"REVOKED":     3,
	}
)

func (x ACMEAccount_Status) Enum() *ACMEAccount_Status {
	p := new(ACMEAccount_Status)
	*p = x
	return p
}

func (x ACMEAccount_Status) String() string {
	return protoimpl.X.EnumStringOf(x.Descriptor(), protoreflect.EnumNumber(x))
}

func (ACMEAccount_Status) Descriptor() protoreflect.EnumDescriptor {
	return file_linkedca_acme_proto_enumTypes[0].Descriptor()
}

func (ACMEAccount_Status) Type() protoreflect.EnumType {
	return &file_linkedca_acme_proto_enumTypes[0]
}

func (x ACMEAccount_Status) Number() protoreflect.EnumNumber {
	return protoreflect.EnumNumber(x)
}

// Deprecated: Use ACMEAccount_Status.Descriptor instead.
func (ACMEAccount_Status) EnumDescriptor() ([]byte, []int) {
	return file_linkedca_acme_proto_rawDescGZIP(), []int{0, 0}
}

type ACMEAccount struct {
	state                protoimpl.MessageState `protogen:"open.v1"`
	Id                   string                 `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
	Jwk                  []byte                 `protobuf:"bytes,2,opt,name=jwk,proto3" json:"jwk,omitempty"`
	Status               ACMEAccount_Status     `protobuf:"varint,3,opt,name=status,proto3,enum=linkedca.ACMEAccount_Status" json:"status,omitempty"`
	Contact              []string               `protobuf:"bytes,4,rep,name=contact,proto3" json:"contact,omitempty"`
	TermsOfServiceAgreed bool                   `protobuf:"varint,5,opt,name=terms_of_service_agreed,json=termsOfServiceAgreed,proto3" json:"terms_of_service_agreed,omitempty"`
	CreatedAt            *timestamppb.Timestamp `protobuf:"bytes,6,opt,name=created_at,json=createdAt,proto3" json:"created_at,omitempty"`
	DeletedAt            *timestamppb.Timestamp `protobuf:"bytes,7,opt,name=deleted_at,json=deletedAt,proto3" json:"deleted_at,omitempty"`
	unknownFields        protoimpl.UnknownFields
	sizeCache            protoimpl.SizeCache
}

func (x *ACMEAccount) Reset() {
	*x = ACMEAccount{}
	mi := &file_linkedca_acme_proto_msgTypes[0]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *ACMEAccount) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*ACMEAccount) ProtoMessage() {}

func (x *ACMEAccount) ProtoReflect() protoreflect.Message {
	mi := &file_linkedca_acme_proto_msgTypes[0]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use ACMEAccount.ProtoReflect.Descriptor instead.
func (*ACMEAccount) Descriptor() ([]byte, []int) {
	return file_linkedca_acme_proto_rawDescGZIP(), []int{0}
}

func (x *ACMEAccount) GetId() string {
	if x != nil {
		return x.Id
	}
	return ""
}

func (x *ACMEAccount) GetJwk() []byte {
	if x != nil {
		return x.Jwk
	}
	return nil
}

func (x *ACMEAccount) GetStatus() ACMEAccount_Status {
	if x != nil {
		return x.Status
	}
	return ACMEAccount_UNDEFINED
}

func (x *ACMEAccount) GetContact() []string {
	if x != nil {
		return x.Contact
	}
	return nil
}

func (x *ACMEAccount) GetTermsOfServiceAgreed() bool {
	if x != nil {
		return x.TermsOfServiceAgreed
	}
	return false
}

func (x *ACMEAccount) GetCreatedAt() *timestamppb.Timestamp {
	if x != nil {
		return x.CreatedAt
	}
	return nil
}

func (x *ACMEAccount) GetDeletedAt() *timestamppb.Timestamp {
	if x != nil {
		return x.DeletedAt
	}
	return nil
}

var File_linkedca_acme_proto protoreflect.FileDescriptor

const file_linkedca_acme_proto_rawDesc = "" +
	"\n" +
	"\x13linkedca/acme.proto\x12\blinkedca\x1a\x1fgoogle/protobuf/timestamp.proto\"\xee\x02\n" +
	"\vACMEAccount\x12\x0e\n" +
	"\x02id\x18\x01 \x01(\tR\x02id\x12\x10\n" +
	"\x03jwk\x18\x02 \x01(\fR\x03jwk\x124\n" +
	"\x06status\x18\x03 \x01(\x0e2\x1c.linkedca.ACMEAccount.StatusR\x06status\x12\x18\n" +
	"\acontact\x18\x04 \x03(\tR\acontact\x125\n" +
	"\x17terms_of_service_agreed\x18\x05 \x01(\bR\x14termsOfServiceAgreed\x129\n" +
	"\n" +
	"created_at\x18\x06 \x01(\v2\x1a.google.protobuf.TimestampR\tcreatedAt\x129\n" +
	"\n" +
	"deleted_at\x18\a \x01(\v2\x1a.google.protobuf.TimestampR\tdeletedAt\"@\n" +
	"\x06Status\x12\r\n" +
	"\tUNDEFINED\x10\x00\x12\t\n" +
	"\x05VALID\x10\x01\x12\x0f\n" +
	"\vDEACTIVATED\x10\x02\x12\v\n" +
	"\aREVOKED\x10\x03B\x1fZ\x1dgithub.com/smallstep/linkedcab\x06proto3"

var (
	file_linkedca_acme_proto_rawDescOnce sync.Once
	file_linkedca_acme_proto_rawDescData []byte
)

func file_linkedca_acme_proto_rawDescGZIP() []byte {
	file_linkedca_acme_proto_rawDescOnce.Do(func() {
		file_linkedca_acme_proto_rawDescData = protoimpl.X.CompressGZIP(unsafe.Slice(unsafe.StringData(file_linkedca_acme_proto_rawDesc), len(file_linkedca_acme_proto_rawDesc)))
	})
	return file_linkedca_acme_proto_rawDescData
}

var file_linkedca_acme_proto_enumTypes = make([]protoimpl.EnumInfo, 1)
var file_linkedca_acme_proto_msgTypes = make([]protoimpl.MessageInfo, 1)
var file_linkedca_acme_proto_goTypes = []any{
	(ACMEAccount_Status)(0),       // 0: linkedca.ACMEAccount.Status
	(*ACMEAccount)(nil),           // 1: linkedca.ACMEAccount
	(*timestamppb.Timestamp)(nil), // 2: google.protobuf.Timestamp
}
var file_linkedca_acme_proto_depIdxs = []int32{
	0, // 0: linkedca.ACMEAccount.status:type_name -> linkedca.ACMEAccount.Status
	2, // 1: linkedca.ACMEAccount.created_at:type_name -> google.protobuf.Timestamp
	2, // 2: linkedca.ACMEAccount.deleted_at:type_name -> google.protobuf.Timestamp
	3, // [3:3] is the sub-list for method output_type
	3, // [3:3] is the sub-list for method input_type
	3, // [3:3] is the sub-list for extension type_name
	3, // [3:3] is the sub-list for extension extendee
	0, // [0:3] is the sub-list for field type_name
}

func init() { file_linkedca_acme_proto_init() }
func file_linkedca_acme_proto_init() {
	if File_linkedca_acme_proto != nil {
		return
	}
	type x struct{}
	out := protoimpl.TypeBuilder{
		File: protoimpl.DescBuilder{
			GoPackagePath: reflect.TypeOf(x{}).PkgPath(),
			RawDescriptor: unsafe.Slice(unsafe.StringData(file_linkedca_acme_proto_rawDesc), len(file_linkedca_acme_proto_rawDesc)),
			NumEnums:      1,
			NumMessages:   1,
			NumExtensions: 0,
			NumServices:   0,
		},
		GoTypes:           file_linkedca_acme_proto_goTypes,
		DependencyIndexes: file_linkedca_acme_proto_depIdxs,
		EnumInfos:         file_linkedca_acme_proto_enumTypes,
		MessageInfos:      file_linkedca_acme_proto_msgTypes,
	}.Build()
	File_linkedca_acme_proto = out.File
	file_linkedca_acme_proto_goTypes = nil
	file_linkedca_acme_proto_depIdxs = nil
}
