// Code generated by protoc-gen-go. DO NOT EDIT.
// versions:
// 	protoc-gen-go v1.36.9
// 	protoc        v6.32.1
// source: linkedca/provisioners.proto

package linkedca

import (
	protoreflect "google.golang.org/protobuf/reflect/protoreflect"
	protoimpl "google.golang.org/protobuf/runtime/protoimpl"
	timestamppb "google.golang.org/protobuf/types/known/timestamppb"
	reflect "reflect"
	sync "sync"
	unsafe "unsafe"
)

const (
	// Verify that this generated code is sufficiently up-to-date.
	_ = protoimpl.EnforceVersion(20 - protoimpl.MinVersion)
	// Verify that runtime/protoimpl is sufficiently up-to-date.
	_ = protoimpl.EnforceVersion(protoimpl.MaxVersion - 20)
)

type Provisioner_Type int32

const (
	Provisioner_NOOP   Provisioner_Type = 0
	Provisioner_JWK    Provisioner_Type = 1
	Provisioner_OIDC   Provisioner_Type = 2
	Provisioner_GCP    Provisioner_Type = 3
	Provisioner_AWS    Provisioner_Type = 4
	Provisioner_AZURE  Provisioner_Type = 5
	Provisioner_ACME   Provisioner_Type = 6
	Provisioner_X5C    Provisioner_Type = 7
	Provisioner_K8SSA  Provisioner_Type = 8
	Provisioner_SSHPOP Provisioner_Type = 9
	Provisioner_SCEP   Provisioner_Type = 10
	Provisioner_NEBULA Provisioner_Type = 11
)

// Enum value maps for Provisioner_Type.
var (
	Provisioner_Type_name = map[int32]string{
		0:  "NOOP",
		1:  "JWK",
		2:  "OIDC",
		3:  "GCP",
		4:  "AWS",
		5:  "AZURE",
		6:  "ACME",
		7:  "X5C",
		8:  "K8SSA",
		9:  "SSHPOP",
		10: "SCEP",
		11: "NEBULA",
	}
	Provisioner_Type_value = map[string]int32{
		"NOOP":   0,
		"JWK":    1,
		"OIDC":   2,
		"GCP":    3,
		"AWS":    4,
		"AZURE":  5,
		"ACME":   6,
		"X5C":    7,
		"K8SSA":  8,
		"SSHPOP": 9,
		"SCEP":   10,
		"NEBULA": 11,
	}
)

func (x Provisioner_Type) Enum() *Provisioner_Type {
	p := new(Provisioner_Type)
	*p = x
	return p
}

func (x Provisioner_Type) String() string {
	return protoimpl.X.EnumStringOf(x.Descriptor(), protoreflect.EnumNumber(x))
}

func (Provisioner_Type) Descriptor() protoreflect.EnumDescriptor {
	return file_linkedca_provisioners_proto_enumTypes[0].Descriptor()
}

func (Provisioner_Type) Type() protoreflect.EnumType {
	return &file_linkedca_provisioners_proto_enumTypes[0]
}

func (x Provisioner_Type) Number() protoreflect.EnumNumber {
	return protoreflect.EnumNumber(x)
}

// Deprecated: Use Provisioner_Type.Descriptor instead.
func (Provisioner_Type) EnumDescriptor() ([]byte, []int) {
	return file_linkedca_provisioners_proto_rawDescGZIP(), []int{0, 0}
}

type ACMEProvisioner_ChallengeType int32

const (
	ACMEProvisioner_UNKNOWN          ACMEProvisioner_ChallengeType = 0
	ACMEProvisioner_HTTP_01          ACMEProvisioner_ChallengeType = 1
	ACMEProvisioner_DNS_01           ACMEProvisioner_ChallengeType = 2
	ACMEProvisioner_TLS_ALPN_01      ACMEProvisioner_ChallengeType = 3
	ACMEProvisioner_DEVICE_ATTEST_01 ACMEProvisioner_ChallengeType = 4
)

// Enum value maps for ACMEProvisioner_ChallengeType.
var (
	ACMEProvisioner_ChallengeType_name = map[int32]string{
		0: "UNKNOWN",
		1: "HTTP_01",
		2: "DNS_01",
		3: "TLS_ALPN_01",
		4: "DEVICE_ATTEST_01",
	}
	ACMEProvisioner_ChallengeType_value = map[string]int32{
		"UNKNOWN":          0,
		"HTTP_01":          1,
		"DNS_01":           2,
		"TLS_ALPN_01":      3,
		"DEVICE_ATTEST_01": 4,
	}
)

func (x ACMEProvisioner_ChallengeType) Enum() *ACMEProvisioner_ChallengeType {
	p := new(ACMEProvisioner_ChallengeType)
	*p = x
	return p
}

func (x ACMEProvisioner_ChallengeType) String() string {
	return protoimpl.X.EnumStringOf(x.Descriptor(), protoreflect.EnumNumber(x))
}

func (ACMEProvisioner_ChallengeType) Descriptor() protoreflect.EnumDescriptor {
	return file_linkedca_provisioners_proto_enumTypes[1].Descriptor()
}

func (ACMEProvisioner_ChallengeType) Type() protoreflect.EnumType {
	return &file_linkedca_provisioners_proto_enumTypes[1]
}

func (x ACMEProvisioner_ChallengeType) Number() protoreflect.EnumNumber {
	return protoreflect.EnumNumber(x)
}

// Deprecated: Use ACMEProvisioner_ChallengeType.Descriptor instead.
func (ACMEProvisioner_ChallengeType) EnumDescriptor() ([]byte, []int) {
	return file_linkedca_provisioners_proto_rawDescGZIP(), []int{14, 0}
}

type ACMEProvisioner_AttestationFormatType int32

const (
	ACMEProvisioner_NONE  ACMEProvisioner_AttestationFormatType = 0
	ACMEProvisioner_APPLE ACMEProvisioner_AttestationFormatType = 1
	ACMEProvisioner_STEP  ACMEProvisioner_AttestationFormatType = 2
	ACMEProvisioner_TPM   ACMEProvisioner_AttestationFormatType = 3
)

// Enum value maps for ACMEProvisioner_AttestationFormatType.
var (
	ACMEProvisioner_AttestationFormatType_name = map[int32]string{
		0: "NONE",
		1: "APPLE",
		2: "STEP",
		3: "TPM",
	}
	ACMEProvisioner_AttestationFormatType_value = map[string]int32{
		"NONE":  0,
		"APPLE": 1,
		"STEP":  2,
		"TPM":   3,
	}
)

func (x ACMEProvisioner_AttestationFormatType) Enum() *ACMEProvisioner_AttestationFormatType {
	p := new(ACMEProvisioner_AttestationFormatType)
	*p = x
	return p
}

func (x ACMEProvisioner_AttestationFormatType) String() string {
	return protoimpl.X.EnumStringOf(x.Descriptor(), protoreflect.EnumNumber(x))
}

func (ACMEProvisioner_AttestationFormatType) Descriptor() protoreflect.EnumDescriptor {
	return file_linkedca_provisioners_proto_enumTypes[2].Descriptor()
}

func (ACMEProvisioner_AttestationFormatType) Type() protoreflect.EnumType {
	return &file_linkedca_provisioners_proto_enumTypes[2]
}

func (x ACMEProvisioner_AttestationFormatType) Number() protoreflect.EnumNumber {
	return protoreflect.EnumNumber(x)
}

// Deprecated: Use ACMEProvisioner_AttestationFormatType.Descriptor instead.
func (ACMEProvisioner_AttestationFormatType) EnumDescriptor() ([]byte, []int) {
	return file_linkedca_provisioners_proto_rawDescGZIP(), []int{14, 1}
}

type Webhook_Kind int32

const (
	Webhook_NO_KIND       Webhook_Kind = 0
	Webhook_ENRICHING     Webhook_Kind = 1
	Webhook_AUTHORIZING   Webhook_Kind = 2
	Webhook_SCEPCHALLENGE Webhook_Kind = 3
	Webhook_NOTIFYING     Webhook_Kind = 4
)

// Enum value maps for Webhook_Kind.
var (
	Webhook_Kind_name = map[int32]string{
		0: "NO_KIND",
		1: "ENRICHING",
		2: "AUTHORIZING",
		3: "SCEPCHALLENGE",
		4: "NOTIFYING",
	}
	Webhook_Kind_value = map[string]int32{
		"NO_KIND":       0,
		"ENRICHING":     1,
		"AUTHORIZING":   2,
		"SCEPCHALLENGE": 3,
		"NOTIFYING":     4,
	}
)

func (x Webhook_Kind) Enum() *Webhook_Kind {
	p := new(Webhook_Kind)
	*p = x
	return p
}

func (x Webhook_Kind) String() string {
	return protoimpl.X.EnumStringOf(x.Descriptor(), protoreflect.EnumNumber(x))
}

func (Webhook_Kind) Descriptor() protoreflect.EnumDescriptor {
	return file_linkedca_provisioners_proto_enumTypes[3].Descriptor()
}

func (Webhook_Kind) Type() protoreflect.EnumType {
	return &file_linkedca_provisioners_proto_enumTypes[3]
}

func (x Webhook_Kind) Number() protoreflect.EnumNumber {
	return protoreflect.EnumNumber(x)
}

// Deprecated: Use Webhook_Kind.Descriptor instead.
func (Webhook_Kind) EnumDescriptor() ([]byte, []int) {
	return file_linkedca_provisioners_proto_rawDescGZIP(), []int{23, 0}
}

type Webhook_CertType int32

const (
	Webhook_ALL  Webhook_CertType = 0
	Webhook_X509 Webhook_CertType = 1
	Webhook_SSH  Webhook_CertType = 2
)

// Enum value maps for Webhook_CertType.
var (
	Webhook_CertType_name = map[int32]string{
		0: "ALL",
		1: "X509",
		2: "SSH",
	}
	Webhook_CertType_value = map[string]int32{
		"ALL":  0,
		"X509": 1,
		"SSH":  2,
	}
)

func (x Webhook_CertType) Enum() *Webhook_CertType {
	p := new(Webhook_CertType)
	*p = x
	return p
}

func (x Webhook_CertType) String() string {
	return protoimpl.X.EnumStringOf(x.Descriptor(), protoreflect.EnumNumber(x))
}

func (Webhook_CertType) Descriptor() protoreflect.EnumDescriptor {
	return file_linkedca_provisioners_proto_enumTypes[4].Descriptor()
}

func (Webhook_CertType) Type() protoreflect.EnumType {
	return &file_linkedca_provisioners_proto_enumTypes[4]
}

func (x Webhook_CertType) Number() protoreflect.EnumNumber {
	return protoreflect.EnumNumber(x)
}

// Deprecated: Use Webhook_CertType.Descriptor instead.
func (Webhook_CertType) EnumDescriptor() ([]byte, []int) {
	return file_linkedca_provisioners_proto_rawDescGZIP(), []int{23, 1}
}

type Provisioner struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	Id            string                 `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
	AuthorityId   string                 `protobuf:"bytes,2,opt,name=authority_id,json=authorityId,proto3" json:"authority_id,omitempty"`
	Type          Provisioner_Type       `protobuf:"varint,3,opt,name=type,proto3,enum=linkedca.Provisioner_Type" json:"type,omitempty"`
	Name          string                 `protobuf:"bytes,4,opt,name=name,proto3" json:"name,omitempty"`
	Details       *ProvisionerDetails    `protobuf:"bytes,5,opt,name=details,proto3" json:"details,omitempty"`
	Claims        *Claims                `protobuf:"bytes,6,opt,name=claims,proto3" json:"claims,omitempty"`
	X509Template  *Template              `protobuf:"bytes,7,opt,name=x509_template,json=x509Template,proto3" json:"x509_template,omitempty"`
	SshTemplate   *Template              `protobuf:"bytes,8,opt,name=ssh_template,json=sshTemplate,proto3" json:"ssh_template,omitempty"`
	CreatedAt     *timestamppb.Timestamp `protobuf:"bytes,9,opt,name=created_at,json=createdAt,proto3" json:"created_at,omitempty"`
	DeletedAt     *timestamppb.Timestamp `protobuf:"bytes,10,opt,name=deleted_at,json=deletedAt,proto3" json:"deleted_at,omitempty"`
	Policy        *Policy                `protobuf:"bytes,11,opt,name=policy,proto3" json:"policy,omitempty"`
	Webhooks      []*Webhook             `protobuf:"bytes,12,rep,name=webhooks,proto3" json:"webhooks,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *Provisioner) Reset() {
	*x = Provisioner{}
	mi := &file_linkedca_provisioners_proto_msgTypes[0]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *Provisioner) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*Provisioner) ProtoMessage() {}

func (x *Provisioner) ProtoReflect() protoreflect.Message {
	mi := &file_linkedca_provisioners_proto_msgTypes[0]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use Provisioner.ProtoReflect.Descriptor instead.
func (*Provisioner) Descriptor() ([]byte, []int) {
	return file_linkedca_provisioners_proto_rawDescGZIP(), []int{0}
}

func (x *Provisioner) GetId() string {
	if x != nil {
		return x.Id
	}
	return ""
}

func (x *Provisioner) GetAuthorityId() string {
	if x != nil {
		return x.AuthorityId
	}
	return ""
}

func (x *Provisioner) GetType() Provisioner_Type {
	if x != nil {
		return x.Type
	}
	return Provisioner_NOOP
}

func (x *Provisioner) GetName() string {
	if x != nil {
		return x.Name
	}
	return ""
}

func (x *Provisioner) GetDetails() *ProvisionerDetails {
	if x != nil {
		return x.Details
	}
	return nil
}

func (x *Provisioner) GetClaims() *Claims {
	if x != nil {
		return x.Claims
	}
	return nil
}

func (x *Provisioner) GetX509Template() *Template {
	if x != nil {
		return x.X509Template
	}
	return nil
}

func (x *Provisioner) GetSshTemplate() *Template {
	if x != nil {
		return x.SshTemplate
	}
	return nil
}

func (x *Provisioner) GetCreatedAt() *timestamppb.Timestamp {
	if x != nil {
		return x.CreatedAt
	}
	return nil
}

func (x *Provisioner) GetDeletedAt() *timestamppb.Timestamp {
	if x != nil {
		return x.DeletedAt
	}
	return nil
}

func (x *Provisioner) GetPolicy() *Policy {
	if x != nil {
		return x.Policy
	}
	return nil
}

func (x *Provisioner) GetWebhooks() []*Webhook {
	if x != nil {
		return x.Webhooks
	}
	return nil
}

type ProvisionerIdentity struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	Id            string                 `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
	Type          Provisioner_Type       `protobuf:"varint,2,opt,name=type,proto3,enum=linkedca.Provisioner_Type" json:"type,omitempty"`
	Name          string                 `protobuf:"bytes,3,opt,name=name,proto3" json:"name,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *ProvisionerIdentity) Reset() {
	*x = ProvisionerIdentity{}
	mi := &file_linkedca_provisioners_proto_msgTypes[1]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *ProvisionerIdentity) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*ProvisionerIdentity) ProtoMessage() {}

func (x *ProvisionerIdentity) ProtoReflect() protoreflect.Message {
	mi := &file_linkedca_provisioners_proto_msgTypes[1]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use ProvisionerIdentity.ProtoReflect.Descriptor instead.
func (*ProvisionerIdentity) Descriptor() ([]byte, []int) {
	return file_linkedca_provisioners_proto_rawDescGZIP(), []int{1}
}

func (x *ProvisionerIdentity) GetId() string {
	if x != nil {
		return x.Id
	}
	return ""
}

func (x *ProvisionerIdentity) GetType() Provisioner_Type {
	if x != nil {
		return x.Type
	}
	return Provisioner_NOOP
}

func (x *ProvisionerIdentity) GetName() string {
	if x != nil {
		return x.Name
	}
	return ""
}

type ProvisionerDetails struct {
	state protoimpl.MessageState `protogen:"open.v1"`
	// Types that are valid to be assigned to Data:
	//
	//	*ProvisionerDetails_JWK
	//	*ProvisionerDetails_OIDC
	//	*ProvisionerDetails_GCP
	//	*ProvisionerDetails_AWS
	//	*ProvisionerDetails_Azure
	//	*ProvisionerDetails_ACME
	//	*ProvisionerDetails_X5C
	//	*ProvisionerDetails_K8SSA
	//	*ProvisionerDetails_SSHPOP
	//	*ProvisionerDetails_SCEP
	//	*ProvisionerDetails_Nebula
	Data          isProvisionerDetails_Data `protobuf_oneof:"data"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *ProvisionerDetails) Reset() {
	*x = ProvisionerDetails{}
	mi := &file_linkedca_provisioners_proto_msgTypes[2]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *ProvisionerDetails) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*ProvisionerDetails) ProtoMessage() {}

func (x *ProvisionerDetails) ProtoReflect() protoreflect.Message {
	mi := &file_linkedca_provisioners_proto_msgTypes[2]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use ProvisionerDetails.ProtoReflect.Descriptor instead.
func (*ProvisionerDetails) Descriptor() ([]byte, []int) {
	return file_linkedca_provisioners_proto_rawDescGZIP(), []int{2}
}

func (x *ProvisionerDetails) GetData() isProvisionerDetails_Data {
	if x != nil {
		return x.Data
	}
	return nil
}

func (x *ProvisionerDetails) GetJWK() *JWKProvisioner {
	if x != nil {
		if x, ok := x.Data.(*ProvisionerDetails_JWK); ok {
			return x.JWK
		}
	}
	return nil
}

func (x *ProvisionerDetails) GetOIDC() *OIDCProvisioner {
	if x != nil {
		if x, ok := x.Data.(*ProvisionerDetails_OIDC); ok {
			return x.OIDC
		}
	}
	return nil
}

func (x *ProvisionerDetails) GetGCP() *GCPProvisioner {
	if x != nil {
		if x, ok := x.Data.(*ProvisionerDetails_GCP); ok {
			return x.GCP
		}
	}
	return nil
}

func (x *ProvisionerDetails) GetAWS() *AWSProvisioner {
	if x != nil {
		if x, ok := x.Data.(*ProvisionerDetails_AWS); ok {
			return x.AWS
		}
	}
	return nil
}

func (x *ProvisionerDetails) GetAzure() *AzureProvisioner {
	if x != nil {
		if x, ok := x.Data.(*ProvisionerDetails_Azure); ok {
			return x.Azure
		}
	}
	return nil
}

func (x *ProvisionerDetails) GetACME() *ACMEProvisioner {
	if x != nil {
		if x, ok := x.Data.(*ProvisionerDetails_ACME); ok {
			return x.ACME
		}
	}
	return nil
}

func (x *ProvisionerDetails) GetX5C() *X5CProvisioner {
	if x != nil {
		if x, ok := x.Data.(*ProvisionerDetails_X5C); ok {
			return x.X5C
		}
	}
	return nil
}

func (x *ProvisionerDetails) GetK8SSA() *K8SSAProvisioner {
	if x != nil {
		if x, ok := x.Data.(*ProvisionerDetails_K8SSA); ok {
			return x.K8SSA
		}
	}
	return nil
}

func (x *ProvisionerDetails) GetSSHPOP() *SSHPOPProvisioner {
	if x != nil {
		if x, ok := x.Data.(*ProvisionerDetails_SSHPOP); ok {
			return x.SSHPOP
		}
	}
	return nil
}

func (x *ProvisionerDetails) GetSCEP() *SCEPProvisioner {
	if x != nil {
		if x, ok := x.Data.(*ProvisionerDetails_SCEP); ok {
			return x.SCEP
		}
	}
	return nil
}

func (x *ProvisionerDetails) GetNebula() *NebulaProvisioner {
	if x != nil {
		if x, ok := x.Data.(*ProvisionerDetails_Nebula); ok {
			return x.Nebula
		}
	}
	return nil
}

type isProvisionerDetails_Data interface {
	isProvisionerDetails_Data()
}

type ProvisionerDetails_JWK struct {
	JWK *JWKProvisioner `protobuf:"bytes,20,opt,name=JWK,proto3,oneof"`
}

type ProvisionerDetails_OIDC struct {
	OIDC *OIDCProvisioner `protobuf:"bytes,21,opt,name=OIDC,proto3,oneof"`
}

type ProvisionerDetails_GCP struct {
	GCP *GCPProvisioner `protobuf:"bytes,22,opt,name=GCP,proto3,oneof"`
}

type ProvisionerDetails_AWS struct {
	AWS *AWSProvisioner `protobuf:"bytes,23,opt,name=AWS,proto3,oneof"`
}

type ProvisionerDetails_Azure struct {
	Azure *AzureProvisioner `protobuf:"bytes,24,opt,name=Azure,proto3,oneof"`
}

type ProvisionerDetails_ACME struct {
	ACME *ACMEProvisioner `protobuf:"bytes,25,opt,name=ACME,proto3,oneof"`
}

type ProvisionerDetails_X5C struct {
	X5C *X5CProvisioner `protobuf:"bytes,26,opt,name=X5C,proto3,oneof"`
}

type ProvisionerDetails_K8SSA struct {
	K8SSA *K8SSAProvisioner `protobuf:"bytes,27,opt,name=K8sSA,proto3,oneof"`
}

type ProvisionerDetails_SSHPOP struct {
	SSHPOP *SSHPOPProvisioner `protobuf:"bytes,28,opt,name=SSHPOP,proto3,oneof"`
}

type ProvisionerDetails_SCEP struct {
	SCEP *SCEPProvisioner `protobuf:"bytes,29,opt,name=SCEP,proto3,oneof"`
}

type ProvisionerDetails_Nebula struct {
	Nebula *NebulaProvisioner `protobuf:"bytes,30,opt,name=Nebula,proto3,oneof"`
}

func (*ProvisionerDetails_JWK) isProvisionerDetails_Data() {}

func (*ProvisionerDetails_OIDC) isProvisionerDetails_Data() {}

func (*ProvisionerDetails_GCP) isProvisionerDetails_Data() {}

func (*ProvisionerDetails_AWS) isProvisionerDetails_Data() {}

func (*ProvisionerDetails_Azure) isProvisionerDetails_Data() {}

func (*ProvisionerDetails_ACME) isProvisionerDetails_Data() {}

func (*ProvisionerDetails_X5C) isProvisionerDetails_Data() {}

func (*ProvisionerDetails_K8SSA) isProvisionerDetails_Data() {}

func (*ProvisionerDetails_SSHPOP) isProvisionerDetails_Data() {}

func (*ProvisionerDetails_SCEP) isProvisionerDetails_Data() {}

func (*ProvisionerDetails_Nebula) isProvisionerDetails_Data() {}

type ProvisionerList struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	Provisioners  []*Provisioner         `protobuf:"bytes,1,rep,name=provisioners,proto3" json:"provisioners,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *ProvisionerList) Reset() {
	*x = ProvisionerList{}
	mi := &file_linkedca_provisioners_proto_msgTypes[3]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *ProvisionerList) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*ProvisionerList) ProtoMessage() {}

func (x *ProvisionerList) ProtoReflect() protoreflect.Message {
	mi := &file_linkedca_provisioners_proto_msgTypes[3]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use ProvisionerList.ProtoReflect.Descriptor instead.
func (*ProvisionerList) Descriptor() ([]byte, []int) {
	return file_linkedca_provisioners_proto_rawDescGZIP(), []int{3}
}

func (x *ProvisionerList) GetProvisioners() []*Provisioner {
	if x != nil {
		return x.Provisioners
	}
	return nil
}

type Claims struct {
	state                      protoimpl.MessageState `protogen:"open.v1"`
	X509                       *X509Claims            `protobuf:"bytes,1,opt,name=x509,proto3" json:"x509,omitempty"`
	Ssh                        *SSHClaims             `protobuf:"bytes,2,opt,name=ssh,proto3" json:"ssh,omitempty"`
	DisableRenewal             bool                   `protobuf:"varint,3,opt,name=disable_renewal,json=disableRenewal,proto3" json:"disable_renewal,omitempty"`
	AllowRenewalAfterExpiry    bool                   `protobuf:"varint,4,opt,name=allow_renewal_after_expiry,json=allowRenewalAfterExpiry,proto3" json:"allow_renewal_after_expiry,omitempty"`
	DisableSmallstepExtensions bool                   `protobuf:"varint,5,opt,name=disable_smallstep_extensions,json=disableSmallstepExtensions,proto3" json:"disable_smallstep_extensions,omitempty"`
	unknownFields              protoimpl.UnknownFields
	sizeCache                  protoimpl.SizeCache
}

func (x *Claims) Reset() {
	*x = Claims{}
	mi := &file_linkedca_provisioners_proto_msgTypes[4]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *Claims) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*Claims) ProtoMessage() {}

func (x *Claims) ProtoReflect() protoreflect.Message {
	mi := &file_linkedca_provisioners_proto_msgTypes[4]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use Claims.ProtoReflect.Descriptor instead.
func (*Claims) Descriptor() ([]byte, []int) {
	return file_linkedca_provisioners_proto_rawDescGZIP(), []int{4}
}

func (x *Claims) GetX509() *X509Claims {
	if x != nil {
		return x.X509
	}
	return nil
}

func (x *Claims) GetSsh() *SSHClaims {
	if x != nil {
		return x.Ssh
	}
	return nil
}

func (x *Claims) GetDisableRenewal() bool {
	if x != nil {
		return x.DisableRenewal
	}
	return false
}

func (x *Claims) GetAllowRenewalAfterExpiry() bool {
	if x != nil {
		return x.AllowRenewalAfterExpiry
	}
	return false
}

func (x *Claims) GetDisableSmallstepExtensions() bool {
	if x != nil {
		return x.DisableSmallstepExtensions
	}
	return false
}

type X509Claims struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	Enabled       bool                   `protobuf:"varint,1,opt,name=enabled,proto3" json:"enabled,omitempty"`
	Durations     *Durations             `protobuf:"bytes,2,opt,name=durations,proto3" json:"durations,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *X509Claims) Reset() {
	*x = X509Claims{}
	mi := &file_linkedca_provisioners_proto_msgTypes[5]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *X509Claims) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*X509Claims) ProtoMessage() {}

func (x *X509Claims) ProtoReflect() protoreflect.Message {
	mi := &file_linkedca_provisioners_proto_msgTypes[5]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use X509Claims.ProtoReflect.Descriptor instead.
func (*X509Claims) Descriptor() ([]byte, []int) {
	return file_linkedca_provisioners_proto_rawDescGZIP(), []int{5}
}

func (x *X509Claims) GetEnabled() bool {
	if x != nil {
		return x.Enabled
	}
	return false
}

func (x *X509Claims) GetDurations() *Durations {
	if x != nil {
		return x.Durations
	}
	return nil
}

type SSHClaims struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	Enabled       bool                   `protobuf:"varint,1,opt,name=enabled,proto3" json:"enabled,omitempty"`
	UserDurations *Durations             `protobuf:"bytes,2,opt,name=user_durations,json=userDurations,proto3" json:"user_durations,omitempty"`
	HostDurations *Durations             `protobuf:"bytes,3,opt,name=host_durations,json=hostDurations,proto3" json:"host_durations,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *SSHClaims) Reset() {
	*x = SSHClaims{}
	mi := &file_linkedca_provisioners_proto_msgTypes[6]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *SSHClaims) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*SSHClaims) ProtoMessage() {}

func (x *SSHClaims) ProtoReflect() protoreflect.Message {
	mi := &file_linkedca_provisioners_proto_msgTypes[6]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use SSHClaims.ProtoReflect.Descriptor instead.
func (*SSHClaims) Descriptor() ([]byte, []int) {
	return file_linkedca_provisioners_proto_rawDescGZIP(), []int{6}
}

func (x *SSHClaims) GetEnabled() bool {
	if x != nil {
		return x.Enabled
	}
	return false
}

func (x *SSHClaims) GetUserDurations() *Durations {
	if x != nil {
		return x.UserDurations
	}
	return nil
}

func (x *SSHClaims) GetHostDurations() *Durations {
	if x != nil {
		return x.HostDurations
	}
	return nil
}

type Durations struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	Default       string                 `protobuf:"bytes,1,opt,name=default,proto3" json:"default,omitempty"`
	Min           string                 `protobuf:"bytes,2,opt,name=min,proto3" json:"min,omitempty"`
	Max           string                 `protobuf:"bytes,3,opt,name=max,proto3" json:"max,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *Durations) Reset() {
	*x = Durations{}
	mi := &file_linkedca_provisioners_proto_msgTypes[7]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *Durations) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*Durations) ProtoMessage() {}

func (x *Durations) ProtoReflect() protoreflect.Message {
	mi := &file_linkedca_provisioners_proto_msgTypes[7]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use Durations.ProtoReflect.Descriptor instead.
func (*Durations) Descriptor() ([]byte, []int) {
	return file_linkedca_provisioners_proto_rawDescGZIP(), []int{7}
}

func (x *Durations) GetDefault() string {
	if x != nil {
		return x.Default
	}
	return ""
}

func (x *Durations) GetMin() string {
	if x != nil {
		return x.Min
	}
	return ""
}

func (x *Durations) GetMax() string {
	if x != nil {
		return x.Max
	}
	return ""
}

type Template struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	Template      []byte                 `protobuf:"bytes,1,opt,name=template,proto3" json:"template,omitempty"`
	Data          []byte                 `protobuf:"bytes,2,opt,name=data,proto3" json:"data,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *Template) Reset() {
	*x = Template{}
	mi := &file_linkedca_provisioners_proto_msgTypes[8]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *Template) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*Template) ProtoMessage() {}

func (x *Template) ProtoReflect() protoreflect.Message {
	mi := &file_linkedca_provisioners_proto_msgTypes[8]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use Template.ProtoReflect.Descriptor instead.
func (*Template) Descriptor() ([]byte, []int) {
	return file_linkedca_provisioners_proto_rawDescGZIP(), []int{8}
}

func (x *Template) GetTemplate() []byte {
	if x != nil {
		return x.Template
	}
	return nil
}

func (x *Template) GetData() []byte {
	if x != nil {
		return x.Data
	}
	return nil
}

type JWKProvisioner struct {
	state               protoimpl.MessageState `protogen:"open.v1"`
	PublicKey           []byte                 `protobuf:"bytes,1,opt,name=public_key,json=publicKey,proto3" json:"public_key,omitempty"`
	EncryptedPrivateKey []byte                 `protobuf:"bytes,2,opt,name=encrypted_private_key,json=encryptedPrivateKey,proto3" json:"encrypted_private_key,omitempty"`
	unknownFields       protoimpl.UnknownFields
	sizeCache           protoimpl.SizeCache
}

func (x *JWKProvisioner) Reset() {
	*x = JWKProvisioner{}
	mi := &file_linkedca_provisioners_proto_msgTypes[9]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *JWKProvisioner) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*JWKProvisioner) ProtoMessage() {}

func (x *JWKProvisioner) ProtoReflect() protoreflect.Message {
	mi := &file_linkedca_provisioners_proto_msgTypes[9]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use JWKProvisioner.ProtoReflect.Descriptor instead.
func (*JWKProvisioner) Descriptor() ([]byte, []int) {
	return file_linkedca_provisioners_proto_rawDescGZIP(), []int{9}
}

func (x *JWKProvisioner) GetPublicKey() []byte {
	if x != nil {
		return x.PublicKey
	}
	return nil
}

func (x *JWKProvisioner) GetEncryptedPrivateKey() []byte {
	if x != nil {
		return x.EncryptedPrivateKey
	}
	return nil
}

type OIDCProvisioner struct {
	state                 protoimpl.MessageState `protogen:"open.v1"`
	ClientId              string                 `protobuf:"bytes,1,opt,name=client_id,json=clientId,proto3" json:"client_id,omitempty"`
	ClientSecret          string                 `protobuf:"bytes,2,opt,name=client_secret,json=clientSecret,proto3" json:"client_secret,omitempty"`
	ConfigurationEndpoint string                 `protobuf:"bytes,3,opt,name=configuration_endpoint,json=configurationEndpoint,proto3" json:"configuration_endpoint,omitempty"`
	Admins                []string               `protobuf:"bytes,4,rep,name=admins,proto3" json:"admins,omitempty"`
	Domains               []string               `protobuf:"bytes,5,rep,name=domains,proto3" json:"domains,omitempty"`
	Groups                []string               `protobuf:"bytes,6,rep,name=groups,proto3" json:"groups,omitempty"`
	ListenAddress         string                 `protobuf:"bytes,7,opt,name=listen_address,json=listenAddress,proto3" json:"listen_address,omitempty"`
	TenantId              string                 `protobuf:"bytes,8,opt,name=tenant_id,json=tenantId,proto3" json:"tenant_id,omitempty"`
	Scopes                []string               `protobuf:"bytes,9,rep,name=scopes,proto3" json:"scopes,omitempty"`
	AuthParams            []string               `protobuf:"bytes,10,rep,name=auth_params,json=authParams,proto3" json:"auth_params,omitempty"`
	unknownFields         protoimpl.UnknownFields
	sizeCache             protoimpl.SizeCache
}

func (x *OIDCProvisioner) Reset() {
	*x = OIDCProvisioner{}
	mi := &file_linkedca_provisioners_proto_msgTypes[10]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *OIDCProvisioner) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*OIDCProvisioner) ProtoMessage() {}

func (x *OIDCProvisioner) ProtoReflect() protoreflect.Message {
	mi := &file_linkedca_provisioners_proto_msgTypes[10]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use OIDCProvisioner.ProtoReflect.Descriptor instead.
func (*OIDCProvisioner) Descriptor() ([]byte, []int) {
	return file_linkedca_provisioners_proto_rawDescGZIP(), []int{10}
}

func (x *OIDCProvisioner) GetClientId() string {
	if x != nil {
		return x.ClientId
	}
	return ""
}

func (x *OIDCProvisioner) GetClientSecret() string {
	if x != nil {
		return x.ClientSecret
	}
	return ""
}

func (x *OIDCProvisioner) GetConfigurationEndpoint() string {
	if x != nil {
		return x.ConfigurationEndpoint
	}
	return ""
}

func (x *OIDCProvisioner) GetAdmins() []string {
	if x != nil {
		return x.Admins
	}
	return nil
}

func (x *OIDCProvisioner) GetDomains() []string {
	if x != nil {
		return x.Domains
	}
	return nil
}

func (x *OIDCProvisioner) GetGroups() []string {
	if x != nil {
		return x.Groups
	}
	return nil
}

func (x *OIDCProvisioner) GetListenAddress() string {
	if x != nil {
		return x.ListenAddress
	}
	return ""
}

func (x *OIDCProvisioner) GetTenantId() string {
	if x != nil {
		return x.TenantId
	}
	return ""
}

func (x *OIDCProvisioner) GetScopes() []string {
	if x != nil {
		return x.Scopes
	}
	return nil
}

func (x *OIDCProvisioner) GetAuthParams() []string {
	if x != nil {
		return x.AuthParams
	}
	return nil
}

type GCPProvisioner struct {
	state                  protoimpl.MessageState `protogen:"open.v1"`
	ServiceAccounts        []string               `protobuf:"bytes,1,rep,name=service_accounts,json=serviceAccounts,proto3" json:"service_accounts,omitempty"`
	ProjectIds             []string               `protobuf:"bytes,2,rep,name=project_ids,json=projectIds,proto3" json:"project_ids,omitempty"`
	DisableCustomSans      bool                   `protobuf:"varint,3,opt,name=disable_custom_sans,json=disableCustomSans,proto3" json:"disable_custom_sans,omitempty"`
	DisableTrustOnFirstUse bool                   `protobuf:"varint,4,opt,name=disable_trust_on_first_use,json=disableTrustOnFirstUse,proto3" json:"disable_trust_on_first_use,omitempty"`
	InstanceAge            string                 `protobuf:"bytes,5,opt,name=instance_age,json=instanceAge,proto3" json:"instance_age,omitempty"`
	DisableSshCaUser       *bool                  `protobuf:"varint,6,opt,name=disable_ssh_ca_user,json=disableSshCaUser,proto3,oneof" json:"disable_ssh_ca_user,omitempty"`
	DisableSshCaHost       *bool                  `protobuf:"varint,7,opt,name=disable_ssh_ca_host,json=disableSshCaHost,proto3,oneof" json:"disable_ssh_ca_host,omitempty"`
	OrganizationId         string                 `protobuf:"bytes,8,opt,name=organization_id,json=organizationId,proto3" json:"organization_id,omitempty"`
	unknownFields          protoimpl.UnknownFields
	sizeCache              protoimpl.SizeCache
}

func (x *GCPProvisioner) Reset() {
	*x = GCPProvisioner{}
	mi := &file_linkedca_provisioners_proto_msgTypes[11]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *GCPProvisioner) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*GCPProvisioner) ProtoMessage() {}

func (x *GCPProvisioner) ProtoReflect() protoreflect.Message {
	mi := &file_linkedca_provisioners_proto_msgTypes[11]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use GCPProvisioner.ProtoReflect.Descriptor instead.
func (*GCPProvisioner) Descriptor() ([]byte, []int) {
	return file_linkedca_provisioners_proto_rawDescGZIP(), []int{11}
}

func (x *GCPProvisioner) GetServiceAccounts() []string {
	if x != nil {
		return x.ServiceAccounts
	}
	return nil
}

func (x *GCPProvisioner) GetProjectIds() []string {
	if x != nil {
		return x.ProjectIds
	}
	return nil
}

func (x *GCPProvisioner) GetDisableCustomSans() bool {
	if x != nil {
		return x.DisableCustomSans
	}
	return false
}

func (x *GCPProvisioner) GetDisableTrustOnFirstUse() bool {
	if x != nil {
		return x.DisableTrustOnFirstUse
	}
	return false
}

func (x *GCPProvisioner) GetInstanceAge() string {
	if x != nil {
		return x.InstanceAge
	}
	return ""
}

func (x *GCPProvisioner) GetDisableSshCaUser() bool {
	if x != nil && x.DisableSshCaUser != nil {
		return *x.DisableSshCaUser
	}
	return false
}

func (x *GCPProvisioner) GetDisableSshCaHost() bool {
	if x != nil && x.DisableSshCaHost != nil {
		return *x.DisableSshCaHost
	}
	return false
}

func (x *GCPProvisioner) GetOrganizationId() string {
	if x != nil {
		return x.OrganizationId
	}
	return ""
}

type AWSProvisioner struct {
	state                  protoimpl.MessageState `protogen:"open.v1"`
	Accounts               []string               `protobuf:"bytes,1,rep,name=accounts,proto3" json:"accounts,omitempty"`
	DisableCustomSans      bool                   `protobuf:"varint,2,opt,name=disable_custom_sans,json=disableCustomSans,proto3" json:"disable_custom_sans,omitempty"`
	DisableTrustOnFirstUse bool                   `protobuf:"varint,3,opt,name=disable_trust_on_first_use,json=disableTrustOnFirstUse,proto3" json:"disable_trust_on_first_use,omitempty"`
	InstanceAge            string                 `protobuf:"bytes,4,opt,name=instance_age,json=instanceAge,proto3" json:"instance_age,omitempty"`
	unknownFields          protoimpl.UnknownFields
	sizeCache              protoimpl.SizeCache
}

func (x *AWSProvisioner) Reset() {
	*x = AWSProvisioner{}
	mi := &file_linkedca_provisioners_proto_msgTypes[12]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *AWSProvisioner) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*AWSProvisioner) ProtoMessage() {}

func (x *AWSProvisioner) ProtoReflect() protoreflect.Message {
	mi := &file_linkedca_provisioners_proto_msgTypes[12]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use AWSProvisioner.ProtoReflect.Descriptor instead.
func (*AWSProvisioner) Descriptor() ([]byte, []int) {
	return file_linkedca_provisioners_proto_rawDescGZIP(), []int{12}
}

func (x *AWSProvisioner) GetAccounts() []string {
	if x != nil {
		return x.Accounts
	}
	return nil
}

func (x *AWSProvisioner) GetDisableCustomSans() bool {
	if x != nil {
		return x.DisableCustomSans
	}
	return false
}

func (x *AWSProvisioner) GetDisableTrustOnFirstUse() bool {
	if x != nil {
		return x.DisableTrustOnFirstUse
	}
	return false
}

func (x *AWSProvisioner) GetInstanceAge() string {
	if x != nil {
		return x.InstanceAge
	}
	return ""
}

type AzureProvisioner struct {
	state                  protoimpl.MessageState `protogen:"open.v1"`
	TenantId               string                 `protobuf:"bytes,1,opt,name=tenant_id,json=tenantId,proto3" json:"tenant_id,omitempty"`
	ResourceGroups         []string               `protobuf:"bytes,2,rep,name=resource_groups,json=resourceGroups,proto3" json:"resource_groups,omitempty"`
	Audience               string                 `protobuf:"bytes,3,opt,name=audience,proto3" json:"audience,omitempty"`
	DisableCustomSans      bool                   `protobuf:"varint,4,opt,name=disable_custom_sans,json=disableCustomSans,proto3" json:"disable_custom_sans,omitempty"`
	DisableTrustOnFirstUse bool                   `protobuf:"varint,5,opt,name=disable_trust_on_first_use,json=disableTrustOnFirstUse,proto3" json:"disable_trust_on_first_use,omitempty"`
	SubscriptionIds        []string               `protobuf:"bytes,6,rep,name=subscription_ids,json=subscriptionIds,proto3" json:"subscription_ids,omitempty"`
	ObjectIds              []string               `protobuf:"bytes,7,rep,name=object_ids,json=objectIds,proto3" json:"object_ids,omitempty"`
	unknownFields          protoimpl.UnknownFields
	sizeCache              protoimpl.SizeCache
}

func (x *AzureProvisioner) Reset() {
	*x = AzureProvisioner{}
	mi := &file_linkedca_provisioners_proto_msgTypes[13]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *AzureProvisioner) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*AzureProvisioner) ProtoMessage() {}

func (x *AzureProvisioner) ProtoReflect() protoreflect.Message {
	mi := &file_linkedca_provisioners_proto_msgTypes[13]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use AzureProvisioner.ProtoReflect.Descriptor instead.
func (*AzureProvisioner) Descriptor() ([]byte, []int) {
	return file_linkedca_provisioners_proto_rawDescGZIP(), []int{13}
}

func (x *AzureProvisioner) GetTenantId() string {
	if x != nil {
		return x.TenantId
	}
	return ""
}

func (x *AzureProvisioner) GetResourceGroups() []string {
	if x != nil {
		return x.ResourceGroups
	}
	return nil
}

func (x *AzureProvisioner) GetAudience() string {
	if x != nil {
		return x.Audience
	}
	return ""
}

func (x *AzureProvisioner) GetDisableCustomSans() bool {
	if x != nil {
		return x.DisableCustomSans
	}
	return false
}

func (x *AzureProvisioner) GetDisableTrustOnFirstUse() bool {
	if x != nil {
		return x.DisableTrustOnFirstUse
	}
	return false
}

func (x *AzureProvisioner) GetSubscriptionIds() []string {
	if x != nil {
		return x.SubscriptionIds
	}
	return nil
}

func (x *AzureProvisioner) GetObjectIds() []string {
	if x != nil {
		return x.ObjectIds
	}
	return nil
}

type ACMEProvisioner struct {
	state              protoimpl.MessageState                  `protogen:"open.v1"`
	ForceCn            bool                                    `protobuf:"varint,1,opt,name=force_cn,json=forceCn,proto3" json:"force_cn,omitempty"`
	RequireEab         bool                                    `protobuf:"varint,2,opt,name=require_eab,json=requireEab,proto3" json:"require_eab,omitempty"`
	Challenges         []ACMEProvisioner_ChallengeType         `protobuf:"varint,3,rep,packed,name=challenges,proto3,enum=linkedca.ACMEProvisioner_ChallengeType" json:"challenges,omitempty"`
	AttestationFormats []ACMEProvisioner_AttestationFormatType `protobuf:"varint,4,rep,packed,name=attestation_formats,json=attestationFormats,proto3,enum=linkedca.ACMEProvisioner_AttestationFormatType" json:"attestation_formats,omitempty"`
	AttestationRoots   [][]byte                                `protobuf:"bytes,5,rep,name=attestation_roots,json=attestationRoots,proto3" json:"attestation_roots,omitempty"`
	TermsOfService     string                                  `protobuf:"bytes,6,opt,name=terms_of_service,json=termsOfService,proto3" json:"terms_of_service,omitempty"`
	Website            string                                  `protobuf:"bytes,7,opt,name=website,proto3" json:"website,omitempty"`
	CaaIdentities      []string                                `protobuf:"bytes,8,rep,name=caa_identities,json=caaIdentities,proto3" json:"caa_identities,omitempty"`
	unknownFields      protoimpl.UnknownFields
	sizeCache          protoimpl.SizeCache
}

func (x *ACMEProvisioner) Reset() {
	*x = ACMEProvisioner{}
	mi := &file_linkedca_provisioners_proto_msgTypes[14]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *ACMEProvisioner) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*ACMEProvisioner) ProtoMessage() {}

func (x *ACMEProvisioner) ProtoReflect() protoreflect.Message {
	mi := &file_linkedca_provisioners_proto_msgTypes[14]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use ACMEProvisioner.ProtoReflect.Descriptor instead.
func (*ACMEProvisioner) Descriptor() ([]byte, []int) {
	return file_linkedca_provisioners_proto_rawDescGZIP(), []int{14}
}

func (x *ACMEProvisioner) GetForceCn() bool {
	if x != nil {
		return x.ForceCn
	}
	return false
}

func (x *ACMEProvisioner) GetRequireEab() bool {
	if x != nil {
		return x.RequireEab
	}
	return false
}

func (x *ACMEProvisioner) GetChallenges() []ACMEProvisioner_ChallengeType {
	if x != nil {
		return x.Challenges
	}
	return nil
}

func (x *ACMEProvisioner) GetAttestationFormats() []ACMEProvisioner_AttestationFormatType {
	if x != nil {
		return x.AttestationFormats
	}
	return nil
}

func (x *ACMEProvisioner) GetAttestationRoots() [][]byte {
	if x != nil {
		return x.AttestationRoots
	}
	return nil
}

func (x *ACMEProvisioner) GetTermsOfService() string {
	if x != nil {
		return x.TermsOfService
	}
	return ""
}

func (x *ACMEProvisioner) GetWebsite() string {
	if x != nil {
		return x.Website
	}
	return ""
}

func (x *ACMEProvisioner) GetCaaIdentities() []string {
	if x != nil {
		return x.CaaIdentities
	}
	return nil
}

type X5CProvisioner struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	Roots         [][]byte               `protobuf:"bytes,1,rep,name=roots,proto3" json:"roots,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *X5CProvisioner) Reset() {
	*x = X5CProvisioner{}
	mi := &file_linkedca_provisioners_proto_msgTypes[15]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *X5CProvisioner) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*X5CProvisioner) ProtoMessage() {}

func (x *X5CProvisioner) ProtoReflect() protoreflect.Message {
	mi := &file_linkedca_provisioners_proto_msgTypes[15]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use X5CProvisioner.ProtoReflect.Descriptor instead.
func (*X5CProvisioner) Descriptor() ([]byte, []int) {
	return file_linkedca_provisioners_proto_rawDescGZIP(), []int{15}
}

func (x *X5CProvisioner) GetRoots() [][]byte {
	if x != nil {
		return x.Roots
	}
	return nil
}

type K8SSAProvisioner struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	PublicKeys    [][]byte               `protobuf:"bytes,1,rep,name=public_keys,json=publicKeys,proto3" json:"public_keys,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *K8SSAProvisioner) Reset() {
	*x = K8SSAProvisioner{}
	mi := &file_linkedca_provisioners_proto_msgTypes[16]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *K8SSAProvisioner) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*K8SSAProvisioner) ProtoMessage() {}

func (x *K8SSAProvisioner) ProtoReflect() protoreflect.Message {
	mi := &file_linkedca_provisioners_proto_msgTypes[16]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use K8SSAProvisioner.ProtoReflect.Descriptor instead.
func (*K8SSAProvisioner) Descriptor() ([]byte, []int) {
	return file_linkedca_provisioners_proto_rawDescGZIP(), []int{16}
}

func (x *K8SSAProvisioner) GetPublicKeys() [][]byte {
	if x != nil {
		return x.PublicKeys
	}
	return nil
}

type SSHPOPProvisioner struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *SSHPOPProvisioner) Reset() {
	*x = SSHPOPProvisioner{}
	mi := &file_linkedca_provisioners_proto_msgTypes[17]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *SSHPOPProvisioner) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*SSHPOPProvisioner) ProtoMessage() {}

func (x *SSHPOPProvisioner) ProtoReflect() protoreflect.Message {
	mi := &file_linkedca_provisioners_proto_msgTypes[17]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use SSHPOPProvisioner.ProtoReflect.Descriptor instead.
func (*SSHPOPProvisioner) Descriptor() ([]byte, []int) {
	return file_linkedca_provisioners_proto_rawDescGZIP(), []int{17}
}

type SCEPDecrypter struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	Certificate   []byte                 `protobuf:"bytes,1,opt,name=certificate,proto3" json:"certificate,omitempty"`
	Key           []byte                 `protobuf:"bytes,2,opt,name=key,proto3" json:"key,omitempty"`
	KeyUri        string                 `protobuf:"bytes,3,opt,name=key_uri,json=keyUri,proto3" json:"key_uri,omitempty"`
	KeyPassword   []byte                 `protobuf:"bytes,4,opt,name=key_password,json=keyPassword,proto3" json:"key_password,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *SCEPDecrypter) Reset() {
	*x = SCEPDecrypter{}
	mi := &file_linkedca_provisioners_proto_msgTypes[18]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *SCEPDecrypter) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*SCEPDecrypter) ProtoMessage() {}

func (x *SCEPDecrypter) ProtoReflect() protoreflect.Message {
	mi := &file_linkedca_provisioners_proto_msgTypes[18]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use SCEPDecrypter.ProtoReflect.Descriptor instead.
func (*SCEPDecrypter) Descriptor() ([]byte, []int) {
	return file_linkedca_provisioners_proto_rawDescGZIP(), []int{18}
}

func (x *SCEPDecrypter) GetCertificate() []byte {
	if x != nil {
		return x.Certificate
	}
	return nil
}

func (x *SCEPDecrypter) GetKey() []byte {
	if x != nil {
		return x.Key
	}
	return nil
}

func (x *SCEPDecrypter) GetKeyUri() string {
	if x != nil {
		return x.KeyUri
	}
	return ""
}

func (x *SCEPDecrypter) GetKeyPassword() []byte {
	if x != nil {
		return x.KeyPassword
	}
	return nil
}

type SCEPProvisioner struct {
	state                         protoimpl.MessageState `protogen:"open.v1"`
	ForceCn                       bool                   `protobuf:"varint,1,opt,name=force_cn,json=forceCn,proto3" json:"force_cn,omitempty"`
	Challenge                     string                 `protobuf:"bytes,2,opt,name=challenge,proto3" json:"challenge,omitempty"`
	Capabilities                  []string               `protobuf:"bytes,3,rep,name=capabilities,proto3" json:"capabilities,omitempty"`
	MinimumPublicKeyLength        int32                  `protobuf:"varint,4,opt,name=minimum_public_key_length,json=minimumPublicKeyLength,proto3" json:"minimum_public_key_length,omitempty"`
	IncludeRoot                   bool                   `protobuf:"varint,5,opt,name=include_root,json=includeRoot,proto3" json:"include_root,omitempty"`
	EncryptionAlgorithmIdentifier int32                  `protobuf:"varint,6,opt,name=encryption_algorithm_identifier,json=encryptionAlgorithmIdentifier,proto3" json:"encryption_algorithm_identifier,omitempty"`
	Decrypter                     *SCEPDecrypter         `protobuf:"bytes,7,opt,name=decrypter,proto3" json:"decrypter,omitempty"`
	ExcludeIntermediate           bool                   `protobuf:"varint,8,opt,name=exclude_intermediate,json=excludeIntermediate,proto3" json:"exclude_intermediate,omitempty"`
	unknownFields                 protoimpl.UnknownFields
	sizeCache                     protoimpl.SizeCache
}

func (x *SCEPProvisioner) Reset() {
	*x = SCEPProvisioner{}
	mi := &file_linkedca_provisioners_proto_msgTypes[19]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *SCEPProvisioner) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*SCEPProvisioner) ProtoMessage() {}

func (x *SCEPProvisioner) ProtoReflect() protoreflect.Message {
	mi := &file_linkedca_provisioners_proto_msgTypes[19]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use SCEPProvisioner.ProtoReflect.Descriptor instead.
func (*SCEPProvisioner) Descriptor() ([]byte, []int) {
	return file_linkedca_provisioners_proto_rawDescGZIP(), []int{19}
}

func (x *SCEPProvisioner) GetForceCn() bool {
	if x != nil {
		return x.ForceCn
	}
	return false
}

func (x *SCEPProvisioner) GetChallenge() string {
	if x != nil {
		return x.Challenge
	}
	return ""
}

func (x *SCEPProvisioner) GetCapabilities() []string {
	if x != nil {
		return x.Capabilities
	}
	return nil
}

func (x *SCEPProvisioner) GetMinimumPublicKeyLength() int32 {
	if x != nil {
		return x.MinimumPublicKeyLength
	}
	return 0
}

func (x *SCEPProvisioner) GetIncludeRoot() bool {
	if x != nil {
		return x.IncludeRoot
	}
	return false
}

func (x *SCEPProvisioner) GetEncryptionAlgorithmIdentifier() int32 {
	if x != nil {
		return x.EncryptionAlgorithmIdentifier
	}
	return 0
}

func (x *SCEPProvisioner) GetDecrypter() *SCEPDecrypter {
	if x != nil {
		return x.Decrypter
	}
	return nil
}

func (x *SCEPProvisioner) GetExcludeIntermediate() bool {
	if x != nil {
		return x.ExcludeIntermediate
	}
	return false
}

type NebulaProvisioner struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	Roots         [][]byte               `protobuf:"bytes,1,rep,name=roots,proto3" json:"roots,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *NebulaProvisioner) Reset() {
	*x = NebulaProvisioner{}
	mi := &file_linkedca_provisioners_proto_msgTypes[20]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *NebulaProvisioner) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*NebulaProvisioner) ProtoMessage() {}

func (x *NebulaProvisioner) ProtoReflect() protoreflect.Message {
	mi := &file_linkedca_provisioners_proto_msgTypes[20]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use NebulaProvisioner.ProtoReflect.Descriptor instead.
func (*NebulaProvisioner) Descriptor() ([]byte, []int) {
	return file_linkedca_provisioners_proto_rawDescGZIP(), []int{20}
}

func (x *NebulaProvisioner) GetRoots() [][]byte {
	if x != nil {
		return x.Roots
	}
	return nil
}

type BasicAuth struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	Username      string                 `protobuf:"bytes,1,opt,name=username,proto3" json:"username,omitempty"`
	Password      string                 `protobuf:"bytes,2,opt,name=password,proto3" json:"password,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *BasicAuth) Reset() {
	*x = BasicAuth{}
	mi := &file_linkedca_provisioners_proto_msgTypes[21]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *BasicAuth) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*BasicAuth) ProtoMessage() {}

func (x *BasicAuth) ProtoReflect() protoreflect.Message {
	mi := &file_linkedca_provisioners_proto_msgTypes[21]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use BasicAuth.ProtoReflect.Descriptor instead.
func (*BasicAuth) Descriptor() ([]byte, []int) {
	return file_linkedca_provisioners_proto_rawDescGZIP(), []int{21}
}

func (x *BasicAuth) GetUsername() string {
	if x != nil {
		return x.Username
	}
	return ""
}

func (x *BasicAuth) GetPassword() string {
	if x != nil {
		return x.Password
	}
	return ""
}

type BearerToken struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	BearerToken   string                 `protobuf:"bytes,1,opt,name=bearer_token,json=bearerToken,proto3" json:"bearer_token,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *BearerToken) Reset() {
	*x = BearerToken{}
	mi := &file_linkedca_provisioners_proto_msgTypes[22]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *BearerToken) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*BearerToken) ProtoMessage() {}

func (x *BearerToken) ProtoReflect() protoreflect.Message {
	mi := &file_linkedca_provisioners_proto_msgTypes[22]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use BearerToken.ProtoReflect.Descriptor instead.
func (*BearerToken) Descriptor() ([]byte, []int) {
	return file_linkedca_provisioners_proto_rawDescGZIP(), []int{22}
}

func (x *BearerToken) GetBearerToken() string {
	if x != nil {
		return x.BearerToken
	}
	return ""
}

type Webhook struct {
	state  protoimpl.MessageState `protogen:"open.v1"`
	Name   string                 `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	Id     string                 `protobuf:"bytes,2,opt,name=id,proto3" json:"id,omitempty"`
	Url    string                 `protobuf:"bytes,3,opt,name=url,proto3" json:"url,omitempty"`
	Kind   Webhook_Kind           `protobuf:"varint,4,opt,name=kind,proto3,enum=linkedca.Webhook_Kind" json:"kind,omitempty"`
	Secret string                 `protobuf:"bytes,5,opt,name=secret,proto3" json:"secret,omitempty"`
	// Types that are valid to be assigned to Auth:
	//
	//	*Webhook_BearerToken
	//	*Webhook_BasicAuth
	Auth                 isWebhook_Auth   `protobuf_oneof:"auth"`
	DisableTlsClientAuth bool             `protobuf:"varint,8,opt,name=disable_tls_client_auth,json=disableTlsClientAuth,proto3" json:"disable_tls_client_auth,omitempty"`
	CertType             Webhook_CertType `protobuf:"varint,9,opt,name=cert_type,json=certType,proto3,enum=linkedca.Webhook_CertType" json:"cert_type,omitempty"`
	unknownFields        protoimpl.UnknownFields
	sizeCache            protoimpl.SizeCache
}

func (x *Webhook) Reset() {
	*x = Webhook{}
	mi := &file_linkedca_provisioners_proto_msgTypes[23]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *Webhook) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*Webhook) ProtoMessage() {}

func (x *Webhook) ProtoReflect() protoreflect.Message {
	mi := &file_linkedca_provisioners_proto_msgTypes[23]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use Webhook.ProtoReflect.Descriptor instead.
func (*Webhook) Descriptor() ([]byte, []int) {
	return file_linkedca_provisioners_proto_rawDescGZIP(), []int{23}
}

func (x *Webhook) GetName() string {
	if x != nil {
		return x.Name
	}
	return ""
}

func (x *Webhook) GetId() string {
	if x != nil {
		return x.Id
	}
	return ""
}

func (x *Webhook) GetUrl() string {
	if x != nil {
		return x.Url
	}
	return ""
}

func (x *Webhook) GetKind() Webhook_Kind {
	if x != nil {
		return x.Kind
	}
	return Webhook_NO_KIND
}

func (x *Webhook) GetSecret() string {
	if x != nil {
		return x.Secret
	}
	return ""
}

func (x *Webhook) GetAuth() isWebhook_Auth {
	if x != nil {
		return x.Auth
	}
	return nil
}

func (x *Webhook) GetBearerToken() *BearerToken {
	if x != nil {
		if x, ok := x.Auth.(*Webhook_BearerToken); ok {
			return x.BearerToken
		}
	}
	return nil
}

func (x *Webhook) GetBasicAuth() *BasicAuth {
	if x != nil {
		if x, ok := x.Auth.(*Webhook_BasicAuth); ok {
			return x.BasicAuth
		}
	}
	return nil
}

func (x *Webhook) GetDisableTlsClientAuth() bool {
	if x != nil {
		return x.DisableTlsClientAuth
	}
	return false
}

func (x *Webhook) GetCertType() Webhook_CertType {
	if x != nil {
		return x.CertType
	}
	return Webhook_ALL
}

type isWebhook_Auth interface {
	isWebhook_Auth()
}

type Webhook_BearerToken struct {
	BearerToken *BearerToken `protobuf:"bytes,6,opt,name=bearer_token,json=bearerToken,proto3,oneof"`
}

type Webhook_BasicAuth struct {
	BasicAuth *BasicAuth `protobuf:"bytes,7,opt,name=basic_auth,json=basicAuth,proto3,oneof"`
}

func (*Webhook_BearerToken) isWebhook_Auth() {}

func (*Webhook_BasicAuth) isWebhook_Auth() {}

var File_linkedca_provisioners_proto protoreflect.FileDescriptor

const file_linkedca_provisioners_proto_rawDesc = "" +
	"\n" +
	"\x1blinkedca/provisioners.proto\x12\blinkedca\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x15linkedca/policy.proto\"\xa8\x05\n" +
	"\vProvisioner\x12\x0e\n" +
	"\x02id\x18\x01 \x01(\tR\x02id\x12!\n" +
	"\fauthority_id\x18\x02 \x01(\tR\vauthorityId\x12.\n" +
	"\x04type\x18\x03 \x01(\x0e2\x1a.linkedca.Provisioner.TypeR\x04type\x12\x12\n" +
	"\x04name\x18\x04 \x01(\tR\x04name\x126\n" +
	"\adetails\x18\x05 \x01(\v2\x1c.linkedca.ProvisionerDetailsR\adetails\x12(\n" +
	"\x06claims\x18\x06 \x01(\v2\x10.linkedca.ClaimsR\x06claims\x127\n" +
	"\rx509_template\x18\a \x01(\v2\x12.linkedca.TemplateR\fx509Template\x125\n" +
	"\fssh_template\x18\b \x01(\v2\x12.linkedca.TemplateR\vsshTemplate\x129\n" +
	"\n" +
	"created_at\x18\t \x01(\v2\x1a.google.protobuf.TimestampR\tcreatedAt\x129\n" +
	"\n" +
	"deleted_at\x18\n" +
	" \x01(\v2\x1a.google.protobuf.TimestampR\tdeletedAt\x12(\n" +
	"\x06policy\x18\v \x01(\v2\x10.linkedca.PolicyR\x06policy\x12-\n" +
	"\bwebhooks\x18\f \x03(\v2\x11.linkedca.WebhookR\bwebhooks\"\x80\x01\n" +
	"\x04Type\x12\b\n" +
	"\x04NOOP\x10\x00\x12\a\n" +
	"\x03JWK\x10\x01\x12\b\n" +
	"\x04OIDC\x10\x02\x12\a\n" +
	"\x03GCP\x10\x03\x12\a\n" +
	"\x03AWS\x10\x04\x12\t\n" +
	"\x05AZURE\x10\x05\x12\b\n" +
	"\x04ACME\x10\x06\x12\a\n" +
	"\x03X5C\x10\a\x12\t\n" +
	"\x05K8SSA\x10\b\x12\n" +
	"\n" +
	"\x06SSHPOP\x10\t\x12\b\n" +
	"\x04SCEP\x10\n" +
	"\x12\n" +
	"\n" +
	"\x06NEBULA\x10\v\"i\n" +
	"\x13ProvisionerIdentity\x12\x0e\n" +
	"\x02id\x18\x01 \x01(\tR\x02id\x12.\n" +
	"\x04type\x18\x02 \x01(\x0e2\x1a.linkedca.Provisioner.TypeR\x04type\x12\x12\n" +
	"\x04name\x18\x03 \x01(\tR\x04name\"\xbd\x04\n" +
	"\x12ProvisionerDetails\x12,\n" +
	"\x03JWK\x18\x14 \x01(\v2\x18.linkedca.JWKProvisionerH\x00R\x03JWK\x12/\n" +
	"\x04OIDC\x18\x15 \x01(\v2\x19.linkedca.OIDCProvisionerH\x00R\x04OIDC\x12,\n" +
	"\x03GCP\x18\x16 \x01(\v2\x18.linkedca.GCPProvisionerH\x00R\x03GCP\x12,\n" +
	"\x03AWS\x18\x17 \x01(\v2\x18.linkedca.AWSProvisionerH\x00R\x03AWS\x122\n" +
	"\x05Azure\x18\x18 \x01(\v2\x1a.linkedca.AzureProvisionerH\x00R\x05Azure\x12/\n" +
	"\x04ACME\x18\x19 \x01(\v2\x19.linkedca.ACMEProvisionerH\x00R\x04ACME\x12,\n" +
	"\x03X5C\x18\x1a \x01(\v2\x18.linkedca.X5CProvisionerH\x00R\x03X5C\x122\n" +
	"\x05K8sSA\x18\x1b \x01(\v2\x1a.linkedca.K8sSAProvisionerH\x00R\x05K8sSA\x125\n" +
	"\x06SSHPOP\x18\x1c \x01(\v2\x1b.linkedca.SSHPOPProvisionerH\x00R\x06SSHPOP\x12/\n" +
	"\x04SCEP\x18\x1d \x01(\v2\x19.linkedca.SCEPProvisionerH\x00R\x04SCEP\x125\n" +
	"\x06Nebula\x18\x1e \x01(\v2\x1b.linkedca.NebulaProvisionerH\x00R\x06NebulaB\x06\n" +
	"\x04data\"L\n" +
	"\x0fProvisionerList\x129\n" +
	"\fprovisioners\x18\x01 \x03(\v2\x15.linkedca.ProvisionerR\fprovisioners\"\x81\x02\n" +
	"\x06Claims\x12(\n" +
	"\x04x509\x18\x01 \x01(\v2\x14.linkedca.X509ClaimsR\x04x509\x12%\n" +
	"\x03ssh\x18\x02 \x01(\v2\x13.linkedca.SSHClaimsR\x03ssh\x12'\n" +
	"\x0fdisable_renewal\x18\x03 \x01(\bR\x0edisableRenewal\x12;\n" +
	"\x1aallow_renewal_after_expiry\x18\x04 \x01(\bR\x17allowRenewalAfterExpiry\x12@\n" +
	"\x1cdisable_smallstep_extensions\x18\x05 \x01(\bR\x1adisableSmallstepExtensions\"Y\n" +
	"\n" +
	"X509Claims\x12\x18\n" +
	"\aenabled\x18\x01 \x01(\bR\aenabled\x121\n" +
	"\tdurations\x18\x02 \x01(\v2\x13.linkedca.DurationsR\tdurations\"\x9d\x01\n" +
	"\tSSHClaims\x12\x18\n" +
	"\aenabled\x18\x01 \x01(\bR\aenabled\x12:\n" +
	"\x0euser_durations\x18\x02 \x01(\v2\x13.linkedca.DurationsR\ruserDurations\x12:\n" +
	"\x0ehost_durations\x18\x03 \x01(\v2\x13.linkedca.DurationsR\rhostDurations\"I\n" +
	"\tDurations\x12\x18\n" +
	"\adefault\x18\x01 \x01(\tR\adefault\x12\x10\n" +
	"\x03min\x18\x02 \x01(\tR\x03min\x12\x10\n" +
	"\x03max\x18\x03 \x01(\tR\x03max\":\n" +
	"\bTemplate\x12\x1a\n" +
	"\btemplate\x18\x01 \x01(\fR\btemplate\x12\x12\n" +
	"\x04data\x18\x02 \x01(\fR\x04data\"c\n" +
	"\x0eJWKProvisioner\x12\x1d\n" +
	"\n" +
	"public_key\x18\x01 \x01(\fR\tpublicKey\x122\n" +
	"\x15encrypted_private_key\x18\x02 \x01(\fR\x13encryptedPrivateKey\"\xd1\x02\n" +
	"\x0fOIDCProvisioner\x12\x1b\n" +
	"\tclient_id\x18\x01 \x01(\tR\bclientId\x12#\n" +
	"\rclient_secret\x18\x02 \x01(\tR\fclientSecret\x125\n" +
	"\x16configuration_endpoint\x18\x03 \x01(\tR\x15configurationEndpoint\x12\x16\n" +
	"\x06admins\x18\x04 \x03(\tR\x06admins\x12\x18\n" +
	"\adomains\x18\x05 \x03(\tR\adomains\x12\x16\n" +
	"\x06groups\x18\x06 \x03(\tR\x06groups\x12%\n" +
	"\x0elisten_address\x18\a \x01(\tR\rlistenAddress\x12\x1b\n" +
	"\ttenant_id\x18\b \x01(\tR\btenantId\x12\x16\n" +
	"\x06scopes\x18\t \x03(\tR\x06scopes\x12\x1f\n" +
	"\vauth_params\x18\n" +
	" \x03(\tR\n" +
	"authParams\"\xac\x03\n" +
	"\x0eGCPProvisioner\x12)\n" +
	"\x10service_accounts\x18\x01 \x03(\tR\x0fserviceAccounts\x12\x1f\n" +
	"\vproject_ids\x18\x02 \x03(\tR\n" +
	"projectIds\x12.\n" +
	"\x13disable_custom_sans\x18\x03 \x01(\bR\x11disableCustomSans\x12:\n" +
	"\x1adisable_trust_on_first_use\x18\x04 \x01(\bR\x16disableTrustOnFirstUse\x12!\n" +
	"\finstance_age\x18\x05 \x01(\tR\vinstanceAge\x122\n" +
	"\x13disable_ssh_ca_user\x18\x06 \x01(\bH\x00R\x10disableSshCaUser\x88\x01\x01\x122\n" +
	"\x13disable_ssh_ca_host\x18\a \x01(\bH\x01R\x10disableSshCaHost\x88\x01\x01\x12'\n" +
	"\x0forganization_id\x18\b \x01(\tR\x0eorganizationIdB\x16\n" +
	"\x14_disable_ssh_ca_userB\x16\n" +
	"\x14_disable_ssh_ca_host\"\xbb\x01\n" +
	"\x0eAWSProvisioner\x12\x1a\n" +
	"\baccounts\x18\x01 \x03(\tR\baccounts\x12.\n" +
	"\x13disable_custom_sans\x18\x02 \x01(\bR\x11disableCustomSans\x12:\n" +
	"\x1adisable_trust_on_first_use\x18\x03 \x01(\bR\x16disableTrustOnFirstUse\x12!\n" +
	"\finstance_age\x18\x04 \x01(\tR\vinstanceAge\"\xaa\x02\n" +
	"\x10AzureProvisioner\x12\x1b\n" +
	"\ttenant_id\x18\x01 \x01(\tR\btenantId\x12'\n" +
	"\x0fresource_groups\x18\x02 \x03(\tR\x0eresourceGroups\x12\x1a\n" +
	"\baudience\x18\x03 \x01(\tR\baudience\x12.\n" +
	"\x13disable_custom_sans\x18\x04 \x01(\bR\x11disableCustomSans\x12:\n" +
	"\x1adisable_trust_on_first_use\x18\x05 \x01(\bR\x16disableTrustOnFirstUse\x12)\n" +
	"\x10subscription_ids\x18\x06 \x03(\tR\x0fsubscriptionIds\x12\x1d\n" +
	"\n" +
	"object_ids\x18\a \x03(\tR\tobjectIds\"\xaf\x04\n" +
	"\x0fACMEProvisioner\x12\x19\n" +
	"\bforce_cn\x18\x01 \x01(\bR\aforceCn\x12\x1f\n" +
	"\vrequire_eab\x18\x02 \x01(\bR\n" +
	"requireEab\x12G\n" +
	"\n" +
	"challenges\x18\x03 \x03(\x0e2'.linkedca.ACMEProvisioner.ChallengeTypeR\n" +
	"challenges\x12`\n" +
	"\x13attestation_formats\x18\x04 \x03(\x0e2/.linkedca.ACMEProvisioner.AttestationFormatTypeR\x12attestationFormats\x12+\n" +
	"\x11attestation_roots\x18\x05 \x03(\fR\x10attestationRoots\x12(\n" +
	"\x10terms_of_service\x18\x06 \x01(\tR\x0etermsOfService\x12\x18\n" +
	"\awebsite\x18\a \x01(\tR\awebsite\x12%\n" +
	"\x0ecaa_identities\x18\b \x03(\tR\rcaaIdentities\"\\\n" +
	"\rChallengeType\x12\v\n" +
	"\aUNKNOWN\x10\x00\x12\v\n" +
	"\aHTTP_01\x10\x01\x12\n" +
	"\n" +
	"\x06DNS_01\x10\x02\x12\x0f\n" +
	"\vTLS_ALPN_01\x10\x03\x12\x14\n" +
	"\x10DEVICE_ATTEST_01\x10\x04\"?\n" +
	"\x15AttestationFormatType\x12\b\n" +
	"\x04NONE\x10\x00\x12\t\n" +
	"\x05APPLE\x10\x01\x12\b\n" +
	"\x04STEP\x10\x02\x12\a\n" +
	"\x03TPM\x10\x03\"&\n" +
	"\x0eX5CProvisioner\x12\x14\n" +
	"\x05roots\x18\x01 \x03(\fR\x05roots\"3\n" +
	"\x10K8sSAProvisioner\x12\x1f\n" +
	"\vpublic_keys\x18\x01 \x03(\fR\n" +
	"publicKeys\"\x13\n" +
	"\x11SSHPOPProvisioner\"\x7f\n" +
	"\rSCEPDecrypter\x12 \n" +
	"\vcertificate\x18\x01 \x01(\fR\vcertificate\x12\x10\n" +
	"\x03key\x18\x02 \x01(\fR\x03key\x12\x17\n" +
	"\akey_uri\x18\x03 \x01(\tR\x06keyUri\x12!\n" +
	"\fkey_password\x18\x04 \x01(\fR\vkeyPassword\"\xfe\x02\n" +
	"\x0fSCEPProvisioner\x12\x19\n" +
	"\bforce_cn\x18\x01 \x01(\bR\aforceCn\x12\x1c\n" +
	"\tchallenge\x18\x02 \x01(\tR\tchallenge\x12\"\n" +
	"\fcapabilities\x18\x03 \x03(\tR\fcapabilities\x129\n" +
	"\x19minimum_public_key_length\x18\x04 \x01(\x05R\x16minimumPublicKeyLength\x12!\n" +
	"\finclude_root\x18\x05 \x01(\bR\vincludeRoot\x12F\n" +
	"\x1fencryption_algorithm_identifier\x18\x06 \x01(\x05R\x1dencryptionAlgorithmIdentifier\x125\n" +
	"\tdecrypter\x18\a \x01(\v2\x17.linkedca.SCEPDecrypterR\tdecrypter\x121\n" +
	"\x14exclude_intermediate\x18\b \x01(\bR\x13excludeIntermediate\")\n" +
	"\x11NebulaProvisioner\x12\x14\n" +
	"\x05roots\x18\x01 \x03(\fR\x05roots\"C\n" +
	"\tBasicAuth\x12\x1a\n" +
	"\busername\x18\x01 \x01(\tR\busername\x12\x1a\n" +
	"\bpassword\x18\x02 \x01(\tR\bpassword\"0\n" +
	"\vBearerToken\x12!\n" +
	"\fbearer_token\x18\x01 \x01(\tR\vbearerToken\"\xec\x03\n" +
	"\aWebhook\x12\x12\n" +
	"\x04name\x18\x01 \x01(\tR\x04name\x12\x0e\n" +
	"\x02id\x18\x02 \x01(\tR\x02id\x12\x10\n" +
	"\x03url\x18\x03 \x01(\tR\x03url\x12*\n" +
	"\x04kind\x18\x04 \x01(\x0e2\x16.linkedca.Webhook.KindR\x04kind\x12\x16\n" +
	"\x06secret\x18\x05 \x01(\tR\x06secret\x12:\n" +
	"\fbearer_token\x18\x06 \x01(\v2\x15.linkedca.BearerTokenH\x00R\vbearerToken\x124\n" +
	"\n" +
	"basic_auth\x18\a \x01(\v2\x13.linkedca.BasicAuthH\x00R\tbasicAuth\x125\n" +
	"\x17disable_tls_client_auth\x18\b \x01(\bR\x14disableTlsClientAuth\x127\n" +
	"\tcert_type\x18\t \x01(\x0e2\x1a.linkedca.Webhook.CertTypeR\bcertType\"U\n" +
	"\x04Kind\x12\v\n" +
	"\aNO_KIND\x10\x00\x12\r\n" +
	"\tENRICHING\x10\x01\x12\x0f\n" +
	"\vAUTHORIZING\x10\x02\x12\x11\n" +
	"\rSCEPCHALLENGE\x10\x03\x12\r\n" +
	"\tNOTIFYING\x10\x04\"&\n" +
	"\bCertType\x12\a\n" +
	"\x03ALL\x10\x00\x12\b\n" +
	"\x04X509\x10\x01\x12\a\n" +
	"\x03SSH\x10\x02B\x06\n" +
	"\x04authB\x1fZ\x1dgithub.com/smallstep/linkedcab\x06proto3"

var (
	file_linkedca_provisioners_proto_rawDescOnce sync.Once
	file_linkedca_provisioners_proto_rawDescData []byte
)

func file_linkedca_provisioners_proto_rawDescGZIP() []byte {
	file_linkedca_provisioners_proto_rawDescOnce.Do(func() {
		file_linkedca_provisioners_proto_rawDescData = protoimpl.X.CompressGZIP(unsafe.Slice(unsafe.StringData(file_linkedca_provisioners_proto_rawDesc), len(file_linkedca_provisioners_proto_rawDesc)))
	})
	return file_linkedca_provisioners_proto_rawDescData
}

var file_linkedca_provisioners_proto_enumTypes = make([]protoimpl.EnumInfo, 5)
var file_linkedca_provisioners_proto_msgTypes = make([]protoimpl.MessageInfo, 24)
var file_linkedca_provisioners_proto_goTypes = []any{
	(Provisioner_Type)(0),                      // 0: linkedca.Provisioner.Type
	(ACMEProvisioner_ChallengeType)(0),         // 1: linkedca.ACMEProvisioner.ChallengeType
	(ACMEProvisioner_AttestationFormatType)(0), // 2: linkedca.ACMEProvisioner.AttestationFormatType
	(Webhook_Kind)(0),                          // 3: linkedca.Webhook.Kind
	(Webhook_CertType)(0),                      // 4: linkedca.Webhook.CertType
	(*Provisioner)(nil),                        // 5: linkedca.Provisioner
	(*ProvisionerIdentity)(nil),                // 6: linkedca.ProvisionerIdentity
	(*ProvisionerDetails)(nil),                 // 7: linkedca.ProvisionerDetails
	(*ProvisionerList)(nil),                    // 8: linkedca.ProvisionerList
	(*Claims)(nil),                             // 9: linkedca.Claims
	(*X509Claims)(nil),                         // 10: linkedca.X509Claims
	(*SSHClaims)(nil),                          // 11: linkedca.SSHClaims
	(*Durations)(nil),                          // 12: linkedca.Durations
	(*Template)(nil),                           // 13: linkedca.Template
	(*JWKProvisioner)(nil),                     // 14: linkedca.JWKProvisioner
	(*OIDCProvisioner)(nil),                    // 15: linkedca.OIDCProvisioner
	(*GCPProvisioner)(nil),                     // 16: linkedca.GCPProvisioner
	(*AWSProvisioner)(nil),                     // 17: linkedca.AWSProvisioner
	(*AzureProvisioner)(nil),                   // 18: linkedca.AzureProvisioner
	(*ACMEProvisioner)(nil),                    // 19: linkedca.ACMEProvisioner
	(*X5CProvisioner)(nil),                     // 20: linkedca.X5CProvisioner
	(*K8SSAProvisioner)(nil),                   // 21: linkedca.K8sSAProvisioner
	(*SSHPOPProvisioner)(nil),                  // 22: linkedca.SSHPOPProvisioner
	(*SCEPDecrypter)(nil),                      // 23: linkedca.SCEPDecrypter
	(*SCEPProvisioner)(nil),                    // 24: linkedca.SCEPProvisioner
	(*NebulaProvisioner)(nil),                  // 25: linkedca.NebulaProvisioner
	(*BasicAuth)(nil),                          // 26: linkedca.BasicAuth
	(*BearerToken)(nil),                        // 27: linkedca.BearerToken
	(*Webhook)(nil),                            // 28: linkedca.Webhook
	(*timestamppb.Timestamp)(nil),              // 29: google.protobuf.Timestamp
	(*Policy)(nil),                             // 30: linkedca.Policy
}
var file_linkedca_provisioners_proto_depIdxs = []int32{
	0,  // 0: linkedca.Provisioner.type:type_name -> linkedca.Provisioner.Type
	7,  // 1: linkedca.Provisioner.details:type_name -> linkedca.ProvisionerDetails
	9,  // 2: linkedca.Provisioner.claims:type_name -> linkedca.Claims
	13, // 3: linkedca.Provisioner.x509_template:type_name -> linkedca.Template
	13, // 4: linkedca.Provisioner.ssh_template:type_name -> linkedca.Template
	29, // 5: linkedca.Provisioner.created_at:type_name -> google.protobuf.Timestamp
	29, // 6: linkedca.Provisioner.deleted_at:type_name -> google.protobuf.Timestamp
	30, // 7: linkedca.Provisioner.policy:type_name -> linkedca.Policy
	28, // 8: linkedca.Provisioner.webhooks:type_name -> linkedca.Webhook
	0,  // 9: linkedca.ProvisionerIdentity.type:type_name -> linkedca.Provisioner.Type
	14, // 10: linkedca.ProvisionerDetails.JWK:type_name -> linkedca.JWKProvisioner
	15, // 11: linkedca.ProvisionerDetails.OIDC:type_name -> linkedca.OIDCProvisioner
	16, // 12: linkedca.ProvisionerDetails.GCP:type_name -> linkedca.GCPProvisioner
	17, // 13: linkedca.ProvisionerDetails.AWS:type_name -> linkedca.AWSProvisioner
	18, // 14: linkedca.ProvisionerDetails.Azure:type_name -> linkedca.AzureProvisioner
	19, // 15: linkedca.ProvisionerDetails.ACME:type_name -> linkedca.ACMEProvisioner
	20, // 16: linkedca.ProvisionerDetails.X5C:type_name -> linkedca.X5CProvisioner
	21, // 17: linkedca.ProvisionerDetails.K8sSA:type_name -> linkedca.K8sSAProvisioner
	22, // 18: linkedca.ProvisionerDetails.SSHPOP:type_name -> linkedca.SSHPOPProvisioner
	24, // 19: linkedca.ProvisionerDetails.SCEP:type_name -> linkedca.SCEPProvisioner
	25, // 20: linkedca.ProvisionerDetails.Nebula:type_name -> linkedca.NebulaProvisioner
	5,  // 21: linkedca.ProvisionerList.provisioners:type_name -> linkedca.Provisioner
	10, // 22: linkedca.Claims.x509:type_name -> linkedca.X509Claims
	11, // 23: linkedca.Claims.ssh:type_name -> linkedca.SSHClaims
	12, // 24: linkedca.X509Claims.durations:type_name -> linkedca.Durations
	12, // 25: linkedca.SSHClaims.user_durations:type_name -> linkedca.Durations
	12, // 26: linkedca.SSHClaims.host_durations:type_name -> linkedca.Durations
	1,  // 27: linkedca.ACMEProvisioner.challenges:type_name -> linkedca.ACMEProvisioner.ChallengeType
	2,  // 28: linkedca.ACMEProvisioner.attestation_formats:type_name -> linkedca.ACMEProvisioner.AttestationFormatType
	23, // 29: linkedca.SCEPProvisioner.decrypter:type_name -> linkedca.SCEPDecrypter
	3,  // 30: linkedca.Webhook.kind:type_name -> linkedca.Webhook.Kind
	27, // 31: linkedca.Webhook.bearer_token:type_name -> linkedca.BearerToken
	26, // 32: linkedca.Webhook.basic_auth:type_name -> linkedca.BasicAuth
	4,  // 33: linkedca.Webhook.cert_type:type_name -> linkedca.Webhook.CertType
	34, // [34:34] is the sub-list for method output_type
	34, // [34:34] is the sub-list for method input_type
	34, // [34:34] is the sub-list for extension type_name
	34, // [34:34] is the sub-list for extension extendee
	0,  // [0:34] is the sub-list for field type_name
}

func init() { file_linkedca_provisioners_proto_init() }
func file_linkedca_provisioners_proto_init() {
	if File_linkedca_provisioners_proto != nil {
		return
	}
	file_linkedca_policy_proto_init()
	file_linkedca_provisioners_proto_msgTypes[2].OneofWrappers = []any{
		(*ProvisionerDetails_JWK)(nil),
		(*ProvisionerDetails_OIDC)(nil),
		(*ProvisionerDetails_GCP)(nil),
		(*ProvisionerDetails_AWS)(nil),
		(*ProvisionerDetails_Azure)(nil),
		(*ProvisionerDetails_ACME)(nil),
		(*ProvisionerDetails_X5C)(nil),
		(*ProvisionerDetails_K8SSA)(nil),
		(*ProvisionerDetails_SSHPOP)(nil),
		(*ProvisionerDetails_SCEP)(nil),
		(*ProvisionerDetails_Nebula)(nil),
	}
	file_linkedca_provisioners_proto_msgTypes[11].OneofWrappers = []any{}
	file_linkedca_provisioners_proto_msgTypes[23].OneofWrappers = []any{
		(*Webhook_BearerToken)(nil),
		(*Webhook_BasicAuth)(nil),
	}
	type x struct{}
	out := protoimpl.TypeBuilder{
		File: protoimpl.DescBuilder{
			GoPackagePath: reflect.TypeOf(x{}).PkgPath(),
			RawDescriptor: unsafe.Slice(unsafe.StringData(file_linkedca_provisioners_proto_rawDesc), len(file_linkedca_provisioners_proto_rawDesc)),
			NumEnums:      5,
			NumMessages:   24,
			NumExtensions: 0,
			NumServices:   0,
		},
		GoTypes:           file_linkedca_provisioners_proto_goTypes,
		DependencyIndexes: file_linkedca_provisioners_proto_depIdxs,
		EnumInfos:         file_linkedca_provisioners_proto_enumTypes,
		MessageInfos:      file_linkedca_provisioners_proto_msgTypes,
	}.Build()
	File_linkedca_provisioners_proto = out.File
	file_linkedca_provisioners_proto_goTypes = nil
	file_linkedca_provisioners_proto_depIdxs = nil
}
