// Code generated by protoc-gen-go. DO NOT EDIT.
// versions:
// 	protoc-gen-go v1.36.9
// 	protoc        v6.32.1
// source: linkedca/admin.proto

package linkedca

import (
	protoreflect "google.golang.org/protobuf/reflect/protoreflect"
	protoimpl "google.golang.org/protobuf/runtime/protoimpl"
	timestamppb "google.golang.org/protobuf/types/known/timestamppb"
	reflect "reflect"
	sync "sync"
	unsafe "unsafe"
)

const (
	// Verify that this generated code is sufficiently up-to-date.
	_ = protoimpl.EnforceVersion(20 - protoimpl.MinVersion)
	// Verify that runtime/protoimpl is sufficiently up-to-date.
	_ = protoimpl.EnforceVersion(protoimpl.MaxVersion - 20)
)

type Admin_Type int32

const (
	Admin_UNKNOWN     Admin_Type = 0
	Admin_ADMIN       Admin_Type = 1
	Admin_SUPER_ADMIN Admin_Type = 2
)

// Enum value maps for Admin_Type.
var (
	Admin_Type_name = map[int32]string{
		0: "UNKNOWN",
		1: "ADMIN",
		2: "SUPER_ADMIN",
	}
	Admin_Type_value = map[string]int32{
		"UNKNOWN":     0,
		"ADMIN":       1,
		"SUPER_ADMIN": 2,
	}
)

func (x Admin_Type) Enum() *Admin_Type {
	p := new(Admin_Type)
	*p = x
	return p
}

func (x Admin_Type) String() string {
	return protoimpl.X.EnumStringOf(x.Descriptor(), protoreflect.EnumNumber(x))
}

func (Admin_Type) Descriptor() protoreflect.EnumDescriptor {
	return file_linkedca_admin_proto_enumTypes[0].Descriptor()
}

func (Admin_Type) Type() protoreflect.EnumType {
	return &file_linkedca_admin_proto_enumTypes[0]
}

func (x Admin_Type) Number() protoreflect.EnumNumber {
	return protoreflect.EnumNumber(x)
}

// Deprecated: Use Admin_Type.Descriptor instead.
func (Admin_Type) EnumDescriptor() ([]byte, []int) {
	return file_linkedca_admin_proto_rawDescGZIP(), []int{0, 0}
}

type Admin struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	Id            string                 `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
	AuthorityId   string                 `protobuf:"bytes,2,opt,name=authority_id,json=authorityId,proto3" json:"authority_id,omitempty"`
	Subject       string                 `protobuf:"bytes,3,opt,name=subject,proto3" json:"subject,omitempty"`
	ProvisionerId string                 `protobuf:"bytes,4,opt,name=provisioner_id,json=provisionerId,proto3" json:"provisioner_id,omitempty"`
	Type          Admin_Type             `protobuf:"varint,5,opt,name=type,proto3,enum=linkedca.Admin_Type" json:"type,omitempty"`
	CreatedAt     *timestamppb.Timestamp `protobuf:"bytes,6,opt,name=created_at,json=createdAt,proto3" json:"created_at,omitempty"`
	DeletedAt     *timestamppb.Timestamp `protobuf:"bytes,7,opt,name=deleted_at,json=deletedAt,proto3" json:"deleted_at,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *Admin) Reset() {
	*x = Admin{}
	mi := &file_linkedca_admin_proto_msgTypes[0]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *Admin) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*Admin) ProtoMessage() {}

func (x *Admin) ProtoReflect() protoreflect.Message {
	mi := &file_linkedca_admin_proto_msgTypes[0]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use Admin.ProtoReflect.Descriptor instead.
func (*Admin) Descriptor() ([]byte, []int) {
	return file_linkedca_admin_proto_rawDescGZIP(), []int{0}
}

func (x *Admin) GetId() string {
	if x != nil {
		return x.Id
	}
	return ""
}

func (x *Admin) GetAuthorityId() string {
	if x != nil {
		return x.AuthorityId
	}
	return ""
}

func (x *Admin) GetSubject() string {
	if x != nil {
		return x.Subject
	}
	return ""
}

func (x *Admin) GetProvisionerId() string {
	if x != nil {
		return x.ProvisionerId
	}
	return ""
}

func (x *Admin) GetType() Admin_Type {
	if x != nil {
		return x.Type
	}
	return Admin_UNKNOWN
}

func (x *Admin) GetCreatedAt() *timestamppb.Timestamp {
	if x != nil {
		return x.CreatedAt
	}
	return nil
}

func (x *Admin) GetDeletedAt() *timestamppb.Timestamp {
	if x != nil {
		return x.DeletedAt
	}
	return nil
}

type AdminList struct {
	state         protoimpl.MessageState `protogen:"open.v1"`
	Admins        []*Admin               `protobuf:"bytes,1,rep,name=admins,proto3" json:"admins,omitempty"`
	unknownFields protoimpl.UnknownFields
	sizeCache     protoimpl.SizeCache
}

func (x *AdminList) Reset() {
	*x = AdminList{}
	mi := &file_linkedca_admin_proto_msgTypes[1]
	ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
	ms.StoreMessageInfo(mi)
}

func (x *AdminList) String() string {
	return protoimpl.X.MessageStringOf(x)
}

func (*AdminList) ProtoMessage() {}

func (x *AdminList) ProtoReflect() protoreflect.Message {
	mi := &file_linkedca_admin_proto_msgTypes[1]
	if x != nil {
		ms := protoimpl.X.MessageStateOf(protoimpl.Pointer(x))
		if ms.LoadMessageInfo() == nil {
			ms.StoreMessageInfo(mi)
		}
		return ms
	}
	return mi.MessageOf(x)
}

// Deprecated: Use AdminList.ProtoReflect.Descriptor instead.
func (*AdminList) Descriptor() ([]byte, []int) {
	return file_linkedca_admin_proto_rawDescGZIP(), []int{1}
}

func (x *AdminList) GetAdmins() []*Admin {
	if x != nil {
		return x.Admins
	}
	return nil
}

var File_linkedca_admin_proto protoreflect.FileDescriptor

const file_linkedca_admin_proto_rawDesc = "" +
	"\n" +
	"\x14linkedca/admin.proto\x12\blinkedca\x1a\x1fgoogle/protobuf/timestamp.proto\"\xcc\x02\n" +
	"\x05Admin\x12\x0e\n" +
	"\x02id\x18\x01 \x01(\tR\x02id\x12!\n" +
	"\fauthority_id\x18\x02 \x01(\tR\vauthorityId\x12\x18\n" +
	"\asubject\x18\x03 \x01(\tR\asubject\x12%\n" +
	"\x0eprovisioner_id\x18\x04 \x01(\tR\rprovisionerId\x12(\n" +
	"\x04type\x18\x05 \x01(\x0e2\x14.linkedca.Admin.TypeR\x04type\x129\n" +
	"\n" +
	"created_at\x18\x06 \x01(\v2\x1a.google.protobuf.TimestampR\tcreatedAt\x129\n" +
	"\n" +
	"deleted_at\x18\a \x01(\v2\x1a.google.protobuf.TimestampR\tdeletedAt\"/\n" +
	"\x04Type\x12\v\n" +
	"\aUNKNOWN\x10\x00\x12\t\n" +
	"\x05ADMIN\x10\x01\x12\x0f\n" +
	"\vSUPER_ADMIN\x10\x02\"4\n" +
	"\tAdminList\x12'\n" +
	"\x06admins\x18\x01 \x03(\v2\x0f.linkedca.AdminR\x06adminsB\x1fZ\x1dgithub.com/smallstep/linkedcab\x06proto3"

var (
	file_linkedca_admin_proto_rawDescOnce sync.Once
	file_linkedca_admin_proto_rawDescData []byte
)

func file_linkedca_admin_proto_rawDescGZIP() []byte {
	file_linkedca_admin_proto_rawDescOnce.Do(func() {
		file_linkedca_admin_proto_rawDescData = protoimpl.X.CompressGZIP(unsafe.Slice(unsafe.StringData(file_linkedca_admin_proto_rawDesc), len(file_linkedca_admin_proto_rawDesc)))
	})
	return file_linkedca_admin_proto_rawDescData
}

var file_linkedca_admin_proto_enumTypes = make([]protoimpl.EnumInfo, 1)
var file_linkedca_admin_proto_msgTypes = make([]protoimpl.MessageInfo, 2)
var file_linkedca_admin_proto_goTypes = []any{
	(Admin_Type)(0),               // 0: linkedca.Admin.Type
	(*Admin)(nil),                 // 1: linkedca.Admin
	(*AdminList)(nil),             // 2: linkedca.AdminList
	(*timestamppb.Timestamp)(nil), // 3: google.protobuf.Timestamp
}
var file_linkedca_admin_proto_depIdxs = []int32{
	0, // 0: linkedca.Admin.type:type_name -> linkedca.Admin.Type
	3, // 1: linkedca.Admin.created_at:type_name -> google.protobuf.Timestamp
	3, // 2: linkedca.Admin.deleted_at:type_name -> google.protobuf.Timestamp
	1, // 3: linkedca.AdminList.admins:type_name -> linkedca.Admin
	4, // [4:4] is the sub-list for method output_type
	4, // [4:4] is the sub-list for method input_type
	4, // [4:4] is the sub-list for extension type_name
	4, // [4:4] is the sub-list for extension extendee
	0, // [0:4] is the sub-list for field type_name
}

func init() { file_linkedca_admin_proto_init() }
func file_linkedca_admin_proto_init() {
	if File_linkedca_admin_proto != nil {
		return
	}
	type x struct{}
	out := protoimpl.TypeBuilder{
		File: protoimpl.DescBuilder{
			GoPackagePath: reflect.TypeOf(x{}).PkgPath(),
			RawDescriptor: unsafe.Slice(unsafe.StringData(file_linkedca_admin_proto_rawDesc), len(file_linkedca_admin_proto_rawDesc)),
			NumEnums:      1,
			NumMessages:   2,
			NumExtensions: 0,
			NumServices:   0,
		},
		GoTypes:           file_linkedca_admin_proto_goTypes,
		DependencyIndexes: file_linkedca_admin_proto_depIdxs,
		EnumInfos:         file_linkedca_admin_proto_enumTypes,
		MessageInfos:      file_linkedca_admin_proto_msgTypes,
	}.Build()
	File_linkedca_admin_proto = out.File
	file_linkedca_admin_proto_goTypes = nil
	file_linkedca_admin_proto_depIdxs = nil
}
